if exists (select * from sysobjects where id = object_id(N'[dbo].[TRG_AUDIT_EMPLOYEESECURITYEXT]') and OBJECTPROPERTY(id, N'IsTrigger') = 1)
drop trigger [dbo].[TRG_AUDIT_EMPLOYEESECURITYEXT]
GO

Create Trigger TRG_AUDIT_EMPLOYEESECURITYEXT
On EMPLOYEESECURITYEXT
For Insert, Update, Delete NOT FOR REPLICATION
As
	DECLARE @DeleteCount int
	DECLARE @InsertCount int
	DECLARE @CurrentUserID VARCHAR(12)
	SELECT @CurrentUserID = SessionDataValue FROM #SessionData WHERE SessionDataKey = 'CURRENT_USER'
	SELECT  @DeleteCount = COUNT(*) FROM DELETED
	SELECT  @InsertCount = COUNT(*) FROM INSERTED
	
	-- Avoid spurious logging when Employee is renamed
	if @InsertCount = 0 OR @DeleteCount = 0 OR UPDATE(FunctionId) OR UPDATE(SCOPETYPE) OR UPDATE(SECURITYTYPE)
	   BEGIN														   

		--- Log Individual Permission Removals
	   INSERT INTO SecAuditHistory(FunctionId, EmployeeId, SecAuditType, SecScopeType, SecAuditUID, SecAuditDate)
		  SELECT FunctionId, EMPLOYEEID, 
		  CASE SECURITYTYPE WHEN 1 THEN 8 ELSE 6 END, 
		  SCOPETYPE, @CurrentUserID, CAST(CONVERT(VARCHAR, GETDATE(), 20) AS datetime)
		  FROM DELETED
		--- Log Group Adds
	   INSERT INTO SecAuditHistory(FunctionId, EmployeeId, SecAuditType, SecScopeType, SecAuditUID, SecAuditDate)
		  SELECT FunctionId, EMPLOYEEID, 
		  CASE SECURITYTYPE WHEN 1 THEN 7 ELSE 5 END, 
		  SCOPETYPE, @CurrentUserID, CAST(CONVERT(VARCHAR, GETDATE(), 20) AS datetime)
		  FROM INSERTED

	   END
GO