CREATE   FUNCTION ComputeWOScheduleInterval
   (@Interval int, @IntervalType int)
RETURNS int
AS
BEGIN
   return CASE @IntervalType
		WHEN 0 THEN @Interval
		WHEN 1 THEN @Interval * 7 
		WHEN 2 THEN @Interval * 30
		WHEN 3 THEN @Interval * 365
		WHEN 4 THEN @Interval * 15
	ELSE NULL
   END
END
GO

CREATE    FUNCTION AdjustQuantityForLeadTime
   (@Quantity int, @Interval int, @IntervalType int, @LeadTime int, @Active int)
RETURNS int
AS
BEGIN
   DECLARE @EffectiveQuantity int
   DECLARE @EffectiveInterval int

   SET @EffectiveInterval = ISNULL(dbo.ComputeWOScheduleInterval(@Interval, @IntervalType), 0)

   IF @EffectiveInterval > 0 AND ISNULL(@LeadTime, 0) > @EffectiveInterval
      SET @EffectiveQuantity = @Quantity * CEILING(cast(@LeadTime as float) / @EffectiveInterval)
   ELSE 
      SET @EffectiveQuantity = @Quantity

   IF @Active = 1
      SET @EffectiveQuantity = @EffectiveQuantity - @Quantity
   return @EffectiveQuantity
END
GO

CREATE VIEW VALLWOITEMWITHCRIBBIN(PARTSCRIB,
                                  PREFERREDCRIBBIN,
                                  TASKITEMNUMBER,
                                  TASKITEMQUANTITY,
                                  EFFECTIVEQUANTITY,
                                  NEXTWODATE,
                                  INTERVAL,
                                  INTERVALTYPE,
                                  ACTIONCODE,
                                  ISSUEOPTION,
                                  OVRORDEROPTION,
                                  WONO,
                                  WODEFSCHEDULENO,
                                  ACTUALAVGLEADTIME) AS
   SELECT PARTSCRIB,
          PREFERREDCRIBBIN,
          TASKITEMNUMBER,
          TASKITEMQUANTITY,
          dbo.ADJUSTQUANTITYFORLEADTIME(TASKITEMQUANTITY,
                                        INTERVAL,
                                        INTERVALTYPE,
                                        ISNULL(OverrideAvgLeadTime,
                                               ISNULL(AvgLeadTime,
                                                      (SELECT MAX(INT)
                                                         FROM GLOBALSETTINGS
                                                        WHERE KEYNAME =
                                                                     'Purchasing_LeadTime'))),
                                        CASE
                                           WHEN WONO IS NOT NULL
                                           AND WODEFSCHEDULENO IS NOT NULL THEN 1
                                           ELSE 0
                                        END) AS EFFECTIVEQUANTITY,
          NEXTWODATE,
          INTERVAL,
          INTERVALTYPE,
          ACTIONCODE,
          ISSUEOPTION,
          OVRORDEROPTION,
          WONO,
          WODEFSCHEDULENO,
          ISNULL(OverrideAvgLeadTime,
                 ISNULL(AvgLeadTime, (SELECT MAX(INT)
                                        FROM GLOBALSETTINGS
                                       WHERE KEYNAME = 'Purchasing_LeadTime')))
                                                                     AS ActualAvgLeadTime
     FROM VALLWODEFSCHEDULEWOITEMS v1 LEFT JOIN VPREFERREDCRIBBIN v2 ON v1.taskitemnumber =
                                                                             v2.itemnumber
                                                                   AND v1.partscrib =
                                                                                   v2.CRIB LEFT JOIN STATION s ON PREFERREDCRIBBIN =
                                                                                                                    s.cribbin
GO