	Create Procedure BuildWOReservations 
As
    DECLARE @WONo int
	DECLARE @WODefScheduleNo int
	DECLARE @PartsCrib int
	DECLARE @PreferredCribBin VARCHAR(15) 
	DECLARE @TaskItemNumber VARCHAR(12)
	DECLARE @SumTaskQuantity int
	DECLARE @OvrOrderOption int
    DECLARE @get_WONeeds CURSOR 
    DECLARE @new_STATUS             int
    DECLARE @last_WONo              int
    DECLARE @last_WODefScheduleNo   int
    DECLARE @hold_ReservationNo     int
    DECLARE @hold_RUNDATE           DATETIME
	DECLARE @ReservationOrderOption int
	DECLARE @WONeedsAreAdditional int
	DECLARE @AdditionalLeadTimeDays int
	DECLARE @UserReservationNo int
	DECLARE @UserReservationType int


    -- Reservation Detail Merge Control
    DECLARE @get_Details CURSOR 
	DECLARE @ReservationDetailNo	int
	DECLARE @ReservationCrib	int
	DECLARE @ReservationItemNumber	VARCHAR(12)
	DECLARE @ReservationQuantity	int
	DECLARE @ReservationActualQuantity int
	DECLARE @RDOvrOrderOption		int
	DECLARE @nCompare				int
	DECLARE @Fetch1Status			int
	DECLARE @Fetch2Status			int
	DECLARE @ReservationChanged     int

	SELECT @ReservationOrderOption = INT FROM GLOBALSETTINGS WHERE KEYNAME = 'Purchasing_DefaultWOOrderOption'
	IF @ReservationOrderOption IS NULL 
	   SET @ReservationOrderOption = 0

	SELECT @AdditionalLeadTimeDays = INT FROM GLOBALSETTINGS WHERE KEYNAME = 'Purchasing_MoreLeadDays'
	IF @AdditionalLeadTimeDays IS NULL 
	   SET @AdditionalLeadTimeDays = 0

	-- NOTE: Must strip off milliseconds from time values
    SELECT @hold_RUNDATE =  cast( convert(varchar, GETDATE(),20) as datetime)

	-- Cursor for existing WO-based potential ordering needs
	SET @get_WONeeds  = CURSOR LOCAL FOR
	SELECT   WONo,
			 WODefScheduleNo,
			 partscrib,
			 preferredcribbin,
			 taskitemnumber,
			 SUM(effectivequantity) AS SUMTASKQUANTITY,
			 OvrOrderOption
		FROM VAllWOItemWithCribBin
	   WHERE PARTSCRIB IS NOT NULL
		 AND (NEXTWODATE < GETDATE() + ActualAvgLeadTime	+ @AdditionalLeadTimeDays
		     OR INTERVALTYPE = 5)
		 AND (ISNULL(OVRORDEROPTION, 0) IN(1, 2) OR ISSUEOPTION IN(1, 2))
	GROUP BY WONo,
			 WODefScheduleNo,
			 partscrib,
			 preferredcribbin,
			 taskitemnumber,
			 OvrOrderOption
	  HAVING SUM(effectivequantity) > 0
	ORDER BY WONo, WODefScheduleNo, TaskItemNumber, OvrOrderOption	


	OPEN @get_WONeeds
	FETCH NEXT FROM @get_WONeeds INTO @WONo, @WODefScheduleNo, @PartsCrib, @PreferredCribBin, 
		@TaskItemNumber, @SumTaskQuantity, @OvrOrderOption
	SET @Fetch1Status = @@FETCH_STATUS
	WHILE @Fetch1Status = 0
		BEGIN
         IF    @hold_ReservationNo IS NULL
            OR ISNULL(@last_WONo, 0) <> ISNULL(@WONo, 0)
            OR ISNULL(@last_WODefScheduleNo, 0) <> ISNULL(@WODefScheduleNo, 0) 
            BEGIN
               SELECT @last_WODefScheduleNo = ISNULL(@WODefScheduleNo, 0);
               SELECT @last_WONo = ISNULL(@WONo, 0);
			   SET @hold_ReservationNo = NULL
               SELECT @hold_ReservationNo = ReservationNo
                 FROM RESERVATION
                WHERE ReservationType = 2
				  AND RESERVATIONSTATUS <> 3
                  AND RESERVATIONWONO = @last_WONo
                  AND RESERVATIONWODEFSCHEDULENO = @last_WODefScheduleNo;

			   -- Don't reserve parts automatically if user has own reservation linked
			   -- to Work Order
			   IF @WONo IS NOT NULL
			      BEGIN
				  SET @UserReservationNo = NULL
				  SELECT @UserReservationNo = WO.ReservationNo, @UserReservationType = ReservationType
				     FROM WO LEFT JOIN RESERVATION ON WO.RESERVATIONNO = RESERVATION.RESERVATIONNO 
					 WHERE WONo = @WONo

				  IF @UserReservationNo IS NOT NULL AND ISNULL(@UserReservationType,0) <> 2
				     BEGIN
					 -- Don't do processing for this Work Order

					 if @hold_ReservationNo IS NOT NULL
					    BEGIN
						-- Clean up any existing records 
						DELETE FROM RESERVATIONDETAIL WHERE RESERVATIONNO = @hold_ReservationNo
						DELETE FROM RESERVATION WHERE RESERVATIONNO = @hold_ReservationNo
						END
					 END
				  ELSE
				     SET @UserReservationNo = NULL
				  END

			   IF @UserReservationNo IS NULL
				   BEGIN
				   IF @hold_ReservationNo IS NULL 
					  BEGIN
					  INSERT INTO RESERVATION
								  (DATECREATED, DATEREQUIRED,
								   RESERVATIONSTATUS, RESERVATIONTYPE,
								   RESERVATIONCOMMENTS,
								   RESERVATIONWONO, RESERVATIONWODEFSCHEDULENO,
								   RESERVEDFOREMPLOYEE, CREATEDBYEMPLOYEE,
								   APPROVEDBYEMPLOYEE, ReservationOrderOption)
						   VALUES (@hold_RUNDATE, @hold_RUNDATE,
								   1, 2,
								   'SYSTEM-GENERATED RESERVATION FOR PREDICTIVE WORK ORDER PURCHASING',
								   @last_WONo, @last_WODefScheduleNo,
								   'WORKORDER', 'SYSTEM',
								   'SYSTEM', @ReservationOrderOption);
					  SELECT @hold_ReservationNo = SCOPE_IDENTITY()
					  END
				  ELSE
   					  UPDATE RESERVATION
						  SET DATEREQUIRED = @hold_RUNDATE,
						  ReservationOrderOption=@ReservationOrderOption WHERE ReservationNo = @hold_ReservationNo;

				  -- Update WO to reference Reservation, if applicable
				  IF @last_WONo <> 0 
				     UPDATE WO SET RESERVATIONNO = @hold_ReservationNo WHERE WONo = @last_WONo
			      END
		     END

      -- If User-assigned reservation number, then just skip the rest of the needs for this Work Order
	  -- for now
      IF @UserReservationNo IS NOT NULL
		 BEGIN
		 FETCH NEXT FROM @get_WONeeds INTO @WONo, @WODefScheduleNo, @PartsCrib, @PreferredCribBin, 
			@TaskItemNumber, @SumTaskQuantity, @OvrOrderOption 
		 SET @Fetch1Status = @@FETCH_STATUS
		 CONTINUE;
		 END

	  -- Merge with the detail records
      SET @get_Details = CURSOR LOCAL FOR
         SELECT   ReservationDetailNo,
                  ReservationCrib,
                  ReservationItemNumber,
				  ISNULL(ReservationQuantity,0),
				  ISNULL(ReservationActualQuantity, 0),
				  OvrOrderOption
             FROM ReservationDetail where ReservationNo = @hold_ReservationNo
			 ORDER BY ReservationItemNumber, OvrOrderOption
	  SET @ReservationChanged = 0
	  OPEN @get_Details
	  FETCH @get_Details INTO @ReservationDetailNo, @ReservationCrib, @ReservationItemNumber,
	     @ReservationQuantity, @ReservationActualQuantity, @RDOvrOrderOption
	  SET @Fetch2Status = @@FETCH_STATUS
	  while (@ReservationChanged = 0 AND @Fetch1Status = 0) OR @Fetch2Status = 0
	     BEGIN
	  	 if @Fetch1Status <> 0 OR @ReservationChanged = 1 
		    Set @nCompare = 1
		 else if @Fetch2Status <> 0 
		    Set @nCompare = -1
		 else if @ReservationItemNumber < @TaskItemNumber 
		    Set @nCompare = 1 
		 else if @ReservationItemNumber > @TaskItemNumber
		    Set @nCompare = -1 
		 else if ISNULL(@RDOvrOrderOption, 0) < ISNULL(@OvrOrderOption, 0)
		    set @nCompare = 1
		 else if ISNULL(@RDOvrOrderOption, 0) > ISNULL(@OvrOrderOption, 0)
		    set @nCompare = -1
		 else
		    set @nCompare = 0
		   
		 -- Insert Reservation Detail Record as needed 
	     if @nCompare = -1 
			BEGIN
	         INSERT INTO RESERVATIONDETAIL
		                 (RESERVATIONNO, RESERVATIONCRIB,
			              RESERVATIONCRIBBIN, RESERVATIONITEMNUMBER,
				          RESERVATIONQUANTITY, RESERVATIONACTUALQUANTITY, OVRORDEROPTION)
				VALUES (@hold_ReservationNo, @partscrib,
					      @preferredcribbin, @taskitemnumber,
						  @SUMTASKQUANTITY, 0, @OvrOrderOption);
			END
		else if @nCompare = 1 
		    BEGIN
			DELETE FROM RESERVATIONDETAIL WHERE RESERVATIONDETAILNO = @ReservationDetailNo
			END
		else
			BEGIN
			-- Matched set of records
			IF @PartsCrib <> ISNULL(@ReservationCrib, 0) OR @SUMTASKQUANTITY <> @ReservationQuantity - @ReservationActualQuantity 
			   BEGIN
			   -- Update the record
			   UPDATE RESERVATIONDETAIL SET ReservationCrib = @PartsCrib,
					ReservationCribBin = @PreferredCribBin,
					ReservationQuantity = @ReservationActualQuantity + @SUMTASKQUANTITY
			   WHERE 
					ReservationDetailNo = @ReservationDetailNo
				END
			END
	    if @nCompare = 1 OR @nCompare = 0 
			BEGIN
			FETCH @get_Details INTO @ReservationDetailNo, @ReservationCrib, @ReservationItemNumber,
				@ReservationQuantity, @ReservationActualQuantity, @RDOvrOrderOption
				SET @Fetch2Status = @@FETCH_STATUS
			END
	    if @nCompare = -1 OR @nCompare = 0 
			BEGIN
			FETCH NEXT FROM @get_WONeeds INTO @WONo, @WODefScheduleNo, @PartsCrib, @PreferredCribBin, 
				@TaskItemNumber, @SumTaskQuantity, @OvrOrderOption 
			SET @Fetch1Status = @@FETCH_STATUS
        	IF    @Fetch1Status = 0 AND
				(ISNULL(@last_WONo, 0) <> ISNULL(@WONo, 0)
				OR ISNULL(@last_WODefScheduleNo, 0) <> ISNULL(@WODefScheduleNo, 0))
				SET @ReservationChanged = 1
			END
		END
		DEALLOCATE @get_Details
      END

      -- Purge anything that wasn't updated
      DELETE FROM RESERVATION
            WHERE RESERVATIONTYPE = 2  
			AND RESERVATIONSTATUS <> 3 AND 
			DATEREQUIRED < @hold_RUNDATE;

      DELETE FROM RESERVATIONDETAIL
            WHERE NOT EXISTS(
                         SELECT *
                           FROM RESERVATION
                          WHERE RESERVATION.RESERVATIONNO =
                                                           RESERVATIONDETAIL.RESERVATIONNO);

	  UPDATE WO SET RESERVATIONNO = NULL WHERE RESERVATIONNO IS NOT NULL AND NOT EXISTS
	     (SELECT * FROM RESERVATION WHERE RESERVATION.RESERVATIONNO = WO.RESERVATIONNO)
	return (0)