IF OBJECT_ID('GenerateDashboardSummaries') IS NOT NULL
DROP PROCEDURE [dbo].[GenerateDashboardSummaries]
GO

CREATE PROCEDURE GenerateDashboardSummaries
AS
BEGIN
TRUNCATE TABLE XTransDay
INSERT INTO XTransDay
SELECT            DATEADD(dd, DATEDIFF(dd, 0, TRANS.Transdate), 0) AS TransMonth,
                  SiteID,
                  TRANS.Item,
                  Max(Description1) AS 'Item Description',
                  TypeDescription,
                  ItemClass,
                  INVENTRY.ItemType,
                  ItemTypeDesc,
                  SUM(ISNULL(Cost,0)) AS 'Sum Cost',
                  SUM(ISNULL(TRANS.Quantity,0)) AS 'Sum Qty',
                  COUNT(distinct TRANS.Item) as 'Distinct Item Count',
                  COUNT(TRANS.item) AS 'Item Count',
                  STATION.Consignment,
                  TRANS.Crib,
		  TRANS.User1,
		  TRANS.User2,
		  TRANS.User3,
		  TRANS.User4,
		  TRANS.User5,
		  TRANS.User6
FROM        TRANS (nolock)
INNER JOIN  INVENTRY (nolock) ON TRANS.Item = INVENTRY.ItemNumber
INNER JOIN	ItemType (nolock) ON INVENTRY.ItemType = ItemType.ItemType
INNER JOIN  Crib (nolock) ON TRANS.Crib = Crib.Crib 
INNER JOIN	STATION (nolock) ON STATION.Cribbin = TRANS.cribbin
WHERE		UsageType = 1
GROUP BY    DATEADD(dd, DATEDIFF(dd, 0, TRANS.Transdate), 0), SiteID, TRANS.Item, ItemClass, INVENTRY.ItemType, ItemTypeDesc, TypeDescription, STATION.Consignment, TRANS.Crib,
		  TRANS.User1, TRANS.User2, TRANS.User3, TRANS.User4, TRANS.User5, TRANS.User6

TRUNCATE TABLE XTransMonth
INSERT INTO XTransMonth
SELECT            DATEADD(m, DATEDIFF(m, 0, Transdate), 0) AS TransMonth,
                  SiteID,
                  Item,
                  Max(Description1) AS 'Item Description',
                  TypeDescription,
                  ItemClass,
                  ItemType,
                  ItemTypeDesc,
                  SUM(ISNULL(CostSum,0)) AS 'Sum Cost',
                  SUM(ISNULL(QtySum,0)) AS 'Sum Qty',
                  SUM(DistinctItemCount),
                  SUM(ItemCount),
                  Consignment,
                  Crib,
		  User1,
		  User2,
		  User3,
		  User4,
		  User5,
		  User6
FROM        XTransDay
GROUP BY    DATEADD(m, DATEDIFF(m, 0, Transdate), 0), SiteID, Item, ItemClass, ItemType, ItemTypeDesc, TypeDescription, Consignment, Crib,
		  User1, User2, User3, User4, User5, User6

TRUNCATE TABLE XEmployeeDay
INSERT INTO XEmployeeDay
SELECT            DATEADD(dd, DATEDIFF(dd, 0, TRANS.Transdate), 0) AS TransMonth,
                  SiteID,
                  EMPLOYEE.ID,
                  Max(EMPLOYEE.Name),
                  ItemNumber,
                  Max(Description1) AS 'Item Description',
                  TypeDescription,
                  ItemClass,
                  INVENTRY.ItemType,
                  ItemTypeDesc,
                  SUM(ISNULL(Cost,0)) AS 'Sum Cost',
                  SUM(ISNULL(TRANS.Quantity,0)) AS 'Sum Qty',
                  COUNT(distinct TRANS.Item) as 'Distinct Item Count',
                  COUNT(TRANS.item) AS 'Item Count',
                  STATION.Consignment,
                  TRANS.Crib,
		  TRANS.User1,
		  TRANS.User2,
		  TRANS.User3,
		  TRANS.User4,
		  TRANS.User5,
		  TRANS.User6
FROM        TRANS (nolock)
INNER JOIN  INVENTRY (nolock) ON TRANS.Item = INVENTRY.ItemNumber
INNER JOIN	EMPLOYEE (nolock) ON TRANS.employee = EMPLOYEE.ID
INNER JOIN	ItemType (nolock) ON INVENTRY.ItemType = ItemType.ItemType
INNER JOIN  Crib (nolock) ON TRANS.Crib = Crib.Crib 
INNER JOIN	STATION (nolock) ON STATION.Cribbin = TRANS.cribbin
WHERE UsageType = 1
GROUP BY    DATEADD(dd, DATEDIFF(dd, 0, TRANS.Transdate), 0), SiteID, EMPLOYEE.ID, ItemNumber, TRANS.Item, ItemClass, INVENTRY.ItemType, ItemTypeDesc, TypeDescription, STATION.Consignment, TRANS.Crib,
		  TRANS.User1, TRANS.User2, TRANS.User3, TRANS.User4, TRANS.User5, TRANS.User6

TRUNCATE TABLE XEmployeeMonth
INSERT INTO XEmployeeMonth
SELECT            DATEADD(m, DATEDIFF(m, 0, Transdate), 0) AS TransMonth,
                  SiteID,
                  EmployeeID,
                  Max(EmployeeName),
                  Item,
                  Max(Description1) AS 'Item Description',
                  TypeDescription,
                  ItemClass,
                  ItemType,
                  ItemTypeDesc,
                  SUM(ISNULL(CostSum,0)),
                  SUM(ISNULL(QtySum,0)),
                  SUM(DistinctItemCount),
                  SUM(ItemCount),
                  Consignment,
                  Crib,
		  User1,
		  User2,
		  User3,
		  User4,
		  User5,
		  User6
FROM        XEmployeeDay (nolock)
GROUP BY    DATEADD(m, DATEDIFF(m, 0, Transdate), 0), SiteID, EmployeeID, EmployeeName, Item, ItemClass, ItemType, ItemTypeDesc, TypeDescription, Consignment, Crib,
		  User1, User2, User3, User4, User5, User6

TRUNCATE TABLE XUDFDay
-- User1
INSERT INTO XUDFDay
SELECT            DATEADD(dd, DATEDIFF(dd, 0, TRANS.Transdate), 0) AS TransMonth,
                  SiteID,
                  'User1',
                  TRANS.User1,
                  ItemNumber,
                  Max(Description1) AS 'Item Description',
                  TypeDescription,
                  ItemClass,
                  INVENTRY.ItemType,
                  ItemTypeDesc,
                  SUM(ISNULL(Cost,0)) AS 'Sum Cost',
                  SUM(ISNULL(TRANS.Quantity,0)) AS 'Sum Qty',
                  COUNT(distinct TRANS.Item) as 'Distinct Item Count',
                  COUNT(TRANS.item) AS 'Item Count',
                  STATION.Consignment,
                  TRANS.Crib
FROM        TRANS (nolock)
INNER JOIN  INVENTRY (nolock) ON TRANS.Item = INVENTRY.ItemNumber
INNER JOIN	EMPLOYEE (nolock) ON TRANS.employee = EMPLOYEE.ID
INNER JOIN	ItemType (nolock) ON INVENTRY.ItemType = ItemType.ItemType
INNER JOIN  Crib (nolock) ON TRANS.Crib = Crib.Crib 
INNER JOIN	STATION (nolock) ON STATION.Cribbin = TRANS.cribbin
WHERE UsageType = 1
GROUP BY    DATEADD(dd, DATEDIFF(dd, 0, TRANS.Transdate), 0), SiteID, TRANS.User1, ItemNumber, TRANS.Item, ItemClass, INVENTRY.ItemType, ItemTypeDesc, TypeDescription, STATION.Consignment, TRANS.Crib

-- User2
INSERT INTO XUDFDay
SELECT            DATEADD(dd, DATEDIFF(dd, 0, TRANS.Transdate), 0) AS TransMonth,
                  SiteID,
                  'User2',
                  TRANS.User2,
                  ItemNumber,
                  Max(Description1) AS 'Item Description',
                  TypeDescription,
                  ItemClass,
                  INVENTRY.ItemType,
                  ItemTypeDesc,
                  SUM(ISNULL(Cost,0)) AS 'Sum Cost',
                  SUM(ISNULL(TRANS.Quantity,0)) AS 'Sum Qty',
                  COUNT(distinct TRANS.Item) as 'Distinct Item Count',
                  COUNT(TRANS.item) AS 'Item Count',
                  STATION.Consignment,
                  TRANS.Crib
FROM        TRANS (nolock)
INNER JOIN  INVENTRY (nolock) ON TRANS.Item = INVENTRY.ItemNumber
INNER JOIN	EMPLOYEE (nolock) ON TRANS.employee = EMPLOYEE.ID
INNER JOIN	ItemType (nolock) ON INVENTRY.ItemType = ItemType.ItemType
INNER JOIN  Crib (nolock) ON TRANS.Crib = Crib.Crib 
INNER JOIN	STATION (nolock) ON STATION.Cribbin = TRANS.cribbin
WHERE UsageType = 1
GROUP BY    DATEADD(dd, DATEDIFF(dd, 0, TRANS.Transdate), 0), SiteID, TRANS.User2, ItemNumber, TRANS.Item, ItemClass, INVENTRY.ItemType, ItemTypeDesc, TypeDescription, STATION.Consignment, TRANS.Crib

-- User3
INSERT INTO XUDFDay
SELECT            DATEADD(dd, DATEDIFF(dd, 0, TRANS.Transdate), 0) AS TransMonth,
                  SiteID,
                  'User3',
                  TRANS.User3,
                  ItemNumber,
                  Max(Description1) AS 'Item Description',
                  TypeDescription,
                  ItemClass,
                  INVENTRY.ItemType,
                  ItemTypeDesc,
                  SUM(ISNULL(Cost,0)) AS 'Sum Cost',
                  SUM(ISNULL(TRANS.Quantity,0)) AS 'Sum Qty',
                  COUNT(distinct TRANS.Item) as 'Distinct Item Count',
                  COUNT(TRANS.item) AS 'Item Count',
                  STATION.Consignment,
                  TRANS.Crib
FROM        TRANS (nolock)
INNER JOIN  INVENTRY (nolock) ON TRANS.Item = INVENTRY.ItemNumber
INNER JOIN	EMPLOYEE (nolock) ON TRANS.employee = EMPLOYEE.ID
INNER JOIN	ItemType (nolock) ON INVENTRY.ItemType = ItemType.ItemType
INNER JOIN  Crib (nolock) ON TRANS.Crib = Crib.Crib 
INNER JOIN	STATION (nolock) ON STATION.Cribbin = TRANS.cribbin
WHERE UsageType = 1
GROUP BY    DATEADD(dd, DATEDIFF(dd, 0, TRANS.Transdate), 0), SiteID, TRANS.User3, ItemNumber, Description1, TRANS.Item, ItemClass, INVENTRY.ItemType, ItemTypeDesc, TypeDescription, STATION.Consignment, TRANS.Crib

-- User4
INSERT INTO XUDFDay
SELECT            DATEADD(dd, DATEDIFF(dd, 0, TRANS.Transdate), 0) AS TransMonth,
                  SiteID,
                  'User4',
                  TRANS.User4,
                  ItemNumber,
                  Max(Description1) AS 'Item Description',
                  TypeDescription,
                  ItemClass,
                  INVENTRY.ItemType,
                  ItemTypeDesc,
                  SUM(ISNULL(Cost,0)) AS 'Sum Cost',
                  SUM(ISNULL(TRANS.Quantity,0)) AS 'Sum Qty',
                  COUNT(distinct TRANS.Item) as 'Distinct Item Count',
                  COUNT(TRANS.item) AS 'Item Count',
                  STATION.Consignment,
                  TRANS.Crib
FROM        TRANS (nolock)
INNER JOIN  INVENTRY (nolock) ON TRANS.Item = INVENTRY.ItemNumber
INNER JOIN	EMPLOYEE (nolock) ON TRANS.employee = EMPLOYEE.ID
INNER JOIN	ItemType (nolock) ON INVENTRY.ItemType = ItemType.ItemType
INNER JOIN  Crib (nolock) ON TRANS.Crib = Crib.Crib 
INNER JOIN	STATION (nolock) ON STATION.Cribbin = TRANS.cribbin
WHERE UsageType = 1
GROUP BY    DATEADD(dd, DATEDIFF(dd, 0, TRANS.Transdate), 0), SiteID, TRANS.User4, ItemNumber, Description1, TRANS.Item, ItemClass, INVENTRY.ItemType, ItemTypeDesc, TypeDescription, STATION.Consignment, TRANS.Crib

-- User5
INSERT INTO XUDFDay
SELECT            DATEADD(dd, DATEDIFF(dd, 0, TRANS.Transdate), 0) AS TransMonth,
                  SiteID,
                  'User5',
                  TRANS.User5,
                  ItemNumber,
                  Max(Description1) AS 'Item Description',
                  TypeDescription,
                  ItemClass,
                  INVENTRY.ItemType,
                  ItemTypeDesc,
                  SUM(ISNULL(Cost,0)) AS 'Sum Cost',
                  SUM(ISNULL(TRANS.Quantity,0)) AS 'Sum Qty',
                  COUNT(distinct TRANS.Item) as 'Distinct Item Count',
                  COUNT(TRANS.item) AS 'Item Count',
                  STATION.Consignment,
                  TRANS.Crib
FROM        TRANS (nolock)
INNER JOIN  INVENTRY (nolock) ON TRANS.Item = INVENTRY.ItemNumber
INNER JOIN	EMPLOYEE (nolock) ON TRANS.employee = EMPLOYEE.ID
INNER JOIN	ItemType (nolock) ON INVENTRY.ItemType = ItemType.ItemType
INNER JOIN  Crib (nolock) ON TRANS.Crib = Crib.Crib 
INNER JOIN	STATION (nolock) ON STATION.Cribbin = TRANS.cribbin
WHERE UsageType = 1
GROUP BY    DATEADD(dd, DATEDIFF(dd, 0, TRANS.Transdate), 0), SiteID, TRANS.User5, ItemNumber, Description1, TRANS.Item, ItemClass, INVENTRY.ItemType, ItemTypeDesc, TypeDescription, STATION.Consignment, TRANS.Crib

-- User6
INSERT INTO XUDFDay
SELECT            DATEADD(dd, DATEDIFF(dd, 0, TRANS.Transdate), 0) AS TransMonth,
                  SiteID,
                  'User6',
                  TRANS.User6,
                  ItemNumber,
                  Max(Description1) AS 'Item Description',
                  TypeDescription,
                  ItemClass,
                  INVENTRY.ItemType,
                  ItemTypeDesc,
                  SUM(ISNULL(Cost,0)) AS 'Sum Cost',
                  SUM(ISNULL(TRANS.Quantity,0)) AS 'Sum Qty',
                  COUNT(distinct TRANS.Item) as 'Distinct Item Count',
                  COUNT(TRANS.item) AS 'Item Count',
                  STATION.Consignment,
                  TRANS.Crib
FROM        TRANS (nolock)
INNER JOIN  INVENTRY (nolock) ON TRANS.Item = INVENTRY.ItemNumber
INNER JOIN	EMPLOYEE (nolock) ON TRANS.employee = EMPLOYEE.ID
INNER JOIN	ItemType (nolock) ON INVENTRY.ItemType = ItemType.ItemType
INNER JOIN  Crib (nolock) ON TRANS.Crib = Crib.Crib 
INNER JOIN	STATION (nolock) ON STATION.Cribbin = TRANS.cribbin
WHERE UsageType = 1
GROUP BY    DATEADD(dd, DATEDIFF(dd, 0, TRANS.Transdate), 0), SiteID, TRANS.User6, ItemNumber, TRANS.Item, Description1, ItemClass, INVENTRY.ItemType, ItemTypeDesc, TypeDescription, STATION.Consignment, TRANS.Crib

TRUNCATE TABLE XUDFMonth
INSERT INTO XUDFMonth
SELECT            DATEADD(m, DATEDIFF(m, 0, Transdate), 0) AS TransMonth,
                  SiteID,
                  UserField,
                  UDFValue,
                  Item,
                  Description1,
                  TypeDescription,
                  ItemClass,
                  ItemType,
                  ItemTypeDesc,
                  SUM(ISNULL(CostSum,0)),
                  SUM(ISNULL(QtySum,0)),
                  SUM(DistinctItemCount),
                  SUM(ItemCount),
                  Consignment,
                  Crib
FROM        XUDFDay (nolock)
GROUP BY    DATEADD(m, DATEDIFF(m, 0, Transdate), 0), 
			SiteID,
			UserField, 
			UDFValue,
			Item, 
			Description1,
			ItemClass, 
			ItemType, 
			ItemTypeDesc, 
			TypeDescription, 
			Consignment, Crib
END