IF OBJECT_ID('GenerateDashboardSummaries') IS NOT NULL
DROP PROCEDURE [dbo].[GenerateDashboardSummaries]
GO

CREATE PROCEDURE GenerateDashboardSummaries
AS
BEGIN

-- Compute start date from number of months in stored option
DECLARE @StartDate date
DECLARE @DashboardMonths int
SELECT @DashboardMonths = INT FROM GLOBALSETTINGS WHERE KEYNAME = 'Options_MonthsToProcessUsageForDashboard'
IF @DashboardMonths IS NULL 
   SET @DashboardMonths = 24
SELECT @StartDate = DATEADD(m, -@DashboardMonths, GETDATE())

TRUNCATE TABLE XTransDay
INSERT INTO XTransDay
SELECT	DATEADD(dd, DATEDIFF(dd, 0, TRANS.Transdate), 0) AS TransMonth,
		SiteID,
		TRANS.Item,
		Max(Description1) AS 'Item Description',
		TypeDescription,
		ItemClass,
		INVENTRY.ItemType,
		ItemTypeDesc,
		SUM(ISNULL(Cost,0)) AS 'Sum Cost',
		SUM(ISNULL(TRANS.Quantity,0)) AS 'Sum Qty',
		COUNT(distinct TRANS.Item) as 'Distinct Item Count',
		COUNT(TRANS.item) AS 'Item Count',
		STATION.Consignment,
		TRANS.Crib,
		TRANS.User1,
		TRANS.User2,
		TRANS.User3,
		TRANS.User4,
		TRANS.User5,
		TRANS.User6
FROM        TRANS (nolock)
INNER JOIN  INVENTRY (nolock) ON TRANS.Item = INVENTRY.ItemNumber
INNER JOIN	ItemType (nolock) ON INVENTRY.ItemType = ItemType.ItemType
INNER JOIN  Crib (nolock) ON TRANS.Crib = Crib.Crib 
INNER JOIN	STATION (nolock) ON STATION.Cribbin = TRANS.cribbin
WHERE		UsageType = 1 AND TRANS.Transdate > @StartDate
GROUP BY    DATEADD(dd, DATEDIFF(dd, 0, TRANS.Transdate), 0), SiteID, TRANS.Item, ItemClass, INVENTRY.ItemType, ItemTypeDesc, TypeDescription, STATION.Consignment, TRANS.Crib,
		  TRANS.User1, TRANS.User2, TRANS.User3, TRANS.User4, TRANS.User5, TRANS.User6

TRUNCATE TABLE XEmployeeDay
INSERT INTO XEmployeeDay
SELECT	DATEADD(dd, DATEDIFF(dd, 0, TRANS.Transdate), 0) AS TransMonth,
		SiteID,
		EMPLOYEE.ID,
		Max(EMPLOYEE.Name),
		ItemNumber,
		Max(Description1) AS 'Item Description',
		TypeDescription,
		ItemClass,
		INVENTRY.ItemType,
		ItemTypeDesc,
		SUM(ISNULL(Cost,0)) AS 'Sum Cost',
		SUM(ISNULL(TRANS.Quantity,0)) AS 'Sum Qty',
		COUNT(distinct TRANS.Item) as 'Distinct Item Count',
		COUNT(TRANS.item) AS 'Item Count',
		STATION.Consignment,
		TRANS.Crib,
		TRANS.User1,
		TRANS.User2,
		TRANS.User3,
		TRANS.User4,
		TRANS.User5,
		TRANS.User6
FROM        TRANS (nolock)
INNER JOIN  INVENTRY (nolock) ON TRANS.Item = INVENTRY.ItemNumber
INNER JOIN	EMPLOYEE (nolock) ON TRANS.employee = EMPLOYEE.ID
INNER JOIN	ItemType (nolock) ON INVENTRY.ItemType = ItemType.ItemType
INNER JOIN  Crib (nolock) ON TRANS.Crib = Crib.Crib 
INNER JOIN	STATION (nolock) ON STATION.Cribbin = TRANS.cribbin
WHERE UsageType = 1 AND TRANS.Transdate > @StartDate 
GROUP BY    DATEADD(dd, DATEDIFF(dd, 0, TRANS.Transdate), 0), SiteID, EMPLOYEE.ID, ItemNumber, TRANS.Item, ItemClass, INVENTRY.ItemType, ItemTypeDesc, TypeDescription, STATION.Consignment, TRANS.Crib,
		  TRANS.User1, TRANS.User2, TRANS.User3, TRANS.User4, TRANS.User5, TRANS.User6

-- Record last date tables updated so status can be monitored
IF EXISTS (SELECT * FROM GLOBALSETTINGS WHERE KEYNAME = 'Dashboards_LastSummaryDate')
	UPDATE GLOBALSETTINGS SET STRING = convert(varchar, GETDATE(),120) WHERE KEYNAME ='Dashboards_LastSummaryDate'
ELSE
	INSERT INTO GLOBALSETTINGS (KEYNAME, STRING) VALUES ('Dashboards_LastSummaryDate', convert(varchar, GETDATE(),120))

END