create proc sp_removeindexes
	@TableName varchar(255),		-- the table to check for indexes
	@bPrintOnly int=0

as
	-- Remove primary key constraint and all indexes from the specified table. Code to enumerate 
	-- index names borrowed from sp_helpindex system procedure. 

	-- @bPrintOnly can be used to print the commands, but may display an extra command to drop
	-- the primary key index since it is not actually removed by the print statement
	
	-- PRELIM
	set nocount on
	set xact_abort on

	declare @objid int,			-- the object id of the table
			@indid smallint,	-- the index id of an index
			@indname sysname,
			@status int,
			@dbname	sysname,
			@keyconstraintname sysname

	DECLARE @SQLCommand VARCHAR(500)

	-- Check to see that the object names are local to the current database.
	select @dbname = parsename(@TableName,3)

	if @dbname is not null and @dbname <> db_name()
	begin
			raiserror(15250,-1,-1)
			return (1)
	end

	-- Check to see the the table exists and initialize @objid.
	select @objid = object_id(@TableName)
	if @objid is NULL
	begin
		select @dbname=db_name()
		raiserror(15009,-1,-1,@TableName,@dbname)
		return (1)
	end

	-- Retrieve the primary key constraint name
	select @keyconstraintname = constraint_name from information_schema.table_constraints 
		where table_name = @TableName

	BEGIN TRAN -- Not a bad idea...

	-- Drop the primary key constraint if one was found. This also drops the corresponding index
	if @keyconstraintname is not null
		begin

		-- Generate drop constraint command
		SET @SQLCommand = 'ALTER TABLE ' + @TableName + ' DROP CONSTRAINT ' +  @keyconstraintname

		-- Print or execute
		if @bPrintOnly=1
			BEGIN
			PRINT (@SQLCommand) 
			PRINT 'GO'
			END
		ELSE
			EXEC (@SQLCommand)
		end

	-- OPEN CURSOR OVER INDEXES 
	declare ms_crs_ind cursor local static for
		select indid, name, status from sysindexes
			where id = @objid and indid > 0 and indid < 255 and (status & 64)=0 order by indid
	open ms_crs_ind
	fetch ms_crs_ind into @indid, @indname, @status

	-- IF NO INDEX, QUIT
	if @@fetch_status < 0
	begin
		deallocate ms_crs_ind
		COMMIT TRAN
		return (0)
	end

	while @@fetch_status >= 0
	begin
		-- Generate drop index command
		SET @SQLCommand = 'DROP INDEX ' + @TableName + '.' + @IndName 

		-- Print or execute
		if @bPrintOnly=1
			BEGIN
			PRINT (@SQLCommand) 
			PRINT 'GO'
			END
		ELSE
			EXEC (@SQLCommand)

		-- Next index
		fetch ms_crs_ind into @indid, @indname, @status
	end
	deallocate ms_crs_ind


	COMMIT TRAN -- Commit the changes

	return (0) -- sp_removeindexes

