-- Adding New Column to INVENTRY table
IF NOT EXISTS (
  SELECT
    *
  FROM
    INFORMATION_SCHEMA.COLUMNS
  WHERE
    TABLE_NAME = 'INVENTRY' AND COLUMN_NAME = 'AccessCodeEx')
BEGIN
  ALTER TABLE INVENTRY
    ADD AccessCodeEx VARCHAR(6) NULL
END;

GO

-- Now transfer AccessCodeEx value from AccessCode into AccessCodeEx
UPDATE INVENTRY
SET AccessCodeEx = AccessCode;

GO


-- Trancate table if it existed before and it's populated
TRUNCATE TABLE ACCESSCODEEX;

GO

-- Copy All existing Access Codes to New table
INSERT INTO ACCESSCODEEX(ACCESSCODEEX, ACCESSCODEEXDESCRIPTION)
SELECT ACCESSCODE, ACCESSCODEDESCRIPTION FROM ACCESSCODE;

GO

--------------------------------------------------------------------------------------------------
-- This section converts AcessCode into AcessCodeEx in comma separated format
-- BEGIN

IF EXISTS (SELECT * FROM sysobjects WHERE name = 'ConvertAccessCode' AND xtype IN ('FN', 'IF', 'TF'))
	DROP FUNCTION dbo.ConvertAccessCode;

GO

-- Create the function that does conversion into new comma separated format
CREATE FUNCTION dbo.ConvertAccessCode (@CODE VARCHAR(100))
RETURNS VARCHAR(255)
WITH EXECUTE AS CALLER
AS
BEGIN
	DECLARE 	
	@AccCodeLength INT -- holds length of the AccessCode
	,@Counter INT		-- holds number of iterations
	,@AccCode VARCHAR(255);

	SELECT	@AccCodeLength = LEN(@CODE)
			,@Counter = @AccCodeLength
			,@AccCode = @CODE;

	WHILE @Counter >= 1
	BEGIN

		IF @Counter % 1 = 0 AND @Counter <= @AccCodeLength
		BEGIN
			SET @AccCode = STUFF(@AccCode, @Counter, 0, ',') -- insert comma before each characther
		END

		SET @Counter = @Counter - 1
	END;

	IF LEN(@AccCode) > 0 
	BEGIN 
		SET @AccCode = @AccCode + ',' -- Always end value with comma (if it has value of course)
	END;

	RETURN(@AccCode);
END;

GO

-- Adding New Column to EMPLOYEE table
IF NOT EXISTS (
  SELECT
    *
  FROM
    INFORMATION_SCHEMA.COLUMNS
  WHERE
    TABLE_NAME = 'EMPLOYEE' AND COLUMN_NAME = 'AccessCodeEx')
BEGIN
  ALTER TABLE EMPLOYEE
    ADD AccessCodeEx VARCHAR(MAX) NULL
END;

GO

-- Clean AccessCodeEx value just in case it was there before
UPDATE EMPLOYEE
SET AccessCodeEx = NULL;

GO

-- Do Convert AccessCode into AccessCodeEx in comma separated format 
Update EMPLOYEE
SET AccessCodeEx = dbo.ConvertAccessCode (AccessCode);

GO

-- We don't need the function any longer
DROP FUNCTION dbo.ConvertAccessCode;

-- END
-- This section converted AcessCode into AcessCodeEx in comma separated format
--------------------------------------------------------------------------------------------------
