-- Adding New Column to INVENTRY table
IF NOT EXISTS (
  SELECT
    *
  FROM
    INFORMATION_SCHEMA.COLUMNS
  WHERE
    TABLE_NAME = 'INVENTRY' AND COLUMN_NAME = 'AccessCodeEx')
BEGIN
  ALTER TABLE INVENTRY
    ADD AccessCodeEx VARCHAR(6) NULL
END;

GO

-- Create New Table
IF OBJECT_ID('ACCESSCODEEX') IS NULL
CREATE TABLE ACCESSCODEEX
(
	AccessCodeEx VARCHAR(6) not null
	,AccessCodeExDescription VARCHAR(50) null
	,CONSTRAINT PK PRIMARY KEY (AccessCodeEx)
);

GO

-- Adding New Column to EMPLOYEE table
IF NOT EXISTS (
  SELECT
    *
  FROM
    INFORMATION_SCHEMA.COLUMNS
  WHERE
    TABLE_NAME = 'EMPLOYEE' AND COLUMN_NAME = 'AccessCodeEx')
BEGIN
  ALTER TABLE EMPLOYEE
    ADD AccessCodeEx VARCHAR(MAX) NULL
END;

GO

-- Modify [dbo].[VCribRelatedItemSummary] view
--SET ANSI_NULLS ON
--GO

--SET QUOTED_IDENTIFIER ON
--GO

ALTER VIEW [dbo].[VCribRelatedItemSummary] AS
   SELECT INVENTRY.Description1,
          INVENTRY.Description2,
          INVENTRY.Price,
          INVENTRY.VendorNumber,
          INVENTRY.ACCESSCODE,
		  INVENTRY.ACCESSCODEEX,
          INVENTRY.ITEMTYPE,
          INVENTRY.ITEMCLASS,
          INVENTRY.ReworkedItemNumber,
          INVENTRY.UPCCode,
          INVENTRY.Comments,
          INVENTRY.PRICETYPE,
          INVENTRY.Manufacturer,
          INVENTRY.MfrNumber,
          INVENTRY.DefaultQty,
          INVENTRY.RESTRICTED,
          INVENTRY.ItemStatusCode,
          INVENTRY.TrackLotNumber,
          INVENTRY.CINo,
          INVENTRY.ClassNo,
          INVENTRY.CIRevision,
          INVENTRY.CINumber,
          INVENTRY.ItemFODControl,
          INVENTRY.AltVendorNo,
          INVENTRY.RequiresInspection,
          INVENTRY.InactiveItem,
          INVENTRY.IssueUnitOfMeasure,
          ITEMRELATIONSHIP.ItemRelationshipId,
          ITEMRELATIONSHIP.RelatedItemNumber,
          ITEMRELATIONSHIP.ItemNumber,
          ITEMRELATIONSHIP.RelatedQuantity,
          VCribItemSummary.CRIB,
          VCribItemSummary.NAME,
          VCribItemSummary.SumBinQuantity,
          VCribItemSummary.SumQuantity,
          VCribItemSummary.SumMonthlyUsage,
          VCribItemSummary.SumOnOrder,
          VCribItemSummary.EnableSiteTransfers,
          ITEMRELATIONSHIP.RelationshipTypeId,
          ITEMRELATIONSHIP.RelationshipCode,
          ITEMRELATIONSHIP.SpecialInstructions,
          RELATIONSHIPTYPE.RelationshipTypeName,
          RELATIONSHIPTYPE.Predefined,
          RELATIONSHIPTYPE.UsageType,
          ITEMRELATIONSHIP.Precedence
     FROM ((INVENTRY INNER JOIN ITEMRELATIONSHIP ON INVENTRY.ItemNumber = ITEMRELATIONSHIP.RelatedItemNumber)
		INNER JOIN VCribItemSummary ON ITEMRELATIONSHIP.RelatedItemNumber =	VCribItemSummary.Item)
		INNER JOIN RELATIONSHIPTYPE ON ITEMRELATIONSHIP.RelationshipTypeId = RELATIONSHIPTYPE.RelationshipTypeId

GO

-- Modify [dbo].[VItemWithRelatedCribBin] view
ALTER VIEW [dbo].[VItemWithRelatedCribBin] AS
   SELECT INVENTRY.Description1,
          INVENTRY.Description2,
          INVENTRY.Price,
          INVENTRY.ACCESSCODE,
		  INVENTRY.ACCESSCODEEX,
          INVENTRY.VendorNumber,
          INVENTRY.ITEMTYPE,
          INVENTRY.ITEMCLASS,
          INVENTRY.ReworkedItemNumber,
          INVENTRY.UPCCode,
          INVENTRY.Comments,
          INVENTRY.Serialized,
          INVENTRY.PRICETYPE,
          INVENTRY.Manufacturer,
          INVENTRY.MfrNumber,
          INVENTRY.DefaultQty,
          INVENTRY.RESTRICTED,
          INVENTRY.ItemStatusCode,
          INVENTRY.TrackLotNumber,
          INVENTRY.CINo,
          INVENTRY.ClassNo,
          INVENTRY.CIRevision,
          INVENTRY.CINumber,
          INVENTRY.UseCheckList,
          INVENTRY.ItemFODControl,
          INVENTRY.AltVendorNo,
          INVENTRY.RequiresInspection,
          INVENTRY.InactiveItem,
          INVENTRY.IssueUnitOfMeasure,
          ITEMRELATIONSHIP.ItemRelationshipId,
          ITEMRELATIONSHIP.RelatedItemNumber,
          ITEMRELATIONSHIP.RelatedQuantity,
          ITEMRELATIONSHIP.Precedence,
          ITEMRELATIONSHIP.RelationshipCode,
          ITEMRELATIONSHIP.Comments AS RelationshipComment,
          ITEMRELATIONSHIP.SpecialInstructions,
          ITEMRELATIONSHIP.RelationshipWODefNo,
          RELATIONSHIPTYPE.RelationshipTypeId,
          RELATIONSHIPTYPE.RelationshipTypeName,
          RELATIONSHIPTYPE.Predefined,
          RELATIONSHIPTYPE.UsageType,
          STATION.CribBin,
          STATION.CRIB,
          STATION.BinQuantity,
          STATION.Quantity,
          STATION.OnOrder,
          STATION.Comments AS BinComments,
          STATION.StopOrdering,
          STATION.BinCapacity,
          STATION.PendingRework,
          ITEMRELATIONSHIP.ItemNumber
     FROM INVENTRY
	 INNER JOIN ITEMRELATIONSHIP ON INVENTRY.ItemNumber = ITEMRELATIONSHIP.RelatedItemNumber
	 INNER JOIN RELATIONSHIPTYPE ON ITEMRELATIONSHIP.RelationshipTypeId = RELATIONSHIPTYPE.RelationshipTypeId
	 INNER JOIN STATION ON ITEMRELATIONSHIP.RelatedItemNumber = STATION.Item

GO

