--------------- INVENTORY HEALTH Crib Centric TRENDS -------------
IF OBJECT_ID('sp_GenerateCribCentricInventoryHealthTrends') IS NOT NULL
DROP PROCEDURE [dbo].sp_GenerateCribCentricInventoryHealthTrends
GO

CREATE PROCEDURE sp_GenerateCribCentricInventoryHealthTrends
AS
BEGIN

DECLARE @DeadStockNotIssuedOffset int
DECLARE @CurrentDate date
DECLARE @StartDate date
DECLARE @OvstCriteria int
DECLARE @KeepDayHistoryDays int
DECLARE @KeepDayHistoryMonths int

SELECT @DeadStockNotIssuedOffset = INT FROM GLOBALSETTINGS WHERE KEYNAME = 'Dashboard_DeadStockNotIssuedOffset'
IF @DeadStockNotIssuedOffset IS NULL
   SET @DeadStockNotIssuedOffset = 90
SELECT @StartDate = DATEADD(d, -@DeadStockNotIssuedOffset, GETDATE());

SELECT @OvstCriteria = INT FROM GLOBALSETTINGS WHERE KEYNAME = 'Dashboard_OverstockCriteria'
IF @OvstCriteria IS NULL
   SET @OvstCriteria = 0

SELECT @KeepDayHistoryDays = INT FROM GLOBALSETTINGS WHERE KEYNAME = 'Dashboard_KeepHistInvConcernsDays'
IF @KeepDayHistoryDays IS NULL
   SET @KeepDayHistoryDays = 31

SELECT @KeepDayHistoryMonths = INT FROM GLOBALSETTINGS WHERE KEYNAME = 'Dashboard_KeepHistInvConcernsMonths'
IF @KeepDayHistoryMonths IS NULL
   SET @KeepDayHistoryMonths = 12

-- If table doesn't exist, create one
IF OBJECT_ID('XInvHealthCribCentricDay') IS NULL
CREATE TABLE XInvHealthCribCentricDay(
	SiteID varchar(12) NOT NULL,
	[Site Description] varchar(50),
	ParentSiteID varchar(12),
	Crib smallint,
	[Crib Name] varchar(50),
	[Crib Type] varchar(50),
	HistoricDate date,
	Overstock int,
	[Dead Stock] int,
	[Below Min] int,
	[Below Critical] int,
	[Out Of Stock] int,
	Lost int,
	Unusable int,
	[In Repair] int,
	[Scheduled CC] int,
	[Due Cycle Count] int,
	[Pending Rework] int, 
	[Total Inventory] decimal(19,4),
	[Inventory Qty] int,
	[Checked Out Cost] decimal(19,4),
	[Checked Out Qty] int,
	[Due Calibration] int
) -- drop table XInvHealthCribCentricDay\

-- If table doesn't exist, create one
IF OBJECT_ID('XInvHealthCribCentricMonth') IS NULL
CREATE TABLE XInvHealthCribCentricMonth(
	SiteID varchar(12) NOT NULL,
	[Site Description] varchar(50),
	ParentSiteID varchar(12),
	Crib smallint,
	[Crib Name] varchar(50),
	[Crib Type] varchar(50),
	HistoricDate date,
	Overstock int,
	[Dead Stock] int,
	[Below Min] int,
	[Below Critical] int,
	[Out Of Stock] int,
	Lost int,
	Unusable int,
	[In Repair] int,
	[Scheduled CC] int,
	[Due Cycle Count] int,
	[Pending Rework] int, 
	[Total Inventory] decimal(19,4),
	[Inventory Qty] int,
	[Checked Out Cost] decimal(19,4),
	[Checked Out Qty] int,
	[Due Calibration] int
) -- drop table XInvHealthCribCentricMonth

-- If today's record already exist -> Delete it to prevent duplicates
IF EXISTS (SELECT * FROM XInvHealthCribCentricDay  WHERE HistoricDate = CAST(getDate() AS DATE))
	DELETE XInvHealthCribCentricDay WHERE HistoricDate=CAST(getDate() AS DATE)

-- delete index if it exists
IF EXISTS(SELECT * FROM sys.indexes WHERE name='IX_XINVHLTHDAY_DT_ST_CR' AND object_id = OBJECT_ID('XInvHealthCribCentricDay'))
	DROP INDEX IX_XINVHLTHDAY_DT_ST_CR ON XInvHealthCribCentricDay;

With AverageUsage as (
    SELECT 
        Crib.SiteID,
	    STATION.Item,
        STATION.Crib,
	    STATION.CribBin,
	    ISNULL(STATION.OnOrder, 0) AS 'OnOrder',
	    ISNULL(STATION.Quantity, 0) AS 'Quantity',
        ISNULL(STATION.TotalPrice, 0) AS 'TotalPrice',
        ISNULL(STATION.Maximum, 0) AS 'Maximum',
	    ((CASE WHEN sh.prev1 < 0 THEN 0 ELSE ISNULL(sh.prev1,0) END +
	    CASE WHEN sh.Prev2 < 0 THEN 0 ELSE ISNULL(sh.Prev2,0) END +
	    CASE WHEN sh.Prev3 < 0 THEN 0 ELSE ISNULL(sh.Prev3,0) END +
	    CASE WHEN sh.Prev4 < 0 THEN 0 ELSE ISNULL(sh.Prev4,0) END +
	    CASE WHEN sh.Prev5 < 0 THEN 0 ELSE ISNULL(sh.Prev5,0) END +
	    CASE WHEN sh.Prev6 < 0 THEN 0 ELSE ISNULL(sh.Prev6,0) END +
	    CASE WHEN sh.Prev7 < 0 THEN 0 ELSE ISNULL(sh.Prev7,0) END +
	    CASE WHEN sh.Prev8 < 0 THEN 0 ELSE ISNULL(sh.Prev8,0) END +
	    CASE WHEN sh.Prev9 < 0 THEN 0 ELSE ISNULL(sh.Prev9,0) END +
	    CASE WHEN sh.Prev10 < 0 THEN 0 ELSE ISNULL(sh.Prev10,0) END +
	    CASE WHEN sh.Prev11 < 0 THEN 0 ELSE ISNULL(sh.Prev11,0) END +
	    CASE WHEN sh.Prev12 < 0 THEN 0 ELSE ISNULL(sh.Prev12,0) END) / 12 ) as AvgUsage
    FROM STATION
	    inner join crib
		    on STATION.Crib = Crib.Crib
        LEFT outer JOIN StationHistory sh
		    ON STATION.CribBin = sh.CribBin
    WHERE
	    item is not null and  quantity > 0
),

--//////////////////// Overstock ////////////////////////
OverStock as(
	SELECT 
		Crib.SiteID as SiteID, 
		Crib.Crib as Crib,
		count(CribBin) as 'Overstock'
	FROM AverageUsage
		inner join crib
			on AverageUsage.Crib = Crib.Crib
	WHERE 
		(Quantity + OnOrder) >	CASE WHEN @OvstCriteria = 0 THEN  Maximum
									WHEN @OvstCriteria = 1 THEN AvgUsage 
									ELSE Maximum 
								END
	GROUP BY Crib.SiteID, Crib.Crib
),

--//////////////////// Deadstock ////////////////////////
DeadStock as ( 
	SELECT 
		Crib.SiteID as SiteID,
		Crib.Crib as Crib,
		count(CribBin) as 'DeadStock'
	FROM   
		STATION 
			INNER JOIN Crib on STATION.Crib = Crib.Crib

	WHERE
		(STATION.DateLastIssue IS NULL OR STATION.DateLastIssue <= @StartDate)     
		AND (STATION.DateLastReceipt IS NULL OR STATION.DateLastReceipt <= @StartDate) 
		AND BinQuantity > 0
	group by Crib.SiteID, Crib.Crib
),

--//////////////////// Below Min ////////////////////////
BelowMin as (
	SELECT 
		SiteID,
		Crib.Crib as Crib,
		count(CribBin) as 'BelowMin'
	FROM
		STATION
			INNER JOIN Crib ON STATION.Crib = Crib.Crib
	WHERE StopOrdering <> 1 
		AND STATION.Item is not null
		AND ((binquantity < ISNULL(OverrideOrderPoint, OrderPoint)) AND ISNULL(OverrideOrderPoint, OrderPoint) <> -1)
	GROUP BY siteid, Crib.Crib
),

--//////////////////// Below Critical ////////////////////////
BelowCritical as (
	SELECT 
		SiteID,
		Crib.Crib as Crib,
		count(CribBin) as 'BelowCrit'
	FROM
		STATION
			INNER JOIN Crib ON STATION.Crib = Crib.Crib
	WHERE StopOrdering <> 1 
		AND ((binquantity < CriticalPoint) AND ISNULL(OverrideOrderPoint, OrderPoint) <> -1)
	GROUP BY siteid, Crib.Crib
),

--//////////////////// Out of Stock ////////////////////////
OutOfStock as ( -- it has 69 records with Item = null
	SELECT 
		Crib.SiteID as SiteID,
		Crib.Crib as Crib,
		count(CribBin) as 'OutOfStock'
	FROM
		STATION
			INNER JOIN Crib ON STATION.Crib = Crib.Crib
	WHERE StopOrdering <> 1 
		AND ((BinQuantity = 0) AND ISNULL(OverrideOrderPoint, OrderPoint) <> -1)
	GROUP BY Crib.siteid, Crib.Crib
),

--//////////////////////// Unusable //////////////////////////////////////////
Unusable as (
	SELECT
		c.SiteID,
		c.Crib,
		count(isr.SerialID) Unusable 
	FROM ItemSerial isr
		INNER JOIN SerialStatus ss on isr.Status = ss.Status
		INNER JOIN Station s on isr.CribBin = s.CribBin
		INNER JOIN Crib c on s.Crib = c.Crib
	WHERE ss.StatusDesc = 'Unusable'
	Group By 	c.SiteID, c.Crib
),

statushistory as (
	select sh1.serialid,sh2.cribbin
	from
	(
		select serialid,max(statushistoryid) as shID
		from serialstatushistory
		where cribbin is not null and cribbin not like '!%'
		group by serialid
	) AS sh1
		inner join serialstatushistory sh2
			on sh1.shid = sh2.statushistoryid
),

--//////////////////////// Lost //////////////////////////////////////////
Lost as (
	SELECT
		c.SiteID,
		c.Crib,
		count(isr.SerialID) Lost 
	FROM ItemSerial isr
		INNER JOIN SerialStatus ss on isr.Status = ss.Status
		INNER JOIN statushistory sh on sh.SerialId = isr.SerialID
		INNER JOIN Station s on sh.CribBin = s.CribBin
		INNER JOIN Crib c on s.Crib = c.Crib
	WHERE ss.StatusDesc = 'Lost'
	Group By 	c.SiteID, c.Crib
),

--///////////////////// In Repair ///////////////////////////////////////
InRepair as (
	SELECT
		c.SiteID,
		c.Crib,
		count(isr.SerialID) AS InRepair 
	FROM ItemSerial isr
		INNER JOIN SerialStatus ss on isr.Status = ss.Status
		INNER JOIN statushistory sh on sh.SerialId = isr.SerialID
		INNER JOIN Station s on sh.CribBin = s.CribBin
		INNER JOIN Crib c on s.Crib = c.Crib

	WHERE ss.StatusDesc = 'In Repair'
	Group By 	c.SiteID, c.Crib 
),

--///////////////////// Bins Scheduled ///////////////////////////////////////
ScheduledCC as (
	SELECT
		c.SiteID,
		ii.Crib,
		count(ii.CribBin) AS SceduledCC 	
	FROM ItemInventory ii
		INNER JOIN Crib c ON ii.Crib = c.Crib
	WHERE DATECOUNTED IS NULL
	Group by c.SiteID, ii.Crib
),

--///////////////////// Bins Past Due ///////////////////////////////////////
PastDueCC as (
	SELECT
		c.SiteID,
		ii.Crib,
		count(ii.CribBin) AS PastDueCC 	
	FROM ItemInventory ii
		INNER JOIN Crib c ON ii.Crib = c.Crib
	WHERE DATECOUNTED IS NULL AND DATEDUE < getdate()
	Group by c.SiteID, ii.Crib
),

--///////////////////// Pending Rework ///////////////////////////////////////
PendingRework as (
	SELECT
		c.SiteID,
		c.Crib,
		Count(Item) AS PendingRework
	FROM STATION s
		INNER JOIN Crib c ON s.Crib = c.Crib
	where PendingRework > 0
	Group by c.SiteID, c.Crib
),

--/////////////////////// Total Inventory Value /////////////////////////////////
InventoryValue as (
	SELECT
		c.SiteID,
		c.Crib,
		SUM(ISNULL(TotalPrice, 0)) AS InvValue
	FROM STATION s
		INNER JOIN Crib c ON s.Crib = c.Crib 
	WHERE s.Item IS NOT NULL
	group by 	c.SiteID, c.Crib
),

--/////////////////////// Total Inventory Qty /////////////////////////////////
InventoryQty as (
	SELECT
		c.SiteID,
		c.Crib,
		SUM(s.Quantity) AS InvQty
	FROM STATION s
		INNER JOIN Crib c ON s.Crib = c.Crib 
	WHERE s.Item IS NOT NULL
	group by 	c.SiteID, c.Crib
),

--/////////////////////// Checked Out Items Cost /////////////////////////////////
CheckedOutCost as (
	SELECT
		c.SiteID,
		c.Crib,
        SUM(ISNULL(co.Cost, 0)) as CheckedOutCost
	FROM CHECKOUT co
		INNER JOIN STATION s ON s.CribBin = co.CribBin
		INNER JOIN Crib c ON c.Crib = s.Crib
	GROUP BY c.SiteID, c.Crib
),

--/////////////////////// Checked Out Items Qty /////////////////////////////////
CheckedOutQty as (
	SELECT
		c.SiteID,
		c.Crib,
        SUM(ISNULL(co.Quantity, 0)) as CheckedOutQty
	FROM CHECKOUT co
		INNER JOIN STATION s ON s.CribBin = co.CribBin
		INNER JOIN Crib c ON c.Crib = s.Crib
	GROUP BY c.SiteID, c.Crib
),

--/////////////////////// Past Calibration Gauges /////////////////////////////////
PastCalibration as (
	SELECT 
		c.SiteID,
		c.Crib,
		SUM(s.Quantity) AS PastCalib
	FROM ItemSerial itms
		INNER JOIN Station s ON s.CribBin = itms.CribBin
		INNER JOIN Crib c ON c.Crib = s.Crib
	WHERE SERIALID IN (SELECT SERIALID FROM GAUGE WHERE NEXTCERTIFYDATE < GetDate())
		AND itms.Status NOT IN ( 4,7,8,9 ) -- Not in OutOfService, InCalibration, Lost, Off-Site
	group by 	c.SiteID, c.Crib
),

-- Building total table with distinct Site, crib and item compasite
Total as (
	SELECT Distinct SiteID, Crib from OverStock
	UNION 
	SELECT Distinct SiteID, Crib from DeadStock
	UNION
	SELECT Distinct SiteID, Crib from BelowMin
	Union
	SELECT Distinct SiteID, Crib from BelowCritical
	UNION
	SELECT Distinct SiteID, Crib from OutOfStock
	UNION 
	SELECT Distinct SiteID, Crib from Lost
	UNION
	SELECT Distinct SiteID, Crib from Unusable
	Union
	SELECT Distinct SiteID, Crib from InRepair
	UNION 
	SELECT Distinct SiteID, Crib from ScheduledCC
	UNION
	SELECT Distinct SiteID, Crib from PastDueCC
	Union
	SELECT Distinct SiteID, Crib from PendingRework
	Union
	SELECT Distinct SiteID, Crib from InventoryValue
	Union
	SELECT Distinct SiteID, Crib from InventoryQty
	Union
	SELECT Distinct SiteID, Crib from CheckedOutCost 
	Union
	SELECT Distinct SiteID, Crib from CheckedOutQty
	Union
	SELECT Distinct SiteID, Crib from PastCalibration
) 

INSERT INTO XInvHealthCribCentricDay

SELECT
	tot.SiteID as SiteID,
	SiteDescription,
	ParentSiteID,
	tot.Crib as Crib,
	c.Name as CribName,
	ct.Description CribType,
	getdate() as HistoricDate,
	ISNULL(Overstock,0) AS Overstock,
	ISNULL(DeadStock,0) AS DeadStock,
	ISNULL(BelowMin,0) AS BelowMin,
	ISNULL(BelowCrit,0) AS BelowCrit,
	ISNULL(OutOfStock,0) AS OutOfStock,
	ISNULL(Lost,0) AS Lost,
	ISNULL(Unusable,0) AS Unusable,
	ISNULL(InRepair,0) AS InRepair,
	ISNULL(SceduledCC,0) AS ScheduledCC,
	ISNULL(PastDueCC,0) AS PastDueCC,
	ISNULL(PendingRework,0) AS PendingRework,
	ISNULL(InvValue,0) AS InvValue,
	ISNULL(InvQty,0) AS InvQty,
	ISNULL(CheckedOutCost,0) AS CheckedOutCost,
	ISNULL(CheckedOutQty,0) AS CheckedOutQty,
	ISNULL(PastCalib,0) AS PastCalib

FROM Total tot
    left outer join OverStock ovs on ovs.SiteID = tot.SiteID AND ovs.Crib = tot.Crib
    left outer join DeadStock ds on ds.SiteID = tot.SiteID AND ds.Crib = tot.Crib
    left outer join BelowMin bm on bm.SiteID = tot.SiteID AND bm.Crib = tot.Crib
    left outer join BelowCritical bc on bc.SiteID = tot.SiteID AND bc.Crib = tot.Crib
    left outer join OutOfStock ous on ous.SiteID = tot.SiteID AND ous.Crib = tot.Crib
    left outer join Lost  l on l.SiteID = tot.SiteID AND l.Crib = tot.Crib
    left outer join Unusable uu on uu.SiteID = tot.SiteID AND uu.Crib = tot.Crib
    left outer join InRepair ir on ir.SiteID = tot.SiteID AND ir.Crib = tot.Crib
    left outer join ScheduledCC sch on sch.SiteID = tot.SiteID AND sch.Crib = tot.Crib
    left outer join PastDueCC pd on pd.SiteID = tot.SiteID AND pd.Crib = tot.Crib
    left outer join PendingRework pr on pr.SiteID = tot.SiteID AND pr.Crib = tot.Crib
    left outer join CheckedOutCost coc on coc.SiteID = tot.SiteID AND coc.Crib = tot.Crib
    left outer join CheckedOutQty coq on coq.SiteID = tot.SiteID AND coq.Crib = tot.Crib
    left outer join PastCalibration pc on pc.SiteID = tot.SiteID AND pc.Crib = tot.Crib
    left outer join InventoryValue iv on iv.SiteID = tot.SiteID AND iv.Crib = tot.Crib
    left outer join InventoryQty iq on iq.SiteID = tot.SiteID AND iq.Crib = tot.Crib

	LEFT OUTER JOIN SiteProfile sp ON tot.SiteID = sp.SiteID
	LEFT OUTER JOIN Crib c ON tot.Crib = c.Crib
	left OUTER JOIN CribType ct ON c.CribType = ct.CribType

ORDER BY  HistoricDate, SiteID, Crib

-- create index for re-populated table
CREATE CLUSTERED INDEX IX_XINVHLTHDAY_DT_ST_CR ON XInvHealthCribCentricDay (HistoricDate, SiteID, Crib)

-- delete old historic data beyond threshhold
DELETE XInvHealthCribCentricDay
WHERE HistoricDate < DATEADD(dd,-@KeepDayHistoryDays,GETDATE())

-- Generate monthly data is needed
-- delete index if it exists
IF EXISTS(SELECT * FROM sys.indexes WHERE name='IX_XINVHLTHMONTH_DT_ST_CR' AND object_id = OBJECT_ID('XInvHealthCribCentricMonth'))
	DROP INDEX IX_XINVHLTHMONTH_DT_ST_CR ON XInvHealthCribCentricMonth;

IF EXISTS (SELECT * FROM XInvHealthCribCentricMonth  WHERE HistoricDate = DATEADD(m, DATEDIFF(m, 0, getdate()), 0))
	DELETE XInvHealthCribCentricMonth WHERE HistoricDate=DATEADD(m, DATEDIFF(m, 0, getdate()), 0)

INSERT INTO XInvHealthCribCentricMonth
SELECT
	SiteID,
	[Site Description],
	ParentSiteID,
	Crib,
	[Crib Name],
	[Crib Type],
	DATEADD(m, DATEDIFF(m, 0, HistoricDate), 0) AS HistoricDate,
	AVG(Overstock) as Overstock,
	AVG([Dead Stock]) AS [Dead Stock],
	AVG([Below Min]) AS [Below Min],
	AVG([Below Critical]) AS [Below Critical],
	AVG([Out Of Stock]) AS [Out Of Stock],
	AVG(Lost) AS Lost,
	AVG(Unusable) AS Unusable,
	AVG([In Repair]) AS [In Repair],
	AVG([Scheduled CC]) AS [Scheduled CC],
	AVG([Due Cycle Count]) AS [Due Cycle Count],
	AVG([Pending Rework]) AS [Pending Rework],
	AVG([Total Inventory]) AS [Total Inventory],
	AVG([Inventory Qty]) AS [Inventory Qty],
	AVG([Checked Out Cost]) AS [Checked Out Cost],
	AVG([Checked Out Qty]) AS [Checked Out Qty],
	AVG([Due Calibration]) AS [Due Calibration]
FROM XInvHealthCribCentricDay
WHERE DATEADD(m, DATEDIFF(m, 0, HistoricDate), 0) = DATEADD(m, DATEDIFF(m, 0, getdate()), 0)
GROUP BY  SiteID, [Site Description], ParentSiteID, Crib, [Crib Name], [Crib Type], DATEADD(m, DATEDIFF(m, 0, HistoricDate), 0)
ORDER BY  HistoricDate, SiteID, Crib

-- create index for re-populated table
CREATE CLUSTERED INDEX IX_XINVHLTHMONTH_DT_ST_CR ON XInvHealthCribCentricMonth (HistoricDate, SiteID, Crib) 

-- delete old historic data beyond threshhold
DELETE XInvHealthCribCentricMonth
WHERE HistoricDate < DATEADD(mm,-@KeepDayHistoryMonths,GETDATE())

END -- INVENTORY HEALTH CRIB CENTRIC TRENDS

GO


