--------------- SITE USAGE SUMMARIES -------------
IF OBJECT_ID('sp_GenerateSiteUsageSummaries') IS NOT NULL
DROP PROCEDURE [dbo].[sp_GenerateSiteUsageSummaries]
GO

CREATE PROCEDURE sp_GenerateSiteUsageSummaries
AS
BEGIN

-- Compute start date from number of months in stored option
DECLARE @StartDate date
DECLARE @DashboardMonths int
SELECT @DashboardMonths = INT FROM GLOBALSETTINGS WHERE KEYNAME = 'Dashboard_ProcessUsageMonths'
IF @DashboardMonths IS NULL 
   SET @DashboardMonths = 24
SELECT @StartDate = DATEADD(m, -@DashboardMonths, GETDATE())

-- delete index if it exists
IF EXISTS(SELECT * FROM sys.indexes WHERE name='IX_XTRANS_ST_CLS' AND object_id = OBJECT_ID('XTransDay'))
	DROP INDEX IX_XTRANS_ST_CLS ON XTransDay

TRUNCATE TABLE XTransDay
INSERT INTO XTransDay
SELECT	DATEADD(dd, DATEDIFF(dd, 0, TRANS.Transdate), 0) AS TransMonth,
		SiteID,
		TRANS.Item,
		Max(Description1) AS 'Item Description',
		TypeDescription,
		ItemClass,
		INVENTRY.ItemType,
		ItemTypeDesc,
		SUM(ISNULL(Cost,0)) AS 'Sum Cost',
		SUM(ISNULL(TRANS.Quantity,0)) AS 'Sum Qty',
		COUNT(distinct TRANS.Item) as 'Distinct Item Count',
		COUNT(TRANS.item) AS 'Item Count',
		STATION.Consignment,
		TRANS.Crib,
		TRANS.User1,
		TRANS.User2,
		TRANS.User3,
		TRANS.User4,
		TRANS.User5,
		TRANS.User6
FROM        TRANS (nolock)
INNER JOIN  INVENTRY (nolock) ON TRANS.Item = INVENTRY.ItemNumber
INNER JOIN	ItemType (nolock) ON INVENTRY.ItemType = ItemType.ItemType
INNER JOIN  Crib (nolock) ON TRANS.Crib = Crib.Crib 
INNER JOIN	STATION (nolock) ON STATION.Cribbin = TRANS.cribbin
WHERE		UsageType = 1 AND TRANS.Transdate > @StartDate
GROUP BY    DATEADD(dd, DATEDIFF(dd, 0, TRANS.Transdate), 0), SiteID, TRANS.Item, ItemClass, INVENTRY.ItemType, ItemTypeDesc, TypeDescription, STATION.Consignment, TRANS.Crib,
		  TRANS.User1, TRANS.User2, TRANS.User3, TRANS.User4, TRANS.User5, TRANS.User6

-- create index for re-populated table
CREATE CLUSTERED INDEX IX_XTRANS_ST_CLS ON XTransDay (SiteID, ItemClass)

TRUNCATE TABLE XTransMonth
INSERT INTO XTransMonth
SELECT            DATEADD(m, DATEDIFF(m, 0, Transdate), 0) AS TransMonth,
                  SiteID,
                  Item,
                  Max(Description1) AS 'Item Description',
                  TypeDescription,
                  ItemClass,
                  ItemType,
                  ItemTypeDesc,
                  SUM(ISNULL(CostSum,0)) AS 'Sum Cost',
                  SUM(ISNULL(QtySum,0)) AS 'Sum Qty',
                  SUM(DistinctItemCount),
                  SUM(ItemCount),
                  Consignment,
                  Crib,
		  User1,
		  User2,
		  User3,
		  User4,
		  User5,
		  User6
FROM        XTransDay
GROUP BY    DATEADD(m, DATEDIFF(m, 0, Transdate), 0), SiteID, Item, ItemClass, ItemType, ItemTypeDesc, TypeDescription, Consignment, Crib,
		  User1, User2, User3, User4, User5, User6

-- Record last date tables updated so status can be monitored
IF EXISTS (SELECT * FROM GLOBALSETTINGS WHERE KEYNAME = 'Dashboard_LastSummaryDate')
	UPDATE GLOBALSETTINGS SET STRING = convert(varchar, GETDATE(),120) WHERE KEYNAME ='Dashboard_LastSummaryDate'
ELSE
	INSERT INTO GLOBALSETTINGS (KEYNAME, STRING) VALUES ('Dashboard_LastSummaryDate', convert(varchar, GETDATE(),120))

END -- SITE USAGE SUMMARIES
GO


--------------- EMPLOYEE USAGE SUMMARIES ----------------------
IF OBJECT_ID('sp_GenerateEmployeeUsageSummaries') IS NOT NULL
DROP PROCEDURE [dbo].[sp_GenerateEmployeeUsageSummaries]
GO

CREATE PROCEDURE sp_GenerateEmployeeUsageSummaries
AS
BEGIN

-- Compute start date from number of months in stored option
DECLARE @StartDate date
DECLARE @DashboardMonths int
SELECT @DashboardMonths = INT FROM GLOBALSETTINGS WHERE KEYNAME = 'Dashboard_ProcessUsageMonths'
IF @DashboardMonths IS NULL 
   SET @DashboardMonths = 24
SELECT @StartDate = DATEADD(m, -@DashboardMonths, GETDATE())

-- delete index if it exists
IF EXISTS(SELECT * FROM sys.indexes WHERE name='IX_XEMPL_EMPL_CLS' AND object_id = OBJECT_ID('XEmployeeDay'))
	DROP INDEX IX_XEMPL_EMPL_CLS ON XEmployeeDay

TRUNCATE TABLE XEmployeeDay
INSERT INTO XEmployeeDay
SELECT	DATEADD(dd, DATEDIFF(dd, 0, TRANS.Transdate), 0) AS TransMonth,
		SiteID,
		EMPLOYEE.ID,
		Max(EMPLOYEE.Name),
		ItemNumber,
		Max(Description1) AS 'Item Description',
		TypeDescription,
		ItemClass,
		INVENTRY.ItemType,
		ItemTypeDesc,
		SUM(ISNULL(Cost,0)) AS 'Sum Cost',
		SUM(ISNULL(TRANS.Quantity,0)) AS 'Sum Qty',
		COUNT(distinct TRANS.Item) as 'Distinct Item Count',
		COUNT(TRANS.item) AS 'Item Count',
		STATION.Consignment,
		TRANS.Crib,
		TRANS.User1,
		TRANS.User2,
		TRANS.User3,
		TRANS.User4,
		TRANS.User5,
		TRANS.User6
FROM        TRANS (nolock)
INNER JOIN  INVENTRY (nolock) ON TRANS.Item = INVENTRY.ItemNumber
INNER JOIN	EMPLOYEE (nolock) ON TRANS.employee = EMPLOYEE.ID
INNER JOIN	ItemType (nolock) ON INVENTRY.ItemType = ItemType.ItemType
INNER JOIN  Crib (nolock) ON TRANS.Crib = Crib.Crib 
INNER JOIN	STATION (nolock) ON STATION.Cribbin = TRANS.cribbin
WHERE UsageType = 1 AND TRANS.Transdate > @StartDate 
GROUP BY    DATEADD(dd, DATEDIFF(dd, 0, TRANS.Transdate), 0), SiteID, EMPLOYEE.ID, ItemNumber, TRANS.Item, ItemClass, INVENTRY.ItemType, ItemTypeDesc, TypeDescription, STATION.Consignment, TRANS.Crib,
		  TRANS.User1, TRANS.User2, TRANS.User3, TRANS.User4, TRANS.User5, TRANS.User6

-- create index for re-populated table
CREATE CLUSTERED INDEX IX_XEMPL_EMPL_CLS ON XEmployeeDay (EmployeeID, ItemClass)

TRUNCATE TABLE XEmployeeMonth
INSERT INTO XEmployeeMonth
SELECT            DATEADD(m, DATEDIFF(m, 0, Transdate), 0) AS TransMonth,
                  SiteID,
                  EmployeeID,
                  Max(EmployeeName),
                  Item,
                  Max(Description1) AS 'Item Description',
                  TypeDescription,
                  ItemClass,
                  ItemType,
                  ItemTypeDesc,
                  SUM(ISNULL(CostSum,0)),
                  SUM(ISNULL(QtySum,0)),
                  SUM(DistinctItemCount),
                  SUM(ItemCount),
                  Consignment,
                  Crib,
		  User1,
		  User2,
		  User3,
		  User4,
		  User5,
		  User6
FROM        XEmployeeDay (nolock)
GROUP BY    DATEADD(m, DATEDIFF(m, 0, Transdate), 0), SiteID, EmployeeID, EmployeeName, Item, ItemClass, ItemType, ItemTypeDesc, TypeDescription, Consignment, Crib,
		  User1, User2, User3, User4, User5, User6

-- Record last date tables updated so status can be monitored
IF EXISTS (SELECT * FROM GLOBALSETTINGS WHERE KEYNAME = 'Dashboard_LastSummaryDate')
	UPDATE GLOBALSETTINGS SET STRING = convert(varchar, GETDATE(),120) WHERE KEYNAME ='Dashboard_LastSummaryDate'
ELSE
	INSERT INTO GLOBALSETTINGS (KEYNAME, STRING) VALUES ('Dashboard_LastSummaryDate', convert(varchar, GETDATE(),120))

END -- EMPLOYEE USAGE SUMMARIES
GO

--------------- INVENTORY CONCERN SUMMARIES -------------
IF OBJECT_ID('sp_GenerateInventoryConcernSummaries') IS NOT NULL
DROP PROCEDURE [dbo].[sp_GenerateInventoryConcernSummaries]
GO

CREATE PROCEDURE sp_GenerateInventoryConcernSummaries
AS
BEGIN

DECLARE @DeadStockNotIssuedOffset int
DECLARE @CurrentDate date
DECLARE @StartDate date
DECLARE @OvstCriteria int

SELECT @DeadStockNotIssuedOffset = INT FROM GLOBALSETTINGS WHERE KEYNAME = 'Dashboard_DeadStockNotIssuedOffset'
IF @DeadStockNotIssuedOffset IS NULL
   SET @DeadStockNotIssuedOffset = 150
SELECT @StartDate = DATEADD(d, -@DeadStockNotIssuedOffset, GETDATE());

SELECT @OvstCriteria = INT FROM GLOBALSETTINGS WHERE KEYNAME = 'Dashboard_OverstockCriteria'
IF @OvstCriteria IS NULL
   SET @OvstCriteria = 0

-- If table doesn't exist, create one
IF OBJECT_ID('XInventryConcern') IS NULL
CREATE TABLE XInventryConcern(
	SiteID varchar(12),
	Crib smallint,
	ConcernType varchar(3),
	BinQtySum int NULL
)

-- delete index if it exists
IF EXISTS(SELECT * FROM sys.indexes WHERE name='IX_XINVCRN_ST_CR' AND object_id = OBJECT_ID('XInventryConcern'))
	DROP INDEX IX_XINVCRN_ST_CR ON XInventryConcern

TRUNCATE TABLE XInventryConcern;

--/////////////// Table to prepare for Overstock calculation  ///////
With AverageUsage as (
    SELECT 
        Crib.SiteID,
	    STATION.Item,
        INVENTRY.Description1 AS ITEMDESC,
        ISNULL(INVENTRY.ItemClass,'(None)') AS ITEMCLASS,
        STATION.Crib,
	    STATION.CribBin,
	    ISNULL(STATION.OnOrder, 0) AS 'OnOrder',
	    ISNULL(STATION.Quantity, 0) AS 'Quantity',
        ISNULL(STATION.TotalPrice, 0) AS 'TotalPrice',
        ISNULL(STATION.Maximum, 0) AS 'Maximum',
	    ((CASE WHEN sh.prev1 < 0 THEN 0 ELSE ISNULL(sh.prev1,0) END +
	    CASE WHEN sh.Prev2 < 0 THEN 0 ELSE ISNULL(sh.Prev2,0) END +
	    CASE WHEN sh.Prev3 < 0 THEN 0 ELSE ISNULL(sh.Prev3,0) END +
	    CASE WHEN sh.Prev4 < 0 THEN 0 ELSE ISNULL(sh.Prev4,0) END +
	    CASE WHEN sh.Prev5 < 0 THEN 0 ELSE ISNULL(sh.Prev5,0) END +
	    CASE WHEN sh.Prev6 < 0 THEN 0 ELSE ISNULL(sh.Prev6,0) END +
	    CASE WHEN sh.Prev7 < 0 THEN 0 ELSE ISNULL(sh.Prev7,0) END +
	    CASE WHEN sh.Prev8 < 0 THEN 0 ELSE ISNULL(sh.Prev8,0) END +
	    CASE WHEN sh.Prev9 < 0 THEN 0 ELSE ISNULL(sh.Prev9,0) END +
	    CASE WHEN sh.Prev10 < 0 THEN 0 ELSE ISNULL(sh.Prev10,0) END +
	    CASE WHEN sh.Prev11 < 0 THEN 0 ELSE ISNULL(sh.Prev11,0) END +
	    CASE WHEN sh.Prev12 < 0 THEN 0 ELSE ISNULL(sh.Prev12,0) END) / 12 ) as AvgUsage
    FROM STATION
	    inner join crib
		    on STATION.Crib = Crib.Crib
        LEFT outer JOIN StationHistory sh
		    ON STATION.CribBin = sh.CribBin
        LEFT outer JOIN INVENTRY
		    ON STATION.Item = INVENTRY.ItemNumber
    WHERE
	    item is not null and  quantity > 0
) 

INSERT INTO XInventryConcern
--//////////////////// Overstock ////////////////////////

SELECT 
	Crib.SiteID, 
    Crib.Crib,
	'OVS' as 'Concern', 
	count(CribBin) as 'BinCount'
FROM AverageUsage
	inner join crib
		on AverageUsage.Crib = Crib.Crib
--    WHERE (Quantity + OnOrder) > AvgUsage OR (Quantity + OnOrder) > Maximum
WHERE 
	(Quantity + OnOrder) >	CASE WHEN @OvstCriteria = 0 THEN  Maximum
								WHEN @OvstCriteria = 1 THEN AvgUsage 
								ELSE Maximum 
							END
GROUP BY Crib.SiteID, Crib.Crib

UNION ALL

--//////////////////// Deadstock ////////////////////////
SELECT 
	Crib.SiteID,
	Crib.Crib,
	'DST' as 'Concern', 
    Count(CribBin) as 'BinCount'
FROM   
	STATION 
	    INNER JOIN INVENTRY INVENTRY ON STATION.ITEM=INVENTRY.ITEMNUMBER
	    INNER JOIN Crib on STATION.Crib = Crib.Crib
WHERE
	(STATION.DateLastIssue IS NULL OR STATION.DateLastIssue <= @StartDate)     
    AND (STATION.DateLastReceipt IS NULL OR STATION.DateLastReceipt <= @StartDate) 
    AND BinQuantity > 0
group by Crib.SiteID, Crib.Crib

UNION ALL

--//////////////////// Below Min ////////////////////////
SELECT 
    SiteID,
	Crib.Crib, 
	'BMS' as 'Concern', 
    count(CribBin) as 'BinCount'
FROM
	STATION
        INNER JOIN INVENTRY ON STATION.Item = INVENTRY.ItemNumber
	    INNER JOIN Crib ON STATION.Crib = Crib.Crib
WHERE StopOrdering <> 1 
	AND STATION.Item is not null
	AND ((binquantity < ISNULL(OverrideOrderPoint, OrderPoint)) AND ISNULL(OverrideOrderPoint, OrderPoint) <> -1)
GROUP BY siteid, Crib.Crib

UNION ALL

--//////////////////// Below Critical ////////////////////////
SELECT 
    SiteID,
	Crib.Crib, 
	'BCS' as 'Concern', 
    count(CribBin) as 'BinCount'
FROM
	STATION
        INNER JOIN INVENTRY ON STATION.Item = INVENTRY.ItemNumber
	    INNER JOIN Crib ON STATION.Crib = Crib.Crib
WHERE StopOrdering <> 1 
	AND ((binquantity < CriticalPoint) AND ISNULL(OverrideOrderPoint, OrderPoint) <> -1)
GROUP BY siteid, Crib.Crib

UNION ALL

--//////////////////// Out of Stock ////////////////////////
SELECT 
    Crib.SiteID,
	Crib.Crib,
	'OUT' as 'Concern', 
    count(CribBin) as 'BinCount'
FROM
	STATION
        INNER JOIN INVENTRY ON STATION.Item = INVENTRY.ItemNumber
	    INNER JOIN Crib ON STATION.Crib = Crib.Crib
WHERE StopOrdering <> 1 
	AND ((BinQuantity = 0) AND ISNULL(OverrideOrderPoint, OrderPoint) <> -1)
GROUP BY Crib.siteid, Crib.Crib

ORDER BY Crib.siteid, Crib.Crib

-- create index for re-populated table
CREATE CLUSTERED INDEX IX_XINVCRN_ST_CR ON XInventryConcern (SiteID, Crib)

END -- INV CONCERN SUMMARIES
GO

--------- Remove Previously used stored Proc -------------
IF OBJECT_ID('GenerateDashboardSummaries') IS NOT NULL
DROP PROCEDURE [dbo].[GenerateDashboardSummaries]