--------------- SITE USAGE SUMMARIES -------------
IF OBJECT_ID('sp_GenerateSiteUsageSummaries') IS NOT NULL
DROP PROCEDURE [dbo].[sp_GenerateSiteUsageSummaries]
GO

CREATE PROCEDURE sp_GenerateSiteUsageSummaries
AS
BEGIN

-- Compute start date from number of months in stored option
DECLARE @StartDate date
DECLARE @DashboardMonths int
SELECT @DashboardMonths = INT FROM GLOBALSETTINGS WHERE KEYNAME = 'Dashboard_ProcessUsageMonths'
IF @DashboardMonths IS NULL 
   SET @DashboardMonths = 24
SELECT @StartDate = DATEADD(m, -@DashboardMonths, GETDATE())

-- delete index if it exists
IF EXISTS(SELECT * FROM sys.indexes WHERE name='IX_XTRANS_ST_CLS' AND object_id = OBJECT_ID('XTransDay'))
	DROP INDEX IX_XTRANS_ST_CLS ON XTransDay

TRUNCATE TABLE XTransDay
INSERT INTO XTransDay
SELECT	DATEADD(dd, DATEDIFF(dd, 0, TRANS.Transdate), 0) AS TransMonth,
		SiteID,
		TRANS.Item,
		Max(Description1) AS 'Item Description',
		TypeDescription,
		ISNULL(ItemClass,'(None)'),
		INVENTRY.ItemType,
		ItemTypeDesc,
		SUM(ISNULL(Cost,0)) AS 'Sum Cost',
		SUM(ISNULL(TRANS.Quantity,0)) AS 'Sum Qty',
		COUNT(distinct TRANS.Item) as 'Distinct Item Count',
		COUNT(TRANS.item) AS 'Item Count',
		STATION.Consignment,
		TRANS.Crib,
		TRANS.User1,
		TRANS.User2,
		TRANS.User3,
		TRANS.User4,
		TRANS.User5,
		TRANS.User6
FROM        TRANS (nolock)
INNER JOIN  INVENTRY (nolock) ON TRANS.Item = INVENTRY.ItemNumber
INNER JOIN  ItemType (nolock) ON INVENTRY.ItemType = ItemType.ItemType
INNER JOIN  Crib (nolock) ON TRANS.Crib = Crib.Crib 
INNER JOIN  STATION (nolock) ON STATION.Cribbin = TRANS.cribbin
WHERE	    TRANS.Transdate > @StartDate
GROUP BY    DATEADD(dd, DATEDIFF(dd, 0, TRANS.Transdate), 0), SiteID, TRANS.Item, ItemClass, INVENTRY.ItemType, ItemTypeDesc, TypeDescription, STATION.Consignment, TRANS.Crib,
		  TRANS.User1, TRANS.User2, TRANS.User3, TRANS.User4, TRANS.User5, TRANS.User6

-- create index for re-populated table
CREATE CLUSTERED INDEX IX_XTRANS_ST_CLS ON XTransDay (SiteID, ItemClass)

TRUNCATE TABLE XTransMonth
INSERT INTO XTransMonth
SELECT            DATEADD(m, DATEDIFF(m, 0, Transdate), 0) AS TransMonth,
                  SiteID,
                  Item,
                  Max(Description1) AS 'Item Description',
                  TypeDescription,
                  ItemClass,
                  ItemType,
                  ItemTypeDesc,
                  SUM(ISNULL(CostSum,0)) AS 'Sum Cost',
                  SUM(ISNULL(QtySum,0)) AS 'Sum Qty',
                  SUM(DistinctItemCount),
                  SUM(ItemCount),
                  Consignment,
                  Crib,
		  User1,
		  User2,
		  User3,
		  User4,
		  User5,
		  User6
FROM        XTransDay
GROUP BY    DATEADD(m, DATEDIFF(m, 0, Transdate), 0), SiteID, Item, ItemClass, ItemType, ItemTypeDesc, TypeDescription, Consignment, Crib,
		  User1, User2, User3, User4, User5, User6

-- Record last date tables updated so status can be monitored
IF EXISTS (SELECT * FROM GLOBALSETTINGS WHERE KEYNAME = 'Dashboard_LastSummaryDate')
	UPDATE GLOBALSETTINGS SET STRING = convert(varchar, GETDATE(),120) WHERE KEYNAME ='Dashboard_LastSummaryDate'
ELSE
	INSERT INTO GLOBALSETTINGS (KEYNAME, STRING) VALUES ('Dashboard_LastSummaryDate', convert(varchar, GETDATE(),120))

END -- SITE USAGE SUMMARIES
GO


--------------- EMPLOYEE USAGE SUMMARIES ----------------------
IF OBJECT_ID('sp_GenerateEmployeeUsageSummaries') IS NOT NULL
DROP PROCEDURE [dbo].[sp_GenerateEmployeeUsageSummaries]
GO

CREATE PROCEDURE sp_GenerateEmployeeUsageSummaries
AS
BEGIN

-- Compute start date from number of months in stored option
DECLARE @StartDate date
DECLARE @DashboardMonths int
SELECT @DashboardMonths = INT FROM GLOBALSETTINGS WHERE KEYNAME = 'Dashboard_ProcessUsageMonths'
IF @DashboardMonths IS NULL 
   SET @DashboardMonths = 24
SELECT @StartDate = DATEADD(m, -@DashboardMonths, GETDATE())

-- delete index if it exists
IF EXISTS(SELECT * FROM sys.indexes WHERE name='IX_XEMPL_EMPL_CLS' AND object_id = OBJECT_ID('XEmployeeDay'))
	DROP INDEX IX_XEMPL_EMPL_CLS ON XEmployeeDay

TRUNCATE TABLE XEmployeeDay
INSERT INTO XEmployeeDay
SELECT	DATEADD(dd, DATEDIFF(dd, 0, TRANS.Transdate), 0) AS TransMonth,
		SiteID,
		EMPLOYEE.ID,
		Max(EMPLOYEE.Name),
		ItemNumber,
		Max(Description1) AS 'Item Description',
		TypeDescription,
		ISNULL(ItemClass,'(None)'),
		INVENTRY.ItemType,
		ItemTypeDesc,
		SUM(ISNULL(Cost,0)) AS 'Sum Cost',
		SUM(ISNULL(TRANS.Quantity,0)) AS 'Sum Qty',
		COUNT(distinct TRANS.Item) as 'Distinct Item Count',
		COUNT(TRANS.item) AS 'Item Count',
		STATION.Consignment,
		TRANS.Crib,
		TRANS.User1,
		TRANS.User2,
		TRANS.User3,
		TRANS.User4,
		TRANS.User5,
		TRANS.User6
FROM        TRANS (nolock)
INNER JOIN  INVENTRY (nolock) ON TRANS.Item = INVENTRY.ItemNumber
INNER JOIN  EMPLOYEE (nolock) ON TRANS.employee = EMPLOYEE.ID
INNER JOIN  ItemType (nolock) ON INVENTRY.ItemType = ItemType.ItemType
INNER JOIN  Crib (nolock) ON TRANS.Crib = Crib.Crib 
INNER JOIN  STATION (nolock) ON STATION.Cribbin = TRANS.cribbin
WHERE 	    TRANS.Transdate > @StartDate 
GROUP BY    DATEADD(dd, DATEDIFF(dd, 0, TRANS.Transdate), 0), SiteID, EMPLOYEE.ID, ItemNumber, TRANS.Item, ItemClass, INVENTRY.ItemType, ItemTypeDesc, TypeDescription, STATION.Consignment, TRANS.Crib,
		  TRANS.User1, TRANS.User2, TRANS.User3, TRANS.User4, TRANS.User5, TRANS.User6

-- create index for re-populated table
CREATE CLUSTERED INDEX IX_XEMPL_EMPL_CLS ON XEmployeeDay (EmployeeID, ItemClass)

TRUNCATE TABLE XEmployeeMonth
INSERT INTO XEmployeeMonth
SELECT            DATEADD(m, DATEDIFF(m, 0, Transdate), 0) AS TransMonth,
                  SiteID,
                  EmployeeID,
                  Max(EmployeeName),
                  Item,
                  Max(Description1) AS 'Item Description',
                  TypeDescription,
                  ItemClass,
                  ItemType,
                  ItemTypeDesc,
                  SUM(ISNULL(CostSum,0)),
                  SUM(ISNULL(QtySum,0)),
                  SUM(DistinctItemCount),
                  SUM(ItemCount),
                  Consignment,
                  Crib,
		  User1,
		  User2,
		  User3,
		  User4,
		  User5,
		  User6
FROM        XEmployeeDay (nolock)
GROUP BY    DATEADD(m, DATEDIFF(m, 0, Transdate), 0), SiteID, EmployeeID, EmployeeName, Item, ItemClass, ItemType, ItemTypeDesc, TypeDescription, Consignment, Crib,
		  User1, User2, User3, User4, User5, User6

-- Record last date tables updated so status can be monitored
IF EXISTS (SELECT * FROM GLOBALSETTINGS WHERE KEYNAME = 'Dashboard_LastSummaryDate')
	UPDATE GLOBALSETTINGS SET STRING = convert(varchar, GETDATE(),120) WHERE KEYNAME ='Dashboard_LastSummaryDate'
ELSE
	INSERT INTO GLOBALSETTINGS (KEYNAME, STRING) VALUES ('Dashboard_LastSummaryDate', convert(varchar, GETDATE(),120))

END -- EMPLOYEE USAGE SUMMARIES
GO


--------------- PO DETAILS SUMMARIES -------------
IF OBJECT_ID('sp_GeneratePODetailsSummaries') IS NOT NULL
DROP PROCEDURE [dbo].sp_GeneratePODetailsSummaries
GO

CREATE PROCEDURE sp_GeneratePODetailsSummaries
AS
BEGIN

-- Compute start date from number of months in stored option
DECLARE @StartDate date
DECLARE @DashboardMonths int
DECLARE @AvgLeadTime int
SELECT @AvgLeadTime = INT FROM GLOBALSETTINGS WHERE KEYNAME = 'Dashboard_LeadTimeForPODetailsSum'
IF @AvgLeadTime IS NULL 
   SET @AvgLeadTime = 3
SELECT @DashboardMonths = INT FROM GLOBALSETTINGS WHERE KEYNAME = 'Dashboard_ProcessUsageMonths'
IF @DashboardMonths IS NULL 
   SET @DashboardMonths = 24
SELECT @StartDate = DATEADD(m, -@DashboardMonths, GETDATE())

-- If table doesn't exist, create one
IF OBJECT_ID('XPODetails') IS NULL
CREATE TABLE XPODetails(
	POItemID int not null,
	PONumber int not null,
	SiteID varchar(12) not null,
	Crib smallint,
	Item  varchar(25),
	DateOrdered datetime,
	Received datetime,
	Quantity int,
	Cost decimal(19,4),
	Type varchar(12),
	LT smallint,
	POStatusDescription varchar(24),
	LTStatus varchar(24),
	PODetailStatus varchar(24)
)
--DROP TABLE XPODetails;

-- If table doesn't exist, create one
IF OBJECT_ID('XPODetailsSum') IS NULL
CREATE TABLE XPODetailsSum(
	SiteID varchar(12) not null,
	Crib smallint,
	Item  varchar(25),
	ParentSiteID varchar(12),
	ItemClass varchar(15),
	ItemClassDesc varchar(50),
	ItemType int, 
	ItemTypeDesc varchar(32),
	[Lines Count] int,
	[Qty Sum] int,
	[Cost Sum] decimal(19,4),
	[Pending Authorization] int,
	[Open Total] int,
	[Open And Late] int,
	[Open And At LT] int,
	[Open And Early] int,
	[Late Total] int,
	[Received Late] int,
	[Received At LT] int,
	[Received Early] int
)
--DROP TABLE XPODetailsSum;

-- delete index if it exists
IF EXISTS(SELECT * FROM sys.indexes WHERE name='IX_XPODT_ST_CR' AND object_id = OBJECT_ID('XPODetails'))
	DROP INDEX IX_XPODT_ST_CR ON XPODetails

TRUNCATE TABLE XPODetails
INSERT INTO XPODetails

Select
	PODetail.ID,
	PO.PONumber, 
	SiteID,
	Crib,
	Item,
	DateOrdered,
	Received,
	Quantity,
	Cost,
	pot.Name as Type,
	DATEDIFF(day,DateOrdered,Received) LT,
	POStatusDescription,
	LTStatus = 'Late',
	CASE 
		WHEN Received is NOT Null 
			THEN 'Fullfilled' 
		WHEN  Received is Null AND POStatusDescription = 'Closed'
			THEN 'Closed\Not Received'
		WHEN  Received is Null AND DATEDIFF(day,DateOrdered,getdate()) > @AvgLeadTime
			THEN 'Open\Late'
		ELSE
			'Open\OnTime'
    END as PODetailStatus
FROM PODetail
	inner join PO on PO.PONumber = PODetail.PONumber
	inner join POStatus pos on PO.POStatusNo = pos.POStatusNo
	inner join PoType pot on PODETAIL.Type = pot.ID
WHERE 
	DateOrdered > @StartDate AND SiteID IS NOT NULL AND
	((POStatusDescription in ('Closed', 'Partial') AND Received IS NOT NULL AND DATEDIFF(day,DateOrdered,Received) > @AvgLeadTime) OR
	(POStatusDescription = 'Closed' AND Received is NULL) OR
	(POStatusDescription in ('Ordered', 'Partial') AND (PODetail.Type = 0 or PODetail.Type = 1) AND Received is NULL AND DATEDIFF(day,DateOrdered,getdate()) > @AvgLeadTime))

UNION ALL

Select
	PODetail.ID,
	PO.PONumber, 
	SiteID,
	Crib,
	Item,
	DateOrdered,
	Received,
	Quantity,
	Cost,
	pot.Name as Type,
	DATEDIFF(day,DateOrdered,Received) LT,
	POStatusDescription,
	LTStatus = 'At',
	PODetailStatus = 'Fullfilled'
FROM PODetail
	inner join PO on PO.PONumber = PODetail.PONumber
	inner join POStatus pos on PO.POStatusNo = pos.POStatusNo
	inner join PoType pot on PODETAIL.Type = pot.ID
WHERE 
	DateOrdered > @StartDate AND SiteID IS NOT NULL AND
	(POStatusDescription in ('Closed', 'Partial') AND Received IS NOT NULL AND DATEDIFF(day,DateOrdered,Received) = @AvgLeadTime )

UNION ALL

Select
	PODetail.ID,
	PO.PONumber, 
	SiteID,
	Crib,
	Item,
	DateOrdered,
	Received,
	Quantity,
	Cost,
	pot.Name as Type,
	DATEDIFF(day,DateOrdered,Received) LT,
	POStatusDescription,
	LTStatus = 'Early',
	PODetailStatus = 'Fullfilled'
FROM PODetail
	inner join PO on PO.PONumber = PODetail.PONumber
	inner join POStatus pos on PO.POStatusNo = pos.POStatusNo
	inner join PoType pot on PODETAIL.Type = pot.ID
WHERE 
	DateOrdered > @StartDate AND SiteID IS NOT NULL AND Received is NOT NULL AND
	DATEDIFF(day,DateOrdered,Received) < @AvgLeadTime

UNION ALL

Select
	PODetail.ID,
	PO.PONumber, 
	SiteID,
	Crib,
	Item,
	DateOrdered,
	Received,
	Quantity,
	Cost,
	pot.Name as Type,
	DATEDIFF(day,DateOrdered,Received) LT,
	POStatusDescription,
	LTStatus = 'Open\OnTime',
	PODetailStatus = 'Open\OnTime'
FROM PODetail
	inner join PO on PO.PONumber = PODetail.PONumber
	inner join POStatus pos on PO.POStatusNo = pos.POStatusNo
	inner join PoType pot on PODETAIL.Type = pot.ID
WHERE 
	DateOrdered > @StartDate AND SiteID IS NOT NULL AND Received is NULL AND
	POStatusDescription in ('Partial', 'Ordered') AND (PODetail.Type = 0 or PODetail.Type = 1)
	AND DATEDIFF(day,DateOrdered,getdate()) <= @AvgLeadTime
	
ORDER BY PODetailStatus;

-- create index for re-populated table
CREATE CLUSTERED INDEX IX_XPODT_ST_CR ON XPODetails (SiteID, Crib)


-- delete index if it exists
IF EXISTS(SELECT * FROM sys.indexes WHERE name='IX_XPODTSUM_ST_CR' AND object_id = OBJECT_ID('XPODetailsSum'))
	DROP INDEX IX_XPODTSUM_ST_CR ON XPODetailsSum

TRUNCATE TABLE XPODetailsSum;

with PODetails as (
	Select
		PODetail.ID,
		PO.PONumber, 
		SiteID,
		Crib,
		Item,
		DateOrdered,
		Received,
		Quantity,
		Cost,
		pot.Name as Type,
		DATEDIFF(day,DateOrdered,Received) LT,
		POStatusDescription,
		LTStatus = 'Late',
		CASE 
			WHEN Received is NOT Null 
				THEN 'Fullfilled' 
			WHEN  Received is Null AND POStatusDescription = 'Closed'
				THEN 'Closed\Not Received'
			WHEN  Received is Null AND DATEDIFF(day,DateOrdered,getdate()) > @AvgLeadTime
				THEN 'Open\Late'
			ELSE
				'Open\OnTime'
		END as PODetailStatus
	FROM PODetail
		inner join PO on PO.PONumber = PODetail.PONumber
		inner join POStatus pos on PO.POStatusNo = pos.POStatusNo
		inner join PoType pot on PODETAIL.Type = pot.ID
	WHERE 
		DateOrdered > @StartDate AND SiteID IS NOT NULL AND
		((POStatusDescription in ('Closed', 'Partial') AND Received IS NOT NULL AND DATEDIFF(day,DateOrdered,Received) > @AvgLeadTime) OR
		(POStatusDescription = 'Closed' AND Received is NULL) OR
		(POStatusDescription in ('Ordered', 'Partial') AND Received is NULL AND DATEDIFF(day,DateOrdered,getdate()) > @AvgLeadTime))

	UNION ALL

	Select
		PODetail.ID,
		PO.PONumber, 
		SiteID,
		Crib,
		Item,
		DateOrdered,
		Received,
		Quantity,
		Cost,
		pot.Name as Type,
		DATEDIFF(day,DateOrdered,Received) LT,
		POStatusDescription,
		LTStatus = 'At',
		PODetailStatus = 'Fullfilled'
	FROM PODetail
		inner join PO on PO.PONumber = PODetail.PONumber
		inner join POStatus pos on PO.POStatusNo = pos.POStatusNo
		inner join PoType pot on PODETAIL.Type = pot.ID
	WHERE 
		DateOrdered > @StartDate AND SiteID IS NOT NULL AND
		(POStatusDescription in ('Closed', 'Partial') AND Received IS NOT NULL AND DATEDIFF(day,DateOrdered,Received) = @AvgLeadTime )

	UNION ALL

	Select
		PODetail.ID,
		PO.PONumber, 
		SiteID,
		Crib,
		Item,
		DateOrdered,
		Received,
		Quantity,
		Cost,
		pot.Name as Type,
		DATEDIFF(day,DateOrdered,Received) LT,
		POStatusDescription,
		LTStatus = 'Early',
		PODetailStatus = 'Fullfilled'
	FROM PODetail
		inner join PO on PO.PONumber = PODetail.PONumber
		inner join POStatus pos on PO.POStatusNo = pos.POStatusNo
		inner join PoType pot on PODETAIL.Type = pot.ID
	WHERE 
		DateOrdered > @StartDate AND SiteID IS NOT NULL AND Received is NOT NULL AND
		DATEDIFF(day,DateOrdered,Received) < @AvgLeadTime

	UNION ALL

	Select
		PODetail.ID,
		PO.PONumber, 
		SiteID,
		Crib,
		Item,
		DateOrdered,
		Received,
		Quantity,
		Cost,
		pot.Name as Type,
		DATEDIFF(day,DateOrdered,Received) LT,
		POStatusDescription,
		LTStatus = 'Open\Early',
		PODetailStatus = 'Open\Early'
	FROM PODetail
		inner join PO on PO.PONumber = PODetail.PONumber
		inner join POStatus pos on PO.POStatusNo = pos.POStatusNo
		inner join PoType pot on PODETAIL.Type = pot.ID
	WHERE 
		DateOrdered > @StartDate AND SiteID IS NOT NULL AND Received is NULL AND
		POStatusDescription in ('Partial', 'Ordered') AND DATEDIFF(day,DateOrdered,getdate()) < @AvgLeadTime

	UNION ALL

	Select
		PODetail.ID,
		PO.PONumber, 
		SiteID,
		Crib,
		Item,
		DateOrdered,
		Received,
		Quantity,
		Cost,
		pot.Name as Type,
		DATEDIFF(day,DateOrdered,Received) LT,
		POStatusDescription,
		LTStatus = 'Open\At',
		PODetailStatus = 'Open\At'
	FROM PODetail
		inner join PO on PO.PONumber = PODetail.PONumber
		inner join POStatus pos on PO.POStatusNo = pos.POStatusNo
		inner join PoType pot on PODETAIL.Type = pot.ID
	WHERE 
		DateOrdered > @StartDate AND SiteID IS NOT NULL AND Received is NULL AND
		POStatusDescription in ('Partial', 'Ordered') AND DATEDIFF(day,DateOrdered,getdate()) = @AvgLeadTime
),

POLineData AS (
	SELECT
		sp.SiteID,
		Crib,
		Item,
		sp.ParentSiteID,
		inv.ItemClass,
		ItemClassDescription,
		inv.ItemType,
		it.ItemTypeDesc,
		Count (ID) as POLinesCount,
		SUM (Quantity) as QtySum,
		SUM (Cost) as CostSum,
		SUM ( CASE WHEN PODetailStatus = 'Open\Late' OR PODetailStatus = 'Open\Early'OR PODetailStatus = 'Open\At' THEN 1 ELSE 0 END ) as POLinesOpenTotal,
		SUM ( CASE WHEN PODetailStatus = 'Open\Late' THEN 1 ELSE 0	END ) as POLinesOpenAndLate,
		SUM ( CASE WHEN PODetailStatus = 'Open\Early' THEN 1 ELSE 0 END ) as POLinesOpenAndEarly,
		SUM ( CASE WHEN PODetailStatus = 'Open\At' THEN 1 ELSE 0 END ) as POLinesOpenAndAtLT,
		SUM ( CASE WHEN LTStatus = 'Late' THEN 1 ELSE 0 END ) as POLinesLateTotal,
		SUM ( CASE WHEN LTStatus = 'Late' AND PODetailStatus = 'Fullfilled' THEN 1 ELSE 0 END ) as POLinesReceivedLate,
		SUM ( CASE WHEN LTStatus = 'At' THEN 1 ELSE 0 END ) as POLinesReceivedAtLeadTime,
		SUM ( CASE WHEN LTStatus = 'Early' THEN 1 ELSE 0 END ) as POLinesReceivedEarly

	FROM PODetails
		inner join  SiteProfile sp on PODetails.SiteID = sp.SiteID
		left outer join INVENTRY inv on PODetails.Item = inv.ItemNumber
		left outer join ItemClass ic on inv.ItemClass = ic.ItemClass
		left outer join ItemType it on inv.ItemType = it.ItemType

	GROUP BY	sp.SiteID,
				Crib,
				Item,
 				sp.ParentSiteID,
				inv.ItemClass,
				ItemClassDescription,
				inv.ItemType,
				it.ItemTypeDesc
),

POPendingData AS (
	SELECT 
	c.SiteID,
	c.Crib,
	vpwal. ItemNumber as Item,
	sp.ParentSiteID,
		inv.ItemClass,
		ItemClassDescription,
		inv.ItemType,
		it.ItemTypeDesc,
	count(ID) as 'PendingAuthorization' 
	FROM VPendingWithAltVendor vpwal
		inner join Crib c on vpwal.CRIB = c.Crib
		inner join  SiteProfile sp on c.SiteID = sp.SiteID
		left outer join INVENTRY inv on vpwal.ItemNumber = inv.ItemNumber
		left outer join ItemClass ic on inv.ItemClass = ic.ItemClass
		left outer join ItemType it on inv.ItemType = it.ItemType
	WHERE 
		(Type IS NULL OR Type = 0) 
		AND PendingOrderType IN(0,1,4) 
		AND ((AutoPurchase IS NULL OR AutoPurchase = 0) AND (StationAutoPurchase IS NULL or StationAutoPurchase = 0)) 
		AND (SuggestedQuantity IS NOT NULL OR REQDETNO IS NOT NULL OR c.CRIB IN (SELECT CRIB FROM CRIB WHERE ORDERREVIEWOPTION IS NULL OR ORDERREVIEWOPTION = 0))
		--AND (ItemNumber IS NULL OR BuyerGroupID IS NULL OR BuyerGroupID IN (Select BuyerGroupID From EmployeeBuyerGroup WHERE EmployeeID = 'E-00'))
	GROUP BY c.Crib, vpwal.ItemNumber, c.SiteID, sp.ParentSiteID, inv.ItemClass, ItemClassDescription, inv.ItemType, it.ItemTypeDesc
)

INSERT INTO XPODetailsSum
SELECT
	ISNULL(POLineData.SiteID,POPendingData.SiteID) AS SiteID,
	ISNULL(POLineData.Crib,POPendingData.Crib) AS Crib,
	ISNULL(POLineData.Item,POPendingData.Item) AS Item,
	ISNULL(POLineData.ParentSiteID,POPendingData.ParentSiteID) AS ParentSiteID,
	ISNULL(POLineData.ItemClass,POPendingData.ItemClass) AS ItemClass,
	ISNULL(POLineData.ItemClassDescription,POPendingData.ItemClassDescription) AS ItemClassDescription,
	ISNULL(POLineData.ItemType,POPendingData.ItemType) AS ItemType,
	ISNULL(POLineData.ItemTypeDesc,POPendingData.ItemTypeDesc) AS ItemTypeDesc,
	ISNULL(POLineData.POLinesCount,0) AS POLinesCount,
	ISNULL(POLineData.QtySum,0) AS QtySum,
	ISNULL(POLineData.CostSum,0) AS CostSum,
	ISNULL(PendingAuthorization,0) AS PendingAuthorization,
	ISNULL(POLineData.POLinesOpenTotal,0) AS POLinesOpenTotal,
	ISNULL(POLineData.POLinesOpenAndLate,0) AS POLinesOpenAndLate,
	ISNULL(POLineData.POLinesOpenAndAtLT,0) AS POLinesOpenAndAtLT,
	ISNULL(POLineData.POLinesOpenAndEarly,0) AS POLinesOpenAndEarly,
	ISNULL(POLineData.POLinesLateTotal,0) AS POLinesLateTotal,
	ISNULL(POLineData.POLinesReceivedLate,0) AS POLinesReceivedLate,
	ISNULL(POLineData.POLinesReceivedAtLeadTime,0) AS POLinesReceivedAtLeadTime,
	ISNULL(POLineData.POLinesReceivedEarly,0) AS POLinesReceivedEarly	
FROM 
	POLineData 
		FULL OUTER JOIN POPendingData on POPendingData.SiteID = POLineData.SiteID 
		AND POPendingData.Crib = POLineData.Crib 
		AND POPendingData.Item = POLineData.Item

order by SiteID, Crib, Item

-- create index for re-populated table
CREATE CLUSTERED INDEX IX_XPODTSUM_ST_CR ON XPODetailsSum (SiteID, Crib)

END -- PO DETAILS SUMMARIES
GO


--------------- INVENTORY HEALTH SUMMARY -------------
IF OBJECT_ID('sp_GenerateInventoryHealthSummary') IS NOT NULL
DROP PROCEDURE [dbo].sp_GenerateInventoryHealthSummary
GO

CREATE PROCEDURE sp_GenerateInventoryHealthSummary
AS
BEGIN

DECLARE @DeadStockNotIssuedOffset int
DECLARE @CurrentDate date
DECLARE @StartDate date
DECLARE @OvstCriteria int

SELECT @DeadStockNotIssuedOffset = INT FROM GLOBALSETTINGS WHERE KEYNAME = 'Dashboard_DeadStockNotIssuedOffset'
IF @DeadStockNotIssuedOffset IS NULL
   SET @DeadStockNotIssuedOffset = 150
SELECT @StartDate = DATEADD(d, -@DeadStockNotIssuedOffset, GETDATE());

SELECT @OvstCriteria = INT FROM GLOBALSETTINGS WHERE KEYNAME = 'Dashboard_OverstockCriteria'
IF @OvstCriteria IS NULL
   SET @OvstCriteria = 0

-- If table doesn't exist, create one
IF OBJECT_ID('XInventoryHealth') IS NULL
CREATE TABLE XInventoryHealth(
	SiteID varchar(12) NOT NULL,
	[Site Description] varchar(50),
	ParentSiteID varchar(12),
	Crib smallint,
	[Crib Name] varchar(50),
	[Crib Type] varchar(50),
	Item varchar(25),
	[Item Description] varchar(50),
	ItemClass varchar(15),
	ItemType varchar(32),
	Overstock int,
	[Dead Stock] int,
	[Below Min] int,
	[Below Critical] int,
	[Out Of Stock] int,
	Lost int,
	Unusable int,
	[In Repair] int,
	[Scheduled CC] int,
	[Due Cycle Count] int,
	[Pending Rework] int, 
	[Total Inventory] decimal(19,4),
	[Inventory Qty] int,
	[Checked Out Cost] decimal(19,4),
	[Checked Out Qty] int,
	[Due Calibration] int
) -- drop table XInventoryHealth

-- delete index if it exists
IF EXISTS(SELECT * FROM sys.indexes WHERE name='IX_XINVHLTH_ST_CR' AND object_id = OBJECT_ID('XInventoryHealth'))
	DROP INDEX IX_XINVHLTH_ST_CR ON XInventoryHealth

TRUNCATE TABLE XInventoryHealth;

With StationAggregated AS (
	SELECT 
		Crib.SiteID,
		STATION.Item,
		STATION.Crib,
		STATION.CribBin,
		ISNULL(OnOrder, 0) AS OnOrder,
		ISNULL(Quantity, 0) AS Quantity,
		ISNULL(BinQuantity, 0) AS BinQuantity,
		ISNULL(TotalPrice, 0) AS TotalPrice,
		ISNULL(Maximum, 0) AS Maximum,
		ISNULL(OverrideOrderPoint, OrderPoint) AS OrderPoint,
		DateLastIssue,
		DateLastReceipt,
		StopOrdering,
		CriticalPoint,
		((CASE WHEN sh.prev1 < 0 THEN 0 ELSE ISNULL(sh.prev1,0) END +
			CASE WHEN sh.Prev2 < 0 THEN 0 ELSE ISNULL(sh.Prev2,0) END +
			CASE WHEN sh.Prev3 < 0 THEN 0 ELSE ISNULL(sh.Prev3,0) END +
			CASE WHEN sh.Prev4 < 0 THEN 0 ELSE ISNULL(sh.Prev4,0) END +
			CASE WHEN sh.Prev5 < 0 THEN 0 ELSE ISNULL(sh.Prev5,0) END +
			CASE WHEN sh.Prev6 < 0 THEN 0 ELSE ISNULL(sh.Prev6,0) END +
			CASE WHEN sh.Prev7 < 0 THEN 0 ELSE ISNULL(sh.Prev7,0) END +
			CASE WHEN sh.Prev8 < 0 THEN 0 ELSE ISNULL(sh.Prev8,0) END +
			CASE WHEN sh.Prev9 < 0 THEN 0 ELSE ISNULL(sh.Prev9,0) END +
			CASE WHEN sh.Prev10 < 0 THEN 0 ELSE ISNULL(sh.Prev10,0) END +
			CASE WHEN sh.Prev11 < 0 THEN 0 ELSE ISNULL(sh.Prev11,0) END +
			CASE WHEN sh.Prev12 < 0 THEN 0 ELSE ISNULL(sh.Prev12,0) END) / 12 ) AS AvgUsage
	FROM STATION
		inner join crib
		    on STATION.Crib = Crib.Crib
        LEFT outer JOIN StationHistory sh
		    ON STATION.CribBin = sh.CribBin
	WHERE
	    item is not null and (BinType = 0 or BinType is NULL)

UNION ALL

	SELECT 
		Crib.SiteID,
		s.Item,
		s.Crib,
		CASE WHEN s.BinType = 3 THEN ss.CribBin ELSE s.CribBin END AS CribBin,
		MAX(ISNULL(ss.OnOrder, 0)) AS OnOrder,
		SUM(ISNULL(s.Quantity, 0)) AS Quantity,
		SUM(ISNULL(s.BinQuantity, 0)) AS BinQuantity,
		SUM(ISNULL(s.TotalPrice, 0)) AS TotalPrice,
		MAX(ISNULL(ss.Maximum, 0)) AS Maximum,
		MAX(ISNULL(ss.OverrideOrderPoint, ss.OrderPoint)) as OrderPoint,
		MAX(s.DateLastIssue) AS DateLastIssue,
		MAX(s.DateLastReceipt) AS DateLastReceipt,
		MAX(CAST(ss.StopOrdering AS INT)) AS StopOrdering,
		MAX(ss.CriticalPoint) AS CriticalPoint,
		SUM(((CASE WHEN sh.prev1 < 0 THEN 0 ELSE ISNULL(sh.prev1,0) END +
			CASE WHEN sh.Prev2 < 0 THEN 0 ELSE ISNULL(sh.Prev2,0) END +
			CASE WHEN sh.Prev3 < 0 THEN 0 ELSE ISNULL(sh.Prev3,0) END +
			CASE WHEN sh.Prev4 < 0 THEN 0 ELSE ISNULL(sh.Prev4,0) END +
			CASE WHEN sh.Prev5 < 0 THEN 0 ELSE ISNULL(sh.Prev5,0) END +
			CASE WHEN sh.Prev6 < 0 THEN 0 ELSE ISNULL(sh.Prev6,0) END +
			CASE WHEN sh.Prev7 < 0 THEN 0 ELSE ISNULL(sh.Prev7,0) END +
			CASE WHEN sh.Prev8 < 0 THEN 0 ELSE ISNULL(sh.Prev8,0) END +
			CASE WHEN sh.Prev9 < 0 THEN 0 ELSE ISNULL(sh.Prev9,0) END +
			CASE WHEN sh.Prev10 < 0 THEN 0 ELSE ISNULL(sh.Prev10,0) END +
			CASE WHEN sh.Prev11 < 0 THEN 0 ELSE ISNULL(sh.Prev11,0) END +
			CASE WHEN sh.Prev12 < 0 THEN 0 ELSE ISNULL(sh.Prev12,0) END) / 12 )) AS AvgUsage
	FROM STATION s
		left outer join STATION ss on ss.CribBin = s.PrimaryCribBin AND ss.BinType = 2
		inner join crib on s.Crib = Crib.Crib
        LEFT outer JOIN StationHistory sh ON s.CribBin = sh.CribBin
	WHERE
		s.item is not null and  s.BinType <> 0 and s.BinType <> 1 and s.BinType is NOT NULL
		and CASE WHEN s.BinType = 3 THEN ss.CribBin ELSE s.CribBin END is not null
	GROUP BY Crib.SiteID, s.Item, s.Crib, CASE WHEN s.BinType = 3 THEN ss.CribBin ELSE s.CribBin END
),

--//////////////////// Overstock ////////////////////////
OverStock AS(
	SELECT 
		Crib.SiteID AS SiteID, 
		Crib.Crib AS Crib,
		Item,
		count(CribBin) AS 'Overstock'
	FROM StationAggregated sa
		inner join crib
			on sa.Crib = Crib.Crib
	WHERE 
	     Quantity > 0 AND
		(Quantity + OnOrder) >	CASE WHEN @OvstCriteria = 0 THEN  Maximum
									WHEN @OvstCriteria = 1 THEN AvgUsage 
									ELSE Maximum 
								END
	GROUP BY Crib.SiteID, Crib.Crib, Item--, ItemDesc, ITEMCLASS
),

--//////////////////// Deadstock ////////////////////////
DeadStock AS ( 
	SELECT 
		c.SiteID AS SiteID,
		c.Crib AS Crib,
		Item,
		count(CribBin) AS 'DeadStock'
	FROM   
		StationAggregated sa 
			INNER JOIN Crib c on sa.Crib = c.Crib
	WHERE
		(sa.DateLastIssue IS NULL OR sa.DateLastIssue <= @StartDate)     
		AND (sa.DateLastReceipt IS NULL OR sa.DateLastReceipt <= @StartDate) 
		AND sa.BinQuantity > 0
	group by c.SiteID, c.Crib, Item
),

--//////////////////// Below Min ////////////////////////
BelowMin AS (
	SELECT 
		c.SiteID AS SiteID,
		c.Crib AS Crib,
		Item,
		count(CribBin) AS 'BelowMin'
	FROM
		StationAggregated sa
			INNER JOIN Crib c ON sa.Crib = c.Crib
	WHERE StopOrdering <> 1 
		AND sa.Item is not null
		AND ((sa.BinQuantity < sa.OrderPoint) AND sa.OrderPoint <> -1)
	GROUP BY c.SiteID, c.Crib, Item
),

--//////////////////// Below Critical ////////////////////////
BelowCritical as (
	SELECT 
		c.SiteID as SiteID,
		c.Crib as Crib,
		Item,
		count(CribBin) as 'BelowCrit'
	FROM
		StationAggregated sa
			INNER JOIN Crib c ON sa.Crib = c.Crib
	WHERE StopOrdering <> 1 
		AND ((sa.BinQuantity < CriticalPoint) AND sa.OrderPoint <> -1)
	GROUP BY c.SiteID, c.Crib, Item--, Description1, INVENTRY.ItemClass
),

--//////////////////// Out of Stock ////////////////////////
OutOfStock as (
	SELECT 
		c.SiteID as SiteID,
		c.Crib as Crib,
		Item,
		count(CribBin) as 'OutOfStock'
	FROM
		StationAggregated sa
			INNER JOIN Crib c ON sa.Crib = c.Crib
	WHERE StopOrdering <> 1 
		AND ((sa.BinQuantity = 0) AND sa.OrderPoint <> -1)
	GROUP BY c.siteid, c.Crib, Item
),

--///////////////////// Bins Scheduled ///////////////////////////////////////
ScheduledCC as (
	SELECT
		c.SiteID,
		ii.Crib,
		ii.ItemNumber AS Item,
		count(ii.CribBin) AS SceduledCC 	
	FROM ItemInventory ii
		INNER JOIN Station s on s.CribBin = ii.CribBin AND s.Item = ii.ItemNumber -- Make sure that only existing CribBins\ItemNumber are counted 
		INNER JOIN Crib c ON ii.Crib = c.Crib
	WHERE DATECOUNTED IS NULL
	Group by c.SiteID, ii.Crib, ii.ItemNumber
),

--///////////////////// Bins Past Due ///////////////////////////////////////
PastDueCC as (
	SELECT
		c.SiteID,
		ii.Crib,
		ii.ItemNumber AS Item,
		count(ii.CribBin) AS PastDueCC 	
	FROM ItemInventory ii
		INNER JOIN Station s on s.CribBin = ii.CribBin AND s.Item = ii.ItemNumber -- Make sure that only existing CribBins\ItemNumber are counted 
		INNER JOIN Crib c ON ii.Crib = c.Crib
	WHERE DATECOUNTED IS NULL AND DATEDUE <= getdate()
	Group by c.SiteID, ii.Crib, ii.ItemNumber
),

--//////////////////////// Unusable //////////////////////////////////////////
Unusable as (
	SELECT
		c.SiteID,
		c.Crib,
		isr.ItemNumber as Item,
		count(isr.SerialID) Unusable 
	FROM ItemSerial isr
		INNER JOIN SerialStatus ss on isr.Status = ss.Status
		INNER JOIN Station s on isr.CribBin = s.CribBin
		INNER JOIN Crib c on s.Crib = c.Crib

	WHERE ss.StatusDesc = 'Unusable'
	Group By 	c.SiteID, c.Crib, isr.ItemNumber--, Description1, inv.ItemClass
),

statushistory as (
	select sh1.serialid,sh2.cribbin
	from
	(
		select serialid,max(statushistoryid) as shID
		from serialstatushistory
		where cribbin is not null and cribbin not like '!%'
		group by serialid
	) AS sh1
		inner join serialstatushistory sh2
			on sh1.shid = sh2.statushistoryid
),

--//////////////////////// Lost //////////////////////////////////////////
Lost as (
	SELECT
		c.SiteID,
		c.Crib,
		isr.ItemNumber as Item,
		count(isr.SerialID) Lost 
	FROM ItemSerial isr
		INNER JOIN SerialStatus ss on isr.Status = ss.Status
		INNER JOIN statushistory sh on sh.SerialId = isr.SerialID
		INNER JOIN Station s on sh.CribBin = s.CribBin
		INNER JOIN Crib c on s.Crib = c.Crib

	WHERE ss.StatusDesc = 'Lost'
	Group By 	c.SiteID, c.Crib, isr.ItemNumber
),

--///////////////////// In Repair ///////////////////////////////////////
InRepair as (
	SELECT
		c.SiteID,
		c.Crib,
		isr.ItemNumber as Item,
		count(isr.SerialID) AS InRepair 
	FROM ItemSerial isr
		INNER JOIN SerialStatus ss on isr.Status = ss.Status
		INNER JOIN statushistory sh on sh.SerialId = isr.SerialID
		INNER JOIN Station s on sh.CribBin = s.CribBin
		INNER JOIN Crib c on s.Crib = c.Crib

	WHERE ss.StatusDesc = 'In Repair'
	Group By 	c.SiteID, c.Crib, isr.ItemNumber 
),

--///////////////////// Pending Rework ///////////////////////////////////////
PendingRework as (
	SELECT
		c.SiteID,
		c.Crib,
		Item,
		Count(Item) AS PendingRework
	FROM STATION s
		INNER JOIN Crib c ON s.Crib = c.Crib
	where s.PendingRework > 0
	Group by c.SiteID, c.Crib, Item
),

--/////////////////////// Total Inventory Value /////////////////////////////////
InventoryValue as (
	SELECT
		c.SiteID,
		c.Crib,
		Item,
		SUM(ISNULL(TotalPrice, 0)) AS InvValue
	FROM STATION s
		INNER JOIN Crib c ON s.Crib = c.Crib 
	WHERE s.Item IS NOT NULL
	group by 	c.SiteID, c.Crib, Item
),

--/////////////////////// Total Inventory Qty /////////////////////////////////
InventoryQty as (
	SELECT
		c.SiteID,
		c.Crib,
		Item,
		SUM(s.Quantity) AS InvQty
	FROM STATION s
		INNER JOIN Crib c ON s.Crib = c.Crib 
	WHERE s.Item IS NOT NULL
	group by 	c.SiteID, c.Crib, Item
),

--/////////////////////// Checked Out Items Cost /////////////////////////////////
CheckedOutCost as (
	SELECT
		c.SiteID,
		c.Crib,
		co.Item as Item,
        SUM(ISNULL(co.Cost, 0)) as CheckedOutCost

	FROM CHECKOUT co
		INNER JOIN STATION s ON s.CribBin = co.CribBin
		INNER JOIN Crib c ON c.Crib = s.Crib
	GROUP BY c.SiteID, c.Crib, co.Item
),

--/////////////////////// Checked Out Items Qty /////////////////////////////////
CheckedOutQty as (
	SELECT
		c.SiteID,
		c.Crib,
		co.Item as Item,
        SUM(ISNULL(co.Quantity, 0)) as CheckedOutQty

	FROM CHECKOUT co
		INNER JOIN STATION s ON s.CribBin = co.CribBin
		INNER JOIN Crib c ON c.Crib = s.Crib
	GROUP BY c.SiteID, c.Crib, co.Item
),

--/////////////////////// Past Calibration Gauges /////////////////////////////////
PastCalibration as (
	SELECT 
		c.SiteID,
		c.Crib,
		itms.ItemNumber as Item,
		SUM(s.Quantity) AS PastCalib
	FROM ItemSerial itms
		INNER JOIN Inventry inv ON inv.ItemNumber = itms.ItemNumber
		INNER JOIN Station s ON s.CribBin = itms.CribBin
		INNER JOIN Crib c ON c.Crib = s.Crib
	WHERE SERIALID IN (SELECT SERIALID FROM GAUGE WHERE NEXTCERTIFYDATE < GetDate())
		AND itms.Status NOT IN ( 4,7,8,9 ) -- Not in OutOfService, InCalibration, Lost, Off-Site
	group by 	c.SiteID, c.Crib, itms.ItemNumber
),

-- Building total table with distinct Site, crib and item compasite
Total as (
	SELECT Distinct SiteID, Crib, Item from OverStock
	UNION 
	SELECT Distinct SiteID, Crib, Item from DeadStock
	UNION
	SELECT Distinct SiteID, Crib, Item from BelowMin
	Union
	SELECT Distinct SiteID, Crib, Item from BelowCritical
	UNION
	SELECT Distinct SiteID, Crib, Item from OutOfStock
	UNION 
	SELECT Distinct SiteID, Crib, Item from Lost
	UNION
	SELECT Distinct SiteID, Crib, Item from Unusable
	Union
	SELECT Distinct SiteID, Crib, Item from InRepair
	UNION 
	SELECT Distinct SiteID, Crib, Item from ScheduledCC
	UNION
	SELECT Distinct SiteID, Crib, Item from PastDueCC
	Union
	SELECT Distinct SiteID, Crib, Item from PendingRework
	Union
	SELECT Distinct SiteID, Crib, Item from InventoryValue
	Union
	SELECT Distinct SiteID, Crib, Item from InventoryQty
	Union
	SELECT Distinct SiteID, Crib, Item from CheckedOutCost 
	Union
	SELECT Distinct SiteID, Crib, Item from CheckedOutQty
	Union
	SELECT Distinct SiteID, Crib, Item from PastCalibration
)  

INSERT INTO XInventoryHealth

SELECT
	tot.SiteID as SiteID,
	SiteDescription,
	ParentSiteID,
	tot.Crib as Crib,
	c.Name as CribName,
	ct.Description CribType,
	tot.Item as Item,
	Description1 AS ItemDesc,
	ISNULL(inv.ItemClass,'(None)') AS ItemGroup,
	ItemTypeDesc,
	ISNULL(Overstock,0) AS Overstock,
	ISNULL(DeadStock,0) AS DeadStock,
	ISNULL(BelowMin,0) AS BelowMin,
	ISNULL(BelowCrit,0) AS BelowCrit,
	ISNULL(OutOfStock,0) AS OutOfStock,
	ISNULL(Lost,0) AS Lost,
	ISNULL(Unusable,0) AS Unusable,
	ISNULL(InRepair,0) AS InRepair,
	ISNULL(SceduledCC,0) AS ScheduledCC,
	ISNULL(PastDueCC,0) AS PastDueCC,
	ISNULL(PendingRework,0) AS PendingRework,
	ISNULL(InvValue,0) AS InvValue,
	ISNULL(InvQty,0) AS InvQty,
	ISNULL(CheckedOutCost,0) AS CheckedOutCost,
	ISNULL(CheckedOutQty,0) AS CheckedOutQty,
	ISNULL(PastCalib,0) AS PastCalib

FROM Total tot
    left outer join OverStock ovs on ovs.SiteID = tot.SiteID AND ovs.Crib = tot.Crib AND ovs.Item = tot.Item
    left outer join DeadStock ds on ds.SiteID = tot.SiteID AND ds.Crib = tot.Crib AND ds.Item = tot.Item
    left outer join BelowMin bm on bm.SiteID = tot.SiteID AND bm.Crib = tot.Crib AND bm.Item = tot.Item
    left outer join BelowCritical bc on bc.SiteID = tot.SiteID AND bc.Crib = tot.Crib AND bc.Item = tot.Item
    left outer join OutOfStock ous on ous.SiteID = tot.SiteID AND ous.Crib = tot.Crib AND ous.Item = tot.Item
    left outer join Lost  l on l.SiteID = tot.SiteID AND l.Crib = tot.Crib AND l.Item = tot.Item
    left outer join Unusable uu on uu.SiteID = tot.SiteID AND uu.Crib = tot.Crib AND uu.Item = tot.Item
    left outer join InRepair ir on ir.SiteID = tot.SiteID AND ir.Crib = tot.Crib AND ir.Item = tot.Item
    left outer join ScheduledCC sch on sch.SiteID = tot.SiteID AND sch.Crib = tot.Crib AND sch.Item = tot.Item
    left outer join PastDueCC pd on pd.SiteID = tot.SiteID AND pd.Crib = tot.Crib AND pd.Item = tot.Item
    left outer join PendingRework pr on pr.SiteID = tot.SiteID AND pr.Crib = tot.Crib AND pr.Item = tot.Item
    left outer join CheckedOutCost coc on coc.SiteID = tot.SiteID AND coc.Crib = tot.Crib AND coc.Item = tot.Item
    left outer join CheckedOutQty coq on coq.SiteID = tot.SiteID AND coq.Crib = tot.Crib AND coq.Item = tot.Item
    left outer join PastCalibration pc on pc.SiteID = tot.SiteID AND pc.Crib = tot.Crib AND pc.Item = tot.Item
    left outer join InventoryValue iv on iv.SiteID = tot.SiteID AND iv.Crib = tot.Crib AND iv.Item = tot.Item
    left outer join InventoryQty iq on iq.SiteID = tot.SiteID AND iq.Crib = tot.Crib AND iq.Item = tot.Item

	LEFT OUTER JOIN INVENTRY inv ON tot.Item = inv.ItemNumber
	LEFT OUTER JOIN ItemType it ON it.ItemType = inv.ItemType
	LEFT OUTER JOIN SiteProfile sp ON tot.SiteID = sp.SiteID
	LEFT OUTER JOIN Crib c ON tot.Crib = c.Crib
	left OUTER JOIN CribType ct ON c.CribType = ct.CribType

ORDER BY  SiteID, Crib, Item

-- create index for re-populated table
CREATE CLUSTERED INDEX IX_XINVHLTH_ST_CR ON XInventoryHealth (SiteID, Crib)

END -- INV HEALTH SUMMARY
GO

--------------- GENERATE DASHBOARD SUMMARIES -------------
IF OBJECT_ID('GenerateDashboardSummaries') IS NOT NULL
DROP PROCEDURE [dbo].[GenerateDashboardSummaries]
GO

CREATE PROCEDURE GenerateDashboardSummaries
AS
BEGIN

	EXEC sp_GenerateSiteUsageSummaries
	EXEC sp_GenerateEmployeeUsageSummaries
	EXEC sp_GenerateInventoryHealthSummary
	EXEC sp_GeneratePODetailsSummaries
 
END 
GO

-- If view exists, drop it and re-create one
IF Object_ID('VXLotsToBeExpired') IS NOT NULL
	DROP VIEW VXLotsToBeExpired
GO

CREATE VIEW VXLotsToBeExpired
AS  
SELECT
	LotNo,
	LotItemNumber as Item,
	LotExpirationDate,
	DATEDIFF(DAY,getdate(),LotExpirationDate) as [Days Due In],
	STATION.Crib,
	SiteID  
FROM LotNumber
      INNER JOIN STATION ON STATION.Item = LotNumber.LotItemNumber
      INNER JOIN Crib ON Crib.Crib = STATION.Crib
WHERE LotExpirationDate IS NOT NULL AND LotExpirationDate < dateadd(dd,30,getdate());
--drop VIEW VXLotsToBeExpired	     

GO

-- If view exists, drop it and re-create one
IF Object_ID ('VXATRStatus') IS NOT NULL
	DROP VIEW VXATRStatus

GO

CREATE VIEW VXATRStatus
as
SELECT 
	sp.SiteID
	,Latitude
	,Longitude
	,Crib.Crib as Crib
	,Action
	,LastSyncDate
	, 
      CASE 
		WHEN Action like '%Error' THEN 'Error'
		WHEN DATEDIFF(hour, LastSyncDate, GetDate()) > ISNULL( (SELECT INT FROM GLOBALSETTINGS WHERE KEYNAME = 'Dashboard_ATRSyncOffset'), 2 )
		OR (Action not like '%ReadyToVend%' AND Action not like '%VendInProcess' ) OR LastSyncDate is NULL THEN 'Offline'  
        ELSE 'Online'  
      END AS CribStatus
	, DATEDIFF(hour, LastSyncDate, GetDate()) as 'Time Not Sync (hr)'

FROM NetStatX
	INNER JOIN Crib ON Crib.Crib = StationNumber
	INNER JOIN SiteProfile sp on sp.SiteID = Crib.SiteID
--drop VIEW VXATRStatus	

GO

-- If view exists, drop it and re-create one
IF Object_ID ('VXATRLoginHistory') IS NOT NULL
	DROP VIEW VXATRLoginHistory

GO

CREATE VIEW VXATRLoginHistory
as
SELECT 
	SiteID
	,Crib.Crib as Crib
	,DATEADD(m, DATEDIFF(m, 0, LoginHistoryDate), 0) AS 'Login Month'
	,COUNT(LoginHistoryDate) as '# of Logins'
FROM LoginHistory
	INNER JOIN Crib ON Crib.DeviceComputerName = TerminalID
WHERE  
	Application = 'CMVEND' AND 
	DATEDIFF(m, LoginHistoryDate, GetDate()) < ISNULL( (SELECT INT FROM GLOBALSETTINGS WHERE KEYNAME = 'Dashboard_ProcessUsageMonths'), 12)
	GROUP BY SiteID, Crib, DATEADD(m, DATEDIFF(m, 0, LoginHistoryDate), 0)
--drop VIEW VXATRLoginHistory

GO

	
-- If view exists, drop it and re-create one
IF Object_ID ('VXStockoutItems') IS NOT NULL
	DROP VIEW VXStockoutItems
GO

CREATE VIEW VXStockoutItems
as
SELECT 
	SiteID
	,c.Crib
	,e.ItemNumber
	,i.Description1 as 'Item Name'
    ,DATEADD(d, DATEDIFF(d, 0, EventDate), 0) AS 'Date'
	,count(EventDate) as '# Of Stockouts'
FROM [Events] e
	inner join Station s on s.CribBin = e.CribBin
	inner join Crib c on c.crib = s.Crib
	inner join Inventry i on i.ItemNumber = e.ItemNumber
WHERE Description like 'Out of Stock%' AND DATEDIFF(m, EventDate, GetDate()) < ISNULL( (SELECT INT FROM GLOBALSETTINGS WHERE KEYNAME = 'Dashboard_ProcessUsageMonths'), 12)
GROUP BY SiteID, c.Crib, e.ItemNumber,i.Description1, DATEADD(d, DATEDIFF(d, 0, EventDate), 0)
--drop VIEW VXStockoutItems

GO