--------------- SITE USAGE SUMMARIES -------------
IF OBJECT_ID('sp_GenerateSiteUsageSummaries') IS NOT NULL
DROP PROCEDURE [dbo].[sp_GenerateSiteUsageSummaries]
GO

CREATE PROCEDURE sp_GenerateSiteUsageSummaries
AS
BEGIN

-- Compute start date from number of months in stored option
DECLARE @StartDate date
DECLARE @DashboardMonths int
SELECT @DashboardMonths = INT FROM GLOBALSETTINGS WHERE KEYNAME = 'Dashboard_ProcessUsageMonths'
IF @DashboardMonths IS NULL 
   SET @DashboardMonths = 24
SELECT @StartDate = DATEADD(m, -@DashboardMonths, GETDATE())

-- delete index if it exists
IF EXISTS(SELECT * FROM sys.indexes WHERE name='IX_XTRANS_ST_CLS' AND object_id = OBJECT_ID('XTransDay'))
	DROP INDEX IX_XTRANS_ST_CLS ON XTransDay

TRUNCATE TABLE XTransDay
INSERT INTO XTransDay
SELECT	DATEADD(dd, DATEDIFF(dd, 0, TRANS.Transdate), 0) AS TransMonth,
		SiteID,
		TRANS.Item,
		Max(Description1) AS 'Item Description',
		TypeDescription,
		ISNULL(ItemClass,'(None)'),
		INVENTRY.ItemType,
		ItemTypeDesc,
		SUM(ISNULL(Cost,0)) AS 'Sum Cost',
		SUM(ISNULL(TRANS.Quantity,0)) AS 'Sum Qty',
		COUNT(distinct TRANS.Item) as 'Distinct Item Count',
		COUNT(TRANS.item) AS 'Item Count',
		STATION.Consignment,
		TRANS.Crib,
		TRANS.User1,
		TRANS.User2,
		TRANS.User3,
		TRANS.User4,
		TRANS.User5,
		TRANS.User6
FROM        TRANS (nolock)
INNER JOIN  INVENTRY (nolock) ON TRANS.Item = INVENTRY.ItemNumber
INNER JOIN  ItemType (nolock) ON INVENTRY.ItemType = ItemType.ItemType
INNER JOIN  Crib (nolock) ON TRANS.Crib = Crib.Crib 
INNER JOIN  STATION (nolock) ON STATION.Cribbin = TRANS.cribbin
WHERE	    TRANS.Transdate > @StartDate
GROUP BY    DATEADD(dd, DATEDIFF(dd, 0, TRANS.Transdate), 0), SiteID, TRANS.Item, ItemClass, INVENTRY.ItemType, ItemTypeDesc, TypeDescription, STATION.Consignment, TRANS.Crib,
		  TRANS.User1, TRANS.User2, TRANS.User3, TRANS.User4, TRANS.User5, TRANS.User6

-- create index for re-populated table
CREATE CLUSTERED INDEX IX_XTRANS_ST_CLS ON XTransDay (SiteID, ItemClass)

TRUNCATE TABLE XTransMonth
INSERT INTO XTransMonth
SELECT	DATEADD(m, DATEDIFF(m, 0, Transdate), 0) AS TransMonth,
		SiteID,
		Item,
		Max(Description1) AS 'Item Description',
		TypeDescription,
		ItemClass,
		ItemType,
		ItemTypeDesc,
		SUM(ISNULL(CostSum,0)) AS 'Sum Cost',
		SUM(ISNULL(QtySum,0)) AS 'Sum Qty',
		SUM(DistinctItemCount),
		SUM(ItemCount),
		Consignment,
		Crib,
		User1,
		User2,
		User3,
		User4,
		User5,
		User6
FROM        XTransDay
GROUP BY    DATEADD(m, DATEDIFF(m, 0, Transdate), 0), SiteID, Item, ItemClass, ItemType, ItemTypeDesc, TypeDescription, Consignment, Crib,
		  User1, User2, User3, User4, User5, User6

-- If table doesn't exist, create one
IF OBJECT_ID('XTransWeek') IS NULL
CREATE TABLE XTransWeek(
	[TransDate] [datetime] NOT NULL,
	[SiteID] [varchar](12) NULL,
	[Item] [varchar](30) NULL,
	[Description1] [varchar](50) NULL,
	[TypeDescription] [varchar](5) NULL,
	[ItemClass] [varchar](15) NULL,
	[ItemType] [int] NULL,
	[ItemTypeDesc] [varchar](32) NULL,
	[CostSum] [decimal](19, 4) NULL,
	[QtySum] [int] NULL,
	[DistinctItemCount] [int] NULL,
	[ItemCount] [int] NULL,
	[Consignment] [int] NULL,
	[Crib] [smallint] NULL,
	[User1] [varchar](20) NULL,	
	[User2] [varchar](20) NULL,	
	[User3] [varchar](20) NULL,	
	[User4] [varchar](20) NULL,	
	[User5] [varchar](20) NULL,	
	[User6] [varchar](20) NULL	
)
--DROP TABLE XPODetails;

TRUNCATE TABLE XTransWeek
INSERT INTO XTransWeek
SELECT	DATEADD(wk, DATEDIFF(wk, 0, Transdate), 0) AS TransWeek,
		SiteID,
		Item,
		Max(Description1) AS 'Item Description',
		TypeDescription,
		ItemClass,
		ItemType,
		ItemTypeDesc,
		SUM(ISNULL(CostSum,0)) AS 'Sum Cost',
		SUM(ISNULL(QtySum,0)) AS 'Sum Qty',
		SUM(DistinctItemCount),
		SUM(ItemCount),
		Consignment,
		Crib,
		User1,
		User2,
		User3,
		User4,
		User5,
		User6
FROM        XTransDay
GROUP BY    DATEADD(wk, DATEDIFF(wk, 0, Transdate), 0), SiteID, Item, ItemClass, ItemType, ItemTypeDesc, TypeDescription, Consignment, Crib,
		  User1, User2, User3, User4, User5, User6

-- Record last date tables updated so status can be monitored
IF EXISTS (SELECT * FROM GLOBALSETTINGS WHERE KEYNAME = 'Dashboard_LastSummaryDate')
	UPDATE GLOBALSETTINGS SET STRING = convert(varchar, GETDATE(),120) WHERE KEYNAME ='Dashboard_LastSummaryDate'
ELSE
	INSERT INTO GLOBALSETTINGS (KEYNAME, STRING) VALUES ('Dashboard_LastSummaryDate', convert(varchar, GETDATE(),120))

END -- SITE USAGE SUMMARIES
GO


--------------- EMPLOYEE USAGE SUMMARIES ----------------------
IF OBJECT_ID('sp_GenerateEmployeeUsageSummaries') IS NOT NULL
DROP PROCEDURE [dbo].[sp_GenerateEmployeeUsageSummaries]
GO

CREATE PROCEDURE sp_GenerateEmployeeUsageSummaries
AS
BEGIN

-- Compute start date from number of months in stored option
DECLARE @StartDate date
DECLARE @DashboardMonths int
SELECT @DashboardMonths = INT FROM GLOBALSETTINGS WHERE KEYNAME = 'Dashboard_ProcessUsageMonths'
IF @DashboardMonths IS NULL 
   SET @DashboardMonths = 24
SELECT @StartDate = DATEADD(m, -@DashboardMonths, GETDATE())

-- delete index if it exists
IF EXISTS(SELECT * FROM sys.indexes WHERE name='IX_XEMPL_EMPL_CLS' AND object_id = OBJECT_ID('XEmployeeDay'))
	DROP INDEX IX_XEMPL_EMPL_CLS ON XEmployeeDay

TRUNCATE TABLE XEmployeeDay
INSERT INTO XEmployeeDay
SELECT	DATEADD(dd, DATEDIFF(dd, 0, TRANS.Transdate), 0) AS TransMonth,
		SiteID,
		EMPLOYEE.ID,
		Max(EMPLOYEE.Name),
		ItemNumber,
		Max(Description1) AS 'Item Description',
		TypeDescription,
		ISNULL(ItemClass,'(None)'),
		INVENTRY.ItemType,
		ItemTypeDesc,
		SUM(ISNULL(Cost,0)) AS 'Sum Cost',
		SUM(ISNULL(TRANS.Quantity,0)) AS 'Sum Qty',
		COUNT(distinct TRANS.Item) as 'Distinct Item Count',
		COUNT(TRANS.item) AS 'Item Count',
		STATION.Consignment,
		TRANS.Crib,
		TRANS.User1,
		TRANS.User2,
		TRANS.User3,
		TRANS.User4,
		TRANS.User5,
		TRANS.User6
FROM        TRANS (nolock)
INNER JOIN  INVENTRY (nolock) ON TRANS.Item = INVENTRY.ItemNumber
INNER JOIN  EMPLOYEE (nolock) ON TRANS.employee = EMPLOYEE.ID
INNER JOIN  ItemType (nolock) ON INVENTRY.ItemType = ItemType.ItemType
INNER JOIN  Crib (nolock) ON TRANS.Crib = Crib.Crib 
INNER JOIN  STATION (nolock) ON STATION.Cribbin = TRANS.cribbin
WHERE 	    TRANS.Transdate > @StartDate 
GROUP BY    DATEADD(dd, DATEDIFF(dd, 0, TRANS.Transdate), 0), SiteID, EMPLOYEE.ID, ItemNumber, TRANS.Item, ItemClass, INVENTRY.ItemType, ItemTypeDesc, TypeDescription, STATION.Consignment, TRANS.Crib,
		  TRANS.User1, TRANS.User2, TRANS.User3, TRANS.User4, TRANS.User5, TRANS.User6

-- create index for re-populated table
CREATE CLUSTERED INDEX IX_XEMPL_EMPL_CLS ON XEmployeeDay (EmployeeID, ItemClass)

TRUNCATE TABLE XEmployeeMonth
INSERT INTO XEmployeeMonth
SELECT	DATEADD(m, DATEDIFF(m, 0, Transdate), 0) AS TransMonth,
		SiteID,
		EmployeeID,
		Max(EmployeeName),
		Item,
		Max(Description1) AS 'Item Description',
		TypeDescription,
		ItemClass,
		ItemType,
		ItemTypeDesc,
		SUM(ISNULL(CostSum,0)),
		SUM(ISNULL(QtySum,0)),
		SUM(DistinctItemCount),
		SUM(ItemCount),
		Consignment,
		Crib,
		User1,
		User2,
		User3,
		User4,
		User5,
		User6
FROM        XEmployeeDay (nolock)
GROUP BY    DATEADD(m, DATEDIFF(m, 0, Transdate), 0), SiteID, EmployeeID, EmployeeName, Item, ItemClass, ItemType, ItemTypeDesc, TypeDescription, Consignment, Crib,
		  User1, User2, User3, User4, User5, User6

-- If table doesn't exist, create one
IF OBJECT_ID('XEmployeeWeek') IS NULL
CREATE TABLE XEmployeeWeek(
	[TransDate] [datetime] NOT NULL,
	[SiteID] [varchar](12) NULL,
	[EmployeeID] [varchar](12) NULL,
	[EmployeeName] [varchar](50) NULL,	
	[Item] [varchar](30) NULL,
	[Description1] [varchar](50) NULL,
	[TypeDescription] [varchar](5) NULL,
	[ItemClass] [varchar](15) NULL,
	[ItemType] [int] NULL,
	[ItemTypeDesc] [varchar](32) NULL,
	[CostSum] [decimal](19, 4) NULL,
	[QtySum] [int] NULL,
	[DistinctItemCount] [int] NULL,
	[ItemCount] [int] NULL,
	[Consignment] [int] NULL,
	[Crib] [smallint] NULL,
	[User1] [varchar](20) NULL,	
	[User2] [varchar](20) NULL,	
	[User3] [varchar](20) NULL,	
	[User4] [varchar](20) NULL,	
	[User5] [varchar](20) NULL,	
	[User6] [varchar](20) NULL	
)
--DROP TABLE XPODetails;

TRUNCATE TABLE XEmployeeWeek
INSERT INTO XEmployeeWeek
SELECT	DATEADD(wk, DATEDIFF(wk, 0, Transdate), 0) AS TransWeek,
		SiteID,
		EmployeeID,
		Max(EmployeeName),
		Item,
		Max(Description1) AS 'Item Description',
		TypeDescription,
		ItemClass,
		ItemType,
		ItemTypeDesc,
		SUM(ISNULL(CostSum,0)),
		SUM(ISNULL(QtySum,0)),
		SUM(DistinctItemCount),
		SUM(ItemCount),
		Consignment,
		Crib,
		User1,
		User2,
		User3,
		User4,
		User5,
		User6
FROM        XEmployeeDay (nolock)
GROUP BY    DATEADD(wk, DATEDIFF(wk, 0, Transdate), 0), SiteID, EmployeeID, EmployeeName, Item, ItemClass, ItemType, ItemTypeDesc, TypeDescription, Consignment, Crib,
		  User1, User2, User3, User4, User5, User6

-- Record last date tables updated so status can be monitored
IF EXISTS (SELECT * FROM GLOBALSETTINGS WHERE KEYNAME = 'Dashboard_LastSummaryDate')
	UPDATE GLOBALSETTINGS SET STRING = convert(varchar, GETDATE(),120) WHERE KEYNAME ='Dashboard_LastSummaryDate'
ELSE
	INSERT INTO GLOBALSETTINGS (KEYNAME, STRING) VALUES ('Dashboard_LastSummaryDate', convert(varchar, GETDATE(),120))

END -- EMPLOYEE USAGE SUMMARIES
GO