CREATE OR REPLACE TRIGGER TRG_AUDIT_EMPLOYEECRIB
   BEFORE DELETE OR INSERT OR UPDATE
   ON EMPLOYEECRIB
   REFERENCING NEW AS NEW OLD AS OLD
   FOR EACH ROW
DECLARE
   hold_CURRENTEMPLOYEEID   EMPLOYEE.ID%TYPE;
/******************************************************************************
   NAME: TRG_AUDIT_EMPLOYEECRIB
   PURPOSE: Log audit changes to the permissions assigned to an employee

   REVISIONS:
   Ver        Date        Author           Description
   ---------  ----------  ---------------  ------------------------------------
   1.0        9/14/2004   RSB              1. Created this trigger.

******************************************************************************/
BEGIN
   -- Get the current application user
   BEGIN
      SELECT SESSIONDATAVALUE
        INTO hold_CURRENTEMPLOYEEID
        FROM SESSIONDATA
       WHERE SESSIONDATAKEY = 'CURRENT_USER';
   EXCEPTION
      WHEN NO_DATA_FOUND THEN
         hold_CURRENTEMPLOYEEID := NULL;   -- No current user found
   END;

   -- Log "removals" of individual user permissions. Note that scope changes are
   -- logged as a removal of the old scope and addition of new scope

   -- NOTE: Be careful to avoid spurious logging when renaming employees
   IF DELETING OR(UPDATING AND(NVL(:OLD.CRIB, 0) <> NVL(:NEW.CRIB, 0))) THEN
      INSERT INTO SECAUDITHISTORY
                  (CRIB, EmployeeId, SecAuditType, SecAuditUID,
                   SecAuditDate)
           VALUES (:OLD.CRIB, :OLD.EMPLOYEEID, 10, hold_CURRENTEMPLOYEEID,
                   TO_DATE(TO_CHAR(SYSDATE, 'YYYYMMDD HH24MISS'), 'YYYYMMDD HH24MISS'));
   END IF;

   -- Log addition of individual user permissions
   IF INSERTING OR(UPDATING AND(NVL(:OLD.CRIB, 0) <> NVL(:NEW.CRIB, 0))) THEN
      INSERT INTO SECAUDITHISTORY
                  (CRIB, EmployeeId, SecAuditType, SecAuditUID,
                   SecAuditDate)
           VALUES (:NEW.CRIB, :NEW.EMPLOYEEID, 9, hold_CURRENTEMPLOYEEID,
                   TO_DATE(TO_CHAR(SYSDATE, 'YYYYMMDD HH24MISS'), 'YYYYMMDD HH24MISS'));
   END IF;
END;
/