CREATE OR REPLACE TRIGGER TRG_AUDIT_EMPLOYEESECURITY
   BEFORE DELETE OR INSERT OR UPDATE
   ON EMPLOYEESECURITY
   REFERENCING NEW AS NEW OLD AS OLD
   FOR EACH ROW
DECLARE
   hold_CURRENTEMPLOYEEID   EMPLOYEE.ID%TYPE;
/******************************************************************************
   NAME: TRG_AUDIT_EMPLOYEESECURITY
   PURPOSE: Log audit changes to the security groups assigned to an employee

   REVISIONS:
   Ver        Date        Author           Description
   ---------  ----------  ---------------  ------------------------------------
   1.0        9/14/2004   RSB              1. Created this trigger.

******************************************************************************/
BEGIN
   -- Get the current application user
   BEGIN
      SELECT SESSIONDATAVALUE
        INTO hold_CURRENTEMPLOYEEID
        FROM SESSIONDATA
       WHERE SESSIONDATAKEY = 'CURRENT_USER';
   EXCEPTION
      WHEN NO_DATA_FOUND THEN
         hold_CURRENTEMPLOYEEID := NULL;   -- No current user found
   END;

   -- Log "removals" of user from security groups. Note that scope changes are
   -- logged as a removal of the old scope and addition of new scope

   -- NOTE: Be careful to avoid spurious logging when renaming employees
   IF    DELETING
      OR (    UPDATING
          AND (   NVL(:OLD.ScopeType, 0) <> NVL(:NEW.ScopeType, 0)
               OR NVL(:OLD.SecurityGrpId, 0) <> NVL(:NEW.SecurityGrpId, 0))) THEN
      INSERT INTO SECAUDITHISTORY
                  (SecurityGrpId, EmployeeId, SecAuditType, SecScopeType,
                   SecAuditUID,
                   SecAuditDate)
           VALUES (:OLD.SECURITYGRPID, :OLD.EMPLOYEEID, 4, :OLD.SCOPETYPE,
                   hold_CURRENTEMPLOYEEID,
                   TO_DATE(TO_CHAR(SYSDATE, 'YYYYMMDD HH24MISS'), 'YYYYMMDD HH24MISS'));
   END IF;

   -- Log addition of user to new security groups
   IF    INSERTING
      OR (    UPDATING
          AND (   NVL(:OLD.ScopeType, 0) <> NVL(:NEW.ScopeType, 0)
               OR NVL(:OLD.SecurityGrpId, 0) <> NVL(:NEW.SecurityGrpId, 0))) THEN
      INSERT INTO SECAUDITHISTORY
                  (SecurityGrpId, EmployeeId, SecAuditType, SecScopeType,
                   SecAuditUID,
                   SecAuditDate)
           VALUES (:NEW.SECURITYGRPID, :NEW.EMPLOYEEID, 3, :NEW.SCOPETYPE,
                   hold_CURRENTEMPLOYEEID,
                   TO_DATE(TO_CHAR(SYSDATE, 'YYYYMMDD HH24MISS'), 'YYYYMMDD HH24MISS'));
   END IF;
END;
/