CREATE OR REPLACE TRIGGER TRG_AUDIT_EMPLOYEESECURITYEXT
   BEFORE DELETE OR INSERT OR UPDATE
   ON EMPLOYEESECURITYEXT
   REFERENCING NEW AS NEW OLD AS OLD
   FOR EACH ROW
DECLARE
   hold_CURRENTEMPLOYEEID   EMPLOYEE.ID%TYPE;
/******************************************************************************
   NAME: TRG_AUDIT_EMPLOYEESECURITYEXT
   PURPOSE: Log audit changes to the permissions assigned to an employee

   REVISIONS:
   Ver        Date        Author           Description
   ---------  ----------  ---------------  ------------------------------------
   1.0        9/14/2004   RSB              1. Created this trigger.

******************************************************************************/
BEGIN
   -- Get the current application user
   BEGIN
      SELECT SESSIONDATAVALUE
        INTO hold_CURRENTEMPLOYEEID
        FROM SESSIONDATA
       WHERE SESSIONDATAKEY = 'CURRENT_USER';
   EXCEPTION
      WHEN NO_DATA_FOUND THEN
         hold_CURRENTEMPLOYEEID := NULL;   -- No current user found
  END;

   -- Log "removals" of individual user permissions. Note that scope changes are
   -- logged as a removal of the old scope and addition of new scope
   -- NOTE: Be careful to avoid spurious logging when renaming employees
   IF    DELETING
      OR (    UPDATING
          AND (   NVL(:OLD.ScopeType, 0) <> NVL(:NEW.ScopeType, 0)
               OR NVL(:OLD.SECURITYTYPE, 0) <> NVL(:NEW.SECURITYTYPE, 0)
               OR NVL(:OLD.FunctionId, 0) <> NVL(:NEW.FunctionId, 0))) THEN
      INSERT INTO SECAUDITHISTORY
                  (FunctionId, EmployeeId, SecAuditType,
                   SecScopeType, SecAuditUID,
                   SecAuditDate)
           VALUES (:OLD.FunctionId, :OLD.EMPLOYEEID, DECODE(:OLD.SECURITYTYPE, 1, 8, 6),
                   :OLD.SCOPETYPE, hold_CURRENTEMPLOYEEID,
                   TO_DATE(TO_CHAR(SYSDATE, 'YYYYMMDD HH24MISS'), 'YYYYMMDD HH24MISS'));
   END IF;

   -- Log addition of individual user permissions
   IF    INSERTING
      OR (    UPDATING
          AND (   NVL(:OLD.ScopeType, 0) <> NVL(:NEW.ScopeType, 0)
               OR NVL(:OLD.SECURITYTYPE, 0) <> NVL(:NEW.SECURITYTYPE, 0)
               OR NVL(:OLD.FunctionId, 0) <> NVL(:NEW.FunctionId, 0))) THEN
      INSERT INTO SECAUDITHISTORY
                  (FunctionId, EmployeeId, SecAuditType,
                   SecScopeType, SecAuditUID,
                   SecAuditDate)
           VALUES (:NEW.FunctionId, :NEW.EMPLOYEEID, DECODE(:NEW.SECURITYTYPE, 1, 7, 5),
                   :NEW.SCOPETYPE, hold_CURRENTEMPLOYEEID,
                   TO_DATE(TO_CHAR(SYSDATE, 'YYYYMMDD HH24MISS'), 'YYYYMMDD HH24MISS'));
   END IF;
END;
/