CREATE OR REPLACE TRIGGER TRG_AUDIT_SECURITYGRPACCESS
   BEFORE DELETE OR INSERT OR UPDATE
   ON SECURITYGRPACCESS
   REFERENCING NEW AS NEW OLD AS OLD
   FOR EACH ROW
DECLARE
   hold_CURRENTEMPLOYEEID   EMPLOYEE.ID%TYPE;

/******************************************************************************
   NAME: TRG_AUDIT_SECURITYGRPACCESS
   PURPOSE: Log changes to the permissions assigned to a Security Group

   REVISIONS:
   Ver        Date        Author           Description
   ---------  ----------  ---------------  ------------------------------------
   1.0        9/23/2004   RSB              1. Created this trigger.

******************************************************************************/                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                   
BEGIN
   -- Get the current application user
   BEGIN
      SELECT SESSIONDATAVALUE
        INTO hold_CURRENTEMPLOYEEID
        FROM SESSIONDATA
       WHERE SESSIONDATAKEY = 'CURRENT_USER';
   EXCEPTION
      WHEN NO_DATA_FOUND THEN
         hold_CURRENTEMPLOYEEID := NULL;   -- No current user found
   END;
   -- Log removals of permissions. 
   IF DELETING OR UPDATING THEN
      INSERT INTO SECAUDITHISTORY
                  (FunctionId, SecurityGrpId, SecAuditType, SecAuditUID,
                   SecAuditDate)
           VALUES (:OLD.FunctionId, :OLD.SecurityGrpId, 2, hold_CURRENTEMPLOYEEID,
                   TO_DATE(TO_CHAR(SYSDATE, 'YYYYMMDD HH24MISS'), 'YYYYMMDD HH24MISS'));
   END IF;
   -- Log addition of permissions
   IF INSERTING THEN
      INSERT INTO SECAUDITHISTORY
                  (FunctionId, SecurityGrpId, SecAuditType, SecAuditUID,
                   SecAuditDate)
           VALUES (:NEW.FunctionId, :NEW.SecurityGrpId, 1, hold_CURRENTEMPLOYEEID,
                   TO_DATE(TO_CHAR(SYSDATE, 'YYYYMMDD HH24MISS'), 'YYYYMMDD HH24MISS'));
   END IF;
END;
/
