CREATE OR REPLACE FUNCTION ComputeWOScheduleInterval(
   in_Interval       IN   INTEGER,
   in_IntervalType   IN   INTEGER)
   RETURN INTEGER IS
   out_Interval   INTEGER;
BEGIN
   IF in_IntervalType = 0 THEN
      out_Interval := in_Interval;
   ELSIF in_IntervalType = 1 THEN
      out_Interval := in_Interval * 7;
   ELSIF in_IntervalType = 2 THEN
      out_Interval := in_Interval * 30;
   ELSIF in_IntervalType = 3 THEN
      out_Interval := in_Interval * 365;
   ELSIF in_IntervalType = 4 THEN
      out_Interval := in_Interval * 15;
   ELSE
      out_Interval := NULL;
   END IF;

   RETURN out_Interval;
END;
/

CREATE OR REPLACE FUNCTION AdjustQuantityForLeadTime(
   in_Quantity       INTEGER,
   in_INTERVAL       INTEGER,
   in_INTERVALTYPE   INTEGER,
   in_LeadTime       INTEGER,
   in_Active         INTEGER)
   RETURN INTEGER IS
   out_EffectiveQuantity    INTEGER;
   hold_EffectiveInterval   INTEGER;
BEGIN
   hold_EffectiveInterval :=
                          NVL(ComputeWOScheduleInterval(in_INTERVAL, in_INTERVALTYPE), 0);

   IF hold_EffectiveInterval > 0 AND NVL(in_LeadTime, 0) > hold_EffectiveInterval THEN
      out_EffectiveQuantity := in_Quantity * CEIL(in_LeadTime / hold_EffectiveInterval);
   ELSE
      out_EffectiveQuantity := in_Quantity;
   END IF;

   IF in_Active = 1 THEN
      out_EffectiveQuantity := out_EffectiveQuantity - in_Quantity;
   END IF;

   RETURN out_EffectiveQuantity;
END;
/

CREATE OR REPLACE VIEW VALLWOITEMWITHCRIBBIN(PARTSCRIB,
                                             PREFERREDCRIBBIN,
                                             TASKITEMNUMBER,
                                             TASKITEMQUANTITY,
                                             EFFECTIVEQUANTITY,
                                             NEXTWODATE,
                                             INTERVAL,
                                             INTERVALTYPE,
                                             ACTIONCODE,
                                             ISSUEOPTION,
                                             OVRORDEROPTION,
                                             WONO,
                                             WODEFSCHEDULENO,
                                             ACTUALAVGLEADTIME) AS
   SELECT PARTSCRIB,
          PREFERREDCRIBBIN,
          TASKITEMNUMBER,
          TASKITEMQUANTITY,
          Adjustquantityforleadtime(TASKITEMQUANTITY,
                                    INTERVAL,
                                    INTERVALTYPE,
                                    NVL(OverrideAvgLeadTime,
                                        NVL(AvgLeadTime,
                                            Getglobalint('Purchasing_LeadTime', 7))),
                                    DECODE(WONo,
                                           NULL, 0,
                                           DECODE(WODefScheduleNo, NULL, 0, 1)))
                                                                     AS EFFECTIVEQUANTITY,
          NEXTWODATE,
          INTERVAL,
          INTERVALTYPE,
          ACTIONCODE,
          ISSUEOPTION,
          OVRORDEROPTION,
          WONO,
          WODEFSCHEDULENO,
          NVL(OverrideAvgLeadTime,
              NVL(AvgLeadTime, Getglobalint('Purchasing_LeadTime', 7)))
                                                                     AS ActualAvgLeadTime
     FROM VALLWODEFSCHEDULEWOITEMS v1, VPREFERREDCRIBBIN v2, STATION s
    WHERE v1.taskitemnumber = v2.itemnumber(+) AND v1.partscrib = v2.CRIB(+)
          AND PREFERREDCRIBBIN = s.cribbin(+);
/