CREATE OR REPLACE PROCEDURE Buildworeservations IS
   new_STATUS                    WO.WOSTATUSNO%TYPE;
   last_WONo                     WO.WONO%TYPE;
   last_WODefScheduleNo          WODEFSCHEDULE.WODEFSCHEDULENO%TYPE;
   hold_ReservationNo            RESERVATION.RESERVATIONNO%TYPE;
   hold_RUNDATE                  DATE;
   hold_OrderOption              RESERVATION.RESERVATIONORDEROPTION%TYPE;
   hold_AdditionalLeadTimeDays   NUMBER(11);
   UserReservationNo             NUMBER(11);
   UserReservationType           NUMBER(11);
BEGIN
   -- NOTE: Must strip off milliseconds from time values
   SELECT TO_DATE(TO_CHAR(SYSDATE, 'YYYYMMDD HH24MISS'), 'YYYYMMDD HH24MISS')
     INTO hold_RUNDATE
     FROM DUAL;

   -- Get default WO Purchasing Option
   BEGIN
      SELECT INT
        INTO hold_OrderOption
        FROM GLOBALSETTINGS
       WHERE KEYNAME = 'Purchasing_DefaultWOOrderOption';
   EXCEPTION
      WHEN NO_DATA_FOUND THEN
         hold_OrderOption := 0;
   END;

   -- Get default addition lead time days
   BEGIN
      SELECT INT
        INTO hold_AdditionalLeadTimeDays
        FROM GLOBALSETTINGS
       WHERE KEYNAME = 'Purchasing_MoreLeadDays';
   EXCEPTION
      WHEN NO_DATA_FOUND THEN
         hold_AdditionalLeadTimeDays := 0;
   END;

   DECLARE
      CURSOR get_WONeeds IS
         SELECT   WONo,
                  WODefScheduleNo,
                  partscrib,
                  preferredcribbin,
                  taskitemnumber,
                  SUM(EffectiveQuantity) AS SUMTASKQUANTITY,
                  OvrOrderOption
             FROM VAllWOItemWithCribBin
            WHERE PARTSCRIB IS NOT NULL
              AND (   NEXTWODATE <
                                 SYSDATE + ActualAvgLeadTime + hold_AdditionalLeadTimeDays
                   OR INTERVALTYPE = 5)
              AND NEXTWODATE < SYSDATE + ActualAvgLeadTime + hold_AdditionalLeadTimeDays
              AND (NVL(OVRORDEROPTION, 0) IN(1, 2) OR ISSUEOPTION IN(1, 2))
           HAVING SUM(EffectiveQuantity) > 0
         GROUP BY WONo,
                  WODefScheduleNo,
                  partscrib,
                  preferredcribbin,
                  taskitemnumber,
                  OvrOrderOption
         ORDER BY WONo, WODefScheduleNo, taskitemnumber, OvrOrderOption;

      WONeeds_rec   get_WONeeds%ROWTYPE;
   BEGIN
      OPEN get_WONeeds;

      FETCH get_WONeeds
       INTO WONeeds_rec;

      WHILE get_WONeeds%FOUND
      LOOP
         -- See if we need a new Reservation
         IF    hold_ReservationNo IS NULL
            OR NVL(last_WONo, 0) <> NVL(WONeeds_rec.WONo, 0)
            OR NVL(last_WODefScheduleNo, 0) <> NVL(WONeeds_rec.WODefScheduleNo, 0) THEN
            BEGIN
               last_WODefScheduleNo := NVL(WONeeds_rec.WODefScheduleNo, 0);
               last_WONo := NVL(WONeeds_rec.WONo, 0);
 					
               SELECT ReservationNo
                 INTO hold_ReservationNo
                 FROM RESERVATION
                WHERE ReservationType = 2
                  AND RESERVATIONSTATUS <> 3
                  AND RESERVATIONWONO = last_WONo
                  AND RESERVATIONWODEFSCHEDULENO = last_WODefScheduleNo;
            EXCEPTION
               WHEN NO_DATA_FOUND THEN
                  hold_ReservationNo := NULL;
            END;

            -- Don't reserve parts automatically if user has own reservation linked
            -- to Work Order
            IF WONeeds_rec.WONo IS NOT NULL THEN
               UserReservationNo := NULL;

               BEGIN
                  SELECT WO.ReservationNo,
                         ReservationType
                    INTO UserReservationNo,
                         UserReservationType
                    FROM WO, RESERVATION
                   WHERE WO.RESERVATIONNO = RESERVATION.RESERVATIONNO(+)
                         AND WONo = WONeeds_rec.WONo;
               EXCEPTION
                  WHEN NO_DATA_FOUND THEN
                     UserReservationNo := NULL;
               END;

               IF UserReservationNo IS NOT NULL AND NVL(UserReservationType, 0) <> 2 THEN
                  -- Don't do processing for this Work Order
                  IF hold_ReservationNo IS NOT NULL THEN
                     -- Clean up any existing records
                     DELETE FROM RESERVATIONDETAIL
                           WHERE RESERVATIONNO = hold_ReservationNo;

                     DELETE FROM RESERVATION
                           WHERE RESERVATIONNO = hold_ReservationNo;
                  END IF;
               ELSE
                  UserReservationNo := NULL;
               END IF;
            END IF;

            IF UserReservationNo IS NULL THEN
               IF hold_ReservationNo IS NULL THEN
                  -- Create the Reservation
                  SELECT SEQ_RESERVATION.NEXTVAL
                    INTO hold_ReservationNO
                    FROM DUAL;

                  INSERT INTO RESERVATION
                              (RESERVATIONNO, DATECREATED, DATEREQUIRED,
                               RESERVATIONSTATUS, RESERVATIONTYPE,
                               RESERVATIONCOMMENTS,
                               RESERVATIONWONO, RESERVATIONWODEFSCHEDULENO,
                               RESERVEDFOREMPLOYEE, CREATEDBYEMPLOYEE,
                               APPROVEDBYEMPLOYEE, ReservationOrderOption)
                       VALUES (hold_ReservationNo, hold_RUNDATE, hold_RUNDATE,
                               1, 2,
                               'SYSTEM-GENERATED RESERVATION FOR PREDICTIVE WORK ORDER PURCHASING',
                               last_WONo, last_WODefScheduleNo,
                               'WORKORDER', 'SYSTEM',
                               'SYSTEM', hold_OrderOption);
               ELSE
                  UPDATE RESERVATION
                     SET DATEREQUIRED = hold_RUNDATE,
                         ReservationOrderOption = hold_OrderOption
                   WHERE ReservationNo = hold_ReservationNo;

                  -- Update WO to reference Reservation, if applicable
                  IF last_WONo <> 0 THEN
                     UPDATE WO
                        SET RESERVATIONNO = hold_ReservationNo
                      WHERE WONo = last_WONo;
                  END IF;
               END IF;
            END IF;
         END IF;

         -- If User-assigned reservation number, then just skip the rest of the needs for this Work Order
         -- for now
         IF UserReservationNo IS NOT NULL THEN
            FETCH get_WONeeds
             INTO WONeeds_rec;

            GOTO NEXTLOOP;
         END IF;

         -- Now let's match-merge the reservation detail records
         DECLARE
            CURSOR get_Details IS
               SELECT   ReservationDetailNo,
                        ReservationCrib,
                        ReservationItemNumber,
                        NVL(ReservationQuantity, 0) AS ReservationQuantity,
                        NVL(ReservationActualQuantity, 0) AS ReservationActualQuantity,
                        OvrOrderOption
                   FROM RESERVATIONDETAIL
                  WHERE ReservationNo = hold_ReservationNo
               ORDER BY ReservationItemNumber, OvrOrderOption;

            nCompare             INTEGER;
            ReservationChanged   INTEGER;
            Details_rec          get_Details%ROWTYPE;
         BEGIN
            ReservationChanged := 0;

            OPEN get_Details;

            FETCH get_Details
             INTO Details_rec;

            WHILE (ReservationChanged = 0 AND get_WONeeds%FOUND) OR get_Details%FOUND
            LOOP
               -- Set the Comparison flag
               IF get_WONeeds%NOTFOUND OR ReservationChanged = 1 THEN
                  nCompare := 1;
               ELSIF get_Details%NOTFOUND THEN
                  nCompare := -1;
               ELSIF Details_rec.ReservationItemNumber < WONeeds_rec.TaskItemNumber THEN
                  nCompare := 1;
               ELSIF Details_rec.ReservationItemNumber > WONeeds_rec.TaskItemNumber THEN
                  nCompare := -1;
               ELSIF NVL(Details_rec.OvrOrderOption, 0) <
                                                        NVL(WONeeds_rec.OvrOrderOption, 0) THEN
                  nCompare := 1;
               ELSIF NVL(Details_rec.OvrOrderOption, 0) >
                                                        NVL(WONeeds_rec.OvrOrderOption, 0) THEN
                  nCompare := -1;
               ELSE
                  nCompare := 0;
               END IF;

               -- Insert Reservation Detail Record as needed
               IF nCompare = -1 THEN
                  INSERT INTO RESERVATIONDETAIL
                              (RESERVATIONNO, RESERVATIONCRIB,
                               RESERVATIONCRIBBIN, RESERVATIONITEMNUMBER,
                               RESERVATIONQUANTITY, RESERVATIONACTUALQUANTITY,
                               OVRORDEROPTION)
                       VALUES (hold_ReservationNo, WONeeds_rec.partscrib,
                               WONeeds_rec.preferredcribbin, WONeeds_rec.taskitemnumber,
                               WONeeds_rec.SUMTASKQUANTITY, 0,
                               WONeeds_rec.OvrOrderOption);
               ELSIF nCompare = 1 THEN
                  DELETE FROM RESERVATIONDETAIL
                        WHERE RESERVATIONDETAILNO = Details_rec.ReservationDetailNo;
               ELSE
                  -- Matched set of records
                  IF    WONeeds_rec.PartsCrib <> NVL(Details_rec.ReservationCrib, 0)
                     OR WONeeds_rec.SUMTASKQUANTITY <>
                             Details_rec.ReservationQuantity
                           - Details_rec.ReservationActualQuantity THEN
                     -- Update the record
                     UPDATE RESERVATIONDETAIL
                        SET ReservationCrib = WONeeds_rec.PartsCrib,
                            ReservationCribBin = WONeeds_rec.PreferredCribBin,
                            ReservationQuantity =
                                 Details_rec.ReservationActualQuantity
                               + WONeeds_rec.SUMTASKQUANTITY
                      WHERE ReservationDetailNo = Details_rec.ReservationDetailNo;
                  END IF;
               END IF;

               -- Advance our matching cursor
               IF nCompare = 1 OR nCompare = 0 THEN
                  FETCH get_Details
                   INTO Details_rec;
               END IF;

               IF nCompare = -1 OR nCompare = 0 THEN
                  FETCH get_WONeeds
                   INTO WONeeds_rec;

                  IF     get_WONeeds%FOUND
                     AND (   NVL(last_WONo, 0) <> NVL(WONeeds_rec.WONo, 0)
                          OR NVL(last_WODefScheduleNo, 0) <>
                                                       NVL(WONeeds_rec.WODefScheduleNo, 0)) THEN
                     ReservationChanged := 1;
                  END IF;
               END IF;
            END LOOP;
         END;

         <<NEXTLOOP>>
         NULL;
      END LOOP;
   END;

   -- Purge anything that wasn't updated
   DELETE FROM RESERVATION
         WHERE RESERVATIONTYPE = 2
           AND RESERVATIONSTATUS <> 3
           AND DATEREQUIRED < hold_RUNDATE;

   -- Orphaned detail records
   DELETE FROM RESERVATIONDETAIL
         WHERE NOT EXISTS(
                         SELECT *
                           FROM RESERVATION
                          WHERE RESERVATION.RESERVATIONNO =
                                                           RESERVATIONDETAIL.RESERVATIONNO);

   -- Orphaned
   UPDATE WO
      SET RESERVATIONNO = NULL
    WHERE RESERVATIONNO IS NOT NULL
      AND NOT EXISTS(SELECT *
                       FROM RESERVATION
                      WHERE RESERVATION.RESERVATIONNO = WO.RESERVATIONNO);
END;
/
