--ORACLE
-- Adding New Column to EMPLOYEE table if it doesn't exist yet
DECLARE
  l_cnt integer := 0;
BEGIN
    BEGIN
      SELECT count(*) into l_Cnt FROM user_tab_columns WHERE table_name = 'EMPLOYEE' AND column_name = 'ACCESSCODEEX';
    EXCEPTION
      WHEN NO_DATA_FOUND THEN l_Cnt := 0;
    END;
  
    IF l_Cnt = 0 THEN
      EXECUTE IMMEDIATE 'ALTER TABLE EMPLOYEE ADD ACCESSCODEEX VARCHAR2(4000)';
    END IF; --ALTER TABLE EMPLOYEE DROP COLUMN ACCESSCODEEX;

    BEGIN
      SELECT count(*) into l_Cnt FROM user_tab_columns WHERE table_name = 'INVENTRY' AND column_name = 'ACCESSCODEEX';
    EXCEPTION
      WHEN NO_DATA_FOUND THEN l_Cnt := 0;
    END;
  
    IF l_Cnt = 0 THEN
      EXECUTE IMMEDIATE 'ALTER TABLE INVENTRY ADD ACCESSCODEEX VARCHAR2(6)';
    END IF; --ALTER TABLE INVENTRY DROP COLUMN ACCESSCODEEX;

END;

/

-- Create new AccessCodeEx table for CM11.2 and higher
BEGIN
  DECLARE v_Cnt INTEGER;
    v_sqlAccCodeEx VARCHAR2(1000) := 'create table ACCESSCODEEX ( 
	ACCESSCODEEX VARCHAR2(6)
	,ACCESSCODEEXDESCRIPTION VARCHAR2(50) NULL
	,CONSTRAINT ACCESSCODEEX_PK PRIMARY KEY (ACCESSCODEEX))';
  BEGIN
    BEGIN
      SELECT count(*) into v_Cnt FROM USER_TABLES WHERE TABLE_NAME = 'ACCESSCODEEX';
      
    EXCEPTION
      WHEN NO_DATA_FOUND THEN v_Cnt := 0;
    END;
  
    IF v_Cnt = 0 THEN
      EXECUTE IMMEDIATE v_sqlAccCodeEx;
    END IF; --DROP TABLE ACCESSCODEEX;
  END;
END;

/

-- Modify VCRIBRELATEDITEMSUMMARY view
CREATE OR REPLACE VIEW VCRIBRELATEDITEMSUMMARY AS
   SELECT INVENTRY.DESCRIPTION1,
          INVENTRY.DESCRIPTION2,
          INVENTRY.PRICE,
          INVENTRY.VENDORNUMBER,
          INVENTRY.ACCESSCODE,
		  INVENTRY.ACCESSCODEEX,
          INVENTRY.ITEMTYPE,
          INVENTRY.ITEMCLASS,
          INVENTRY.REWORKEDITEMNUMBER,
          INVENTRY.UPCCODE,
          INVENTRY.COMMENTS,
          INVENTRY.PRICETYPE,
          INVENTRY.MANUFACTURER,
          INVENTRY.MFRNUMBER,
          INVENTRY.DEFAULTQTY,
          INVENTRY.RESTRICTED,
          INVENTRY.ITEMSTATUSCODE,
          INVENTRY.TRACKLOTNUMBER,
          INVENTRY.CINO,
          INVENTRY.CLASSNO,
          INVENTRY.CIREVISION,
          INVENTRY.CINUMBER,
          INVENTRY.ITEMFODCONTROL,
          INVENTRY.ALTVENDORNO,
          INVENTRY.REQUIRESINSPECTION,
          INVENTRY.INACTIVEITEM,
          INVENTRY.ISSUEUNITOFMEASURE,
          ITEMRELATIONSHIP.ITEMRELATIONSHIPID,
          ITEMRELATIONSHIP.RELATEDITEMNUMBER,
          ITEMRELATIONSHIP.ITEMNUMBER,
          ITEMRELATIONSHIP.RELATEDQUANTITY,
          VCRIBITEMSUMMARY.CRIB,
          VCRIBITEMSUMMARY.NAME,
          VCRIBITEMSUMMARY.SUMBINQUANTITY,
          VCRIBITEMSUMMARY.SUMQUANTITY,
          VCRIBITEMSUMMARY.SUMMONTHLYUSAGE,
          VCRIBITEMSUMMARY.SUMONORDER,
          VCRIBITEMSUMMARY.ENABLESITETRANSFERS,
          ITEMRELATIONSHIP.RELATIONSHIPTYPEID,
          ITEMRELATIONSHIP.RELATIONSHIPCODE,
          ITEMRELATIONSHIP.SPECIALINSTRUCTIONS,
          RELATIONSHIPTYPE.RELATIONSHIPTYPENAME,
          RELATIONSHIPTYPE.PREDEFINED,
          RELATIONSHIPTYPE.USAGETYPE,
          ITEMRELATIONSHIP.PRECEDENCE
     FROM ((INVENTRY INNER JOIN ITEMRELATIONSHIP ON INVENTRY.ITEMNUMBER = ITEMRELATIONSHIP.RELATEDITEMNUMBER)
		INNER JOIN VCRIBITEMSUMMARY ON ITEMRELATIONSHIP.RELATEDITEMNUMBER =	VCRIBITEMSUMMARY.ITEM)
		INNER JOIN RELATIONSHIPTYPE ON ITEMRELATIONSHIP.RELATIONSHIPTYPEID = RELATIONSHIPTYPE.RELATIONSHIPTYPEID

/

-- Modify VITEMWITHRELATEDCRIBBIN view
CREATE OR REPLACE VIEW VITEMWITHRELATEDCRIBBIN AS
   SELECT INVENTRY.DESCRIPTION1,
          INVENTRY.DESCRIPTION2,
          INVENTRY.PRICE,
          INVENTRY.ACCESSCODE,
		  INVENTRY.ACCESSCODEEX,
          INVENTRY.VENDORNUMBER,
          INVENTRY.ITEMTYPE,
          INVENTRY.ITEMCLASS,
          INVENTRY.REWORKEDITEMNUMBER,
          INVENTRY.UPCCODE,
          INVENTRY.COMMENTS,
          INVENTRY.SERIALIZED,
          INVENTRY.PRICETYPE,
          INVENTRY.MANUFACTURER,
          INVENTRY.MFRNUMBER,
          INVENTRY.DEFAULTQTY,
          INVENTRY.RESTRICTED,
          INVENTRY.ITEMSTATUSCODE,
          INVENTRY.TRACKLOTNUMBER,
          INVENTRY.CINO,
          INVENTRY.CLASSNO,
          INVENTRY.CIREVISION,
          INVENTRY.CINUMBER,
          INVENTRY.USECHECKLIST,
          INVENTRY.ItemFODControl,
          INVENTRY.ALTVENDORNO,
          INVENTRY.REQUIRESINSPECTION,
          INVENTRY.INACTIVEITEM,
          INVENTRY.ISSUEUNITOFMEASURE,
          ITEMRELATIONSHIP.ITEMRELATIONSHIPID,
          ITEMRELATIONSHIP.RELATEDITEMNUMBER,
          ITEMRELATIONSHIP.RELATEDQUANTITY,
          ITEMRELATIONSHIP.PRECEDENCE,
          ITEMRELATIONSHIP.RELATIONSHIPCODE,
          ITEMRELATIONSHIP.COMMENTS AS RELATIONSHIPCOMMENT,
          ITEMRELATIONSHIP.SPECIALINSTRUCTIONS,
          ITEMRELATIONSHIP.RELATIONSHIPWODEFNO,
          RELATIONSHIPTYPE.RELATIONSHIPTYPEID,
          RELATIONSHIPTYPE.RELATIONSHIPTYPENAME,
          RELATIONSHIPTYPE.PREDEFINED,
          RELATIONSHIPTYPE.USAGETYPE,
          STATION.CRIBBIN,
          STATION.CRIB,
          STATION.BINQUANTITY,
          STATION.QUANTITY,
          STATION.ONORDER,
          STATION.COMMENTS AS BINCOMMENTS,
          STATION.STOPORDERING,
          STATION.BINCAPACITY,
          STATION.PENDINGREWORK,
          ITEMRELATIONSHIP.ITEMNUMBER
     FROM INVENTRY
	 INNER JOIN ITEMRELATIONSHIP ON INVENTRY.ITEMNUMBER = ITEMRELATIONSHIP.RELATEDITEMNUMBER
	 INNER JOIN RELATIONSHIPTYPE ON ITEMRELATIONSHIP.RELATIONSHIPTYPEID = RELATIONSHIPTYPE.RELATIONSHIPTYPEID
	 INNER JOIN STATION ON ITEMRELATIONSHIP.RELATEDITEMNUMBER = STATION.ITEM

/
