--------------------------- Create Tables and Views ----------------------------
BEGIN
  DECLARE v_Cnt INTEGER;
    v_sqlInvHlth VARCHAR2(1000) := 'create table XINVENTORYHEALTH ( 
      SiteID varchar2(12) NOT NULL,
      "Site Description" varchar2(50),
      ParentSiteID varchar2(12),
      Crib number(5),
      "Crib Name" varchar2(50),
      "Crib Type" varchar2(50),
      Item varchar2(25),
      "Item Description" varchar2(50),
      ItemClass varchar2(15),
      ItemType varchar2(32),
      Overstock number(10),
      "Dead Stock" number(10),
      "Below Min" number(10),
      "Below Critical" number(10),
      "Out Of Stock" number(10),
      Lost number(10),
      Unusable number(10),
      "In Repair" number(10),
      "Scheduled CC" number(10),
      "Due Cycle Count" number(10),
      "Pending Rework" number(10), 
      "Total Inventory" number(19,4),
      "Inventory Qty" number(10),
      "Checked Out Cost" number(19,4),
      "Checked Out Qty" number(10),
      "Due Calibration" number(10) )';
      
    v_sqlPODtls VARCHAR2(1000) := 'create table XPODETAILS ( 
      POItemID NUMBER(11) NOT NULL,
      PONumber NUMBER(11) NOT NULL,
      SiteID VARCHAR2(12) NOT NULL,
      Crib NUMBER(11), 
      Item VARCHAR2(12),
      DateOrdered DATE,
      Received DATE,
      Quantity NUMBER(11),
      Cost NUMBER(19,4),
      Type VARCHAR2(12),
      LT NUMBER(11),
      POStatusDescription VARCHAR2(24),
      LTStatus VARCHAR2(24),
      PODetailStatus VARCHAR2(24) )';
  
    v_sqlPODtlsSum VARCHAR2(1000) := 'create table XPODETAILSSUM ( 
      SiteID VARCHAR2(12) NOT NULL,
      Crib NUMBER(5,0), 
      Item VARCHAR2(12),
      ParentSiteID VARCHAR2(12),
      ItemClass VARCHAR2(15),
      ItemClassDesc VARCHAR2(50),
      ItemType NUMBER(5,0),
      ItemTypeDesc VARCHAR2(32),
      "Lines Count" NUMBER(11),
      "Qty Sum" NUMBER(11),
      "Cost Sum" NUMBER(19,4),
      "Pending Authorization" NUMBER(11),
      "Open Total" NUMBER(11),
      "Open And Late" NUMBER(11),
      "Open And At LT" NUMBER(11),
      "Open And Early" NUMBER(11),
      "Late Total" NUMBER(11),
      "Received Late" NUMBER(11),
      "Received At LT" NUMBER(11),
      "Received Early" NUMBER(11) )';
      
  BEGIN
    BEGIN
      SELECT count(*) into v_Cnt FROM USER_TABLES WHERE TABLE_NAME = 'XINVENTORYHEALTH';
      
    EXCEPTION
      WHEN NO_DATA_FOUND THEN v_Cnt := 0;
    END;
  
    IF v_Cnt = 0 THEN
      EXECUTE IMMEDIATE v_sqlInvHlth;
    END IF; --DROP TABLE XINVENTORYHEALTH;
    
    BEGIN
      SELECT count(*) into v_Cnt FROM USER_TABLES WHERE TABLE_NAME = 'XPODETAILS';
    EXCEPTION
      WHEN NO_DATA_FOUND THEN v_Cnt := 0;
    END;
    
    IF v_Cnt = 0 THEN
      EXECUTE IMMEDIATE v_sqlPODtls;
    END IF; --DROP TABLE XPODETAILS;  
  
    BEGIN
      SELECT count(*) into v_Cnt FROM USER_TABLES WHERE TABLE_NAME = 'XPODETAILSSUM';
    EXCEPTION
      WHEN NO_DATA_FOUND THEN v_Cnt := 0;
    END;
    
    IF v_Cnt = 0 THEN
      EXECUTE IMMEDIATE v_sqlPODtlsSum;
    END IF; --DROP TABLE XPODETAILSSUM;
   
  END;
END;
/

------------------------  VXLotsToBeExpired ------------------------------------
CREATE OR REPLACE VIEW VXLotsToBeExpired AS
  SELECT
    LotNo,
    LotItemNumber as Item,
    LotExpirationDate,
    (LotExpirationDate - CURRENT_DATE) as "Days Due In",
    STATION.Crib,
    SiteID  
  FROM LotNumber
        INNER JOIN STATION ON STATION.Item = LotNumber.LotItemNumber
        INNER JOIN Crib ON Crib.Crib = STATION.Crib
  WHERE LotExpirationDate IS NOT NULL AND LotExpirationDate < CURRENT_DATE + 30
  --drop VIEW VXLotsToBeExpired
/

------------------------  VXATRStatus ------------------------------------
CREATE OR REPLACE VIEW VXATRStatus AS
  SELECT 
    sp.SiteID
    ,Latitude
    ,Longitude
    ,Crib.Crib as Crib
    ,Action
    ,LastSyncDate
    ,CASE 
        WHEN Action like '%Error' THEN 'Error'
        WHEN (CURRENT_DATE - LastSyncDate) * 24 > GETGLOBALINT('Dashboard_ATRSyncOffset', 2) 
          OR (Action not like '%ReadyToVend%' AND Action not like '%VendInProcess' ) OR LastSyncDate is NULL THEN 'Offline'  
        ELSE 'Online'  
      END AS CribStatus
    ,(CURRENT_DATE - LastSyncDate) * 24 as "Time Not Sync (hr)"
  FROM NetStatX
    INNER JOIN Crib ON Crib.Crib = StationNumber
    INNER JOIN SiteProfile sp on sp.SiteID = Crib.SiteID
  --drop VIEW VXATRStatus
/

------------------------  VXATRLoginHistory ------------------------------------
CREATE OR REPLACE VIEW VXATRLoginHistory AS
  SELECT 
    SiteID
    ,Crib.Crib as Crib
    ,TO_DATE(TRUNC(LoginHistoryDate, 'MM')) AS "Login Month"
    ,COUNT(LoginHistoryDate) as "# of Logins"
  FROM LoginHistory
    INNER JOIN Crib ON Crib.DeviceComputerName = TerminalID
  WHERE  
    Application = 'CMVEND' AND
    MONTHS_BETWEEN(TO_DATE(TRUNC(SYSDATE, 'MM')), TO_DATE(TRUNC(LoginHistoryDate, 'MM'))) <= GETGLOBALINT('Dashboard_ProcessUsageMonths', 12)
  GROUP BY SiteID, Crib, TO_DATE(TRUNC(LoginHistoryDate, 'MM'))
  --drop VIEW VXATRLoginHistory
/

------------------------  VXStockoutItems ------------------------------------
CREATE OR REPLACE VIEW VXStockoutItems AS
  SELECT 
    SiteID
    ,c.Crib
    ,e.ItemNumber
    ,i.Description1 as "Item Name"
    ,TO_DATE(TRUNC(EventDate)) + 0 AS "Date"
    ,count(EventDate) as "# Of Stockouts"
  FROM Events e
    inner join Station s on s.CribBin = e.CribBin
    inner join Crib c on c.crib = s.Crib
    inner join Inventry i on i.ItemNumber = e.ItemNumber
  WHERE Description like 'Out of Stock%' 
    AND MONTHS_BETWEEN(TO_DATE(TRUNC(SYSDATE, 'MM')), TO_DATE(TRUNC(EventDate, 'MM'))) < GETGLOBALINT('Dashboard_ProcessUsageMonths', 32)
  GROUP BY SiteID, c.Crib, e.ItemNumber,i.Description1, TO_DATE(TRUNC(EventDate))
  --drop VIEW VXStockoutItems
/

-------------------- sp_GenerateSiteUsageSummaries -----------------------------
CREATE or REPLACE PROCEDURE sp_GenerateSiteUsageSummaries IS
  -- Compute start date from number of months in stored option
  v_StartDate DATE;
  v_DashboardMonths NUMBER(11,0);

BEGIN
  v_DashboardMonths := GETGLOBALINT('Dashboard_ProcessUsageMonths', 24);
  v_StartDate := ADD_MONTHS(CURRENT_DATE, -v_DashboardMonths);
  
  ------------------------------- XTRANSDAY ------------------------------------
  -- delete index if it exists
  FOR MY_CUR in (SELECT INDEX_NAME FROM USER_INDEXES WHERE INDEX_NAME='IX_XTRANSD_ST_CLS' AND TABLE_NAME = 'XTRANSDAY') loop
    EXECUTE IMMEDIATE 'DROP INDEX ' || MY_CUR.INDEX_NAME;
  END LOOP;  
 
  EXECUTE IMMEDIATE  'TRUNCATE TABLE XTRANSDAY';
  INSERT INTO XTRANSDAY(TRANSDATE, SITEID, ITEM, DESCRIPTION1, 
                        TYPEDESCRIPTION, ITEMCLASS, ITEMTYPE, ITEMTYPEDESC,
                        COSTSUM, QTYSUM, DISTINCTITEMCOUNT, ITEMCOUNT, CONSIGNMENT,
                        CRIB, USER1, USER2, USER3, USER4, USER5, USER6)

  SELECT	TO_DATE(TRUNC(TRANSDATE)) AS TRANSDATE,
      SITEID,
      TRANS.ITEM,
      Max(Description1) AS DESCRIPTION1,
      TYPEDESCRIPTION,
      NVL(ITEMCLASS,'(None)'),
      INVENTRY.ITEMTYPE,
      ITEMTYPEDESC,
      SUM(NVL(Cost,0)) AS COSTSUM,
      SUM(NVL(TRANS.Quantity,0)) AS QTYSUM,
      COUNT(distinct TRANS.Item) as DISTINCTITEMCOUNT,
      COUNT(TRANS.item) AS ITEMCOUNT,
      STATION.CONSIGNMENT,
      TRANS.CRIB,
      TRANS.USER1,
      TRANS.USER2,
      TRANS.USER3,
      TRANS.USER4,
      TRANS.USER5,
      TRANS.USER6
  FROM  TRANS
  INNER JOIN  INVENTRY ON TRANS.Item = INVENTRY.ItemNumber
  INNER JOIN  ItemType ON INVENTRY.ItemType = ItemType.ItemType
  INNER JOIN  Crib ON TRANS.Crib = Crib.Crib 
  INNER JOIN  STATION ON STATION.Cribbin = TRANS.cribbin
  WHERE	    TRANS.Transdate > v_StartDate
  GROUP BY    TO_DATE(TRUNC(TRANSDATE)), SiteID, TRANS.Item, ItemClass, INVENTRY.ItemType, ItemTypeDesc, TypeDescription, STATION.Consignment, TRANS.Crib,
        TRANS.User1, TRANS.User2, TRANS.User3, TRANS.User4, TRANS.User5, TRANS.User6;
  
  -- create index for re-populated table
  EXECUTE IMMEDIATE  'CREATE INDEX IX_XTRANSD_ST_CLS ON XTransDay (SiteID, ItemClass)';
  
  ------------------------------- XTRANSMONTH ----------------------------------
  -- delete index if it exists
  FOR MY_CUR in (SELECT INDEX_NAME FROM USER_INDEXES WHERE INDEX_NAME='IX_XTRANSM_ST_CLS' AND TABLE_NAME = 'XTRANSMONTH') loop
    EXECUTE IMMEDIATE 'DROP INDEX ' || MY_CUR.INDEX_NAME;
  END LOOP;  
 
  EXECUTE IMMEDIATE  'TRUNCATE TABLE XTRANSMONTH';
  INSERT INTO XTRANSMONTH(TRANSDATE, SITEID, ITEM, DESCRIPTION1, 
                          TYPEDESCRIPTION, ITEMCLASS, ITEMTYPE, ITEMTYPEDESC,
                          COSTSUM, QTYSUM, DISTINCTITEMCOUNT, ITEMCOUNT, CONSIGNMENT,
                          CRIB, USER1, USER2, USER3, USER4, USER5, USER6)
  
  SELECT	TO_DATE(TRUNC(TRANSDATE, 'MM')) AS TRANSDATE,
      SITEID,
      ITEM,
      MAX(DESCRIPTION1) AS DESCRIPTION1,
      TYPEDESCRIPTION,
      ITEMCLASS,
      ITEMTYPE,
      ITEMTYPEDESC,
      SUM(COSTSUM) AS COSTSUM,
      SUM(QTYSUM) AS QTYSUM,
      SUM(DISTINCTITEMCOUNT) as DISTINCTITEMCOUNT,
      SUM(ITEMCOUNT) AS ITEMCOUNT,
      CONSIGNMENT,
      CRIB,
      USER1,
      USER2,
      USER3,
      USER4,
      USER5,
      USER6
  FROM  XTRANSDAY
  GROUP BY    TO_DATE(TRUNC(TRANSDATE, 'MM')), SiteID, Item, ItemClass, ItemType, ItemTypeDesc, TypeDescription, Consignment, Crib,
        User1, User2, User3, User4, User5, User6
  ORDER BY TRANSDATE;
  
  -- create index for re-populated table
  EXECUTE IMMEDIATE  'CREATE INDEX IX_XTRANSM_ST_CLS ON XTransMonth (SiteID, ItemClass)'; 
  
END;
/

-------------------- sp_GenerateEmplUsageSummaries -----------------------------
CREATE or REPLACE PROCEDURE sp_GenerateEmplUsageSummaries IS
  -- Compute start date from number of months in stored option
  v_StartDate DATE;
  v_DashboardMonths NUMBER(11,0);

BEGIN
  v_DashboardMonths := GETGLOBALINT('Dashboard_ProcessUsageMonths', 24);
  v_StartDate := ADD_MONTHS(CURRENT_DATE, -v_DashboardMonths);
  
  ------------------------------- XEMPLOYEEDAY ---------------------------------
  -- delete index if it exists
  FOR MY_CUR in (SELECT INDEX_NAME FROM USER_INDEXES WHERE INDEX_NAME='IX_XEMPLD_EMPL_CLS' AND TABLE_NAME = 'XEMPLOYEEDAY') loop
    EXECUTE IMMEDIATE 'DROP INDEX ' || MY_CUR.INDEX_NAME;
  END LOOP;  

  EXECUTE IMMEDIATE  'TRUNCATE TABLE XEMPLOYEEDAY';
  INSERT INTO XEMPLOYEEDAY(TRANSDATE, SITEID, EMPLOYEEID, EMPLOYEENAME, ITEM, DESCRIPTION1, 
                        TYPEDESCRIPTION, ITEMCLASS, ITEMTYPE, ITEMTYPEDESC,
                        COSTSUM, QTYSUM, DISTINCTITEMCOUNT, ITEMCOUNT, CONSIGNMENT,
                        CRIB, USER1, USER2, USER3, USER4, USER5, USER6)

  SELECT	TO_DATE(TRUNC(TRANSDATE)) AS TRANSDATE,
      SITEID,
      EMPLOYEE.ID AS EMPLOYEEID,
      Max(EMPLOYEE.Name) AS EMPLOYEENAME,
      TRANS.Item,
      Max(Description1) AS DESCRIPTION1,
      TYPEDESCRIPTION,
      NVL(ITEMCLASS,'(None)'),
      INVENTRY.ITEMTYPE,
      ITEMTYPEDESC,
      SUM(NVL(Cost,0)) AS COSTSUM,
      SUM(NVL(TRANS.Quantity,0)) AS QTYSUM,
      COUNT(distinct TRANS.Item) as DISTINCTITEMCOUNT,
      COUNT(TRANS.item) AS ITEMCOUNT,
      STATION.CONSIGNMENT,
      TRANS.CRIB,
      TRANS.USER1,
      TRANS.USER2,
      TRANS.USER3,
      TRANS.USER4,
      TRANS.USER5,
      TRANS.USER6
  FROM  TRANS
  INNER JOIN  INVENTRY ON TRANS.Item = INVENTRY.ItemNumber
  INNER JOIN  EMPLOYEE ON TRANS.employee = EMPLOYEE.ID
  INNER JOIN  ItemType ON INVENTRY.ItemType = ItemType.ItemType
  INNER JOIN  Crib ON TRANS.Crib = Crib.Crib 
  INNER JOIN  STATION ON STATION.Cribbin = TRANS.cribbin
  WHERE	    TRANS.Transdate > v_StartDate
  GROUP BY    TO_DATE(TRUNC(TRANSDATE)), SiteID, EMPLOYEE.ID, TRANS.Item, ItemClass, INVENTRY.ItemType, ItemTypeDesc, TypeDescription, STATION.Consignment, TRANS.Crib,
        TRANS.User1, TRANS.User2, TRANS.User3, TRANS.User4, TRANS.User5, TRANS.User6;
  
  -- create index for re-populated table
  EXECUTE IMMEDIATE  'CREATE INDEX IX_XEMPLD_EMPL_CLS ON XEMPLOYEEDAY (SiteID, ItemClass)';
  
  ------------------------------- XEMPLOYEEMONTH -------------------------------
  -- delete index if it exists
  FOR MY_CUR in (SELECT INDEX_NAME FROM USER_INDEXES WHERE INDEX_NAME='IX_XEMPLM_EMPL_CLS' AND TABLE_NAME = 'XEMPLOYEEMONTH') loop
    EXECUTE IMMEDIATE 'DROP INDEX ' || MY_CUR.INDEX_NAME;
  END LOOP;  
 
  EXECUTE IMMEDIATE  'TRUNCATE TABLE XEMPLOYEEMONTH';
  INSERT INTO XEMPLOYEEMONTH(TRANSDATE, SITEID, EMPLOYEEID, EMPLOYEENAME, ITEM, DESCRIPTION1, 
                          TYPEDESCRIPTION, ITEMCLASS, ITEMTYPE, ITEMTYPEDESC,
                          COSTSUM, QTYSUM, DISTINCTITEMCOUNT, ITEMCOUNT, CONSIGNMENT,
                          CRIB, USER1, USER2, USER3, USER4, USER5, USER6)
  
  SELECT	TO_DATE(TRUNC(TRANSDATE, 'MM')) AS TRANSDATE,
      SITEID,
      EMPLOYEEID,
      MAX(EMPLOYEENAME) AS EMPLOYEENAME,
      ITEM,
      MAX(DESCRIPTION1) AS DESCRIPTION1,
      TYPEDESCRIPTION,
      ITEMCLASS,
      ITEMTYPE,
      ITEMTYPEDESC,
      SUM(COSTSUM) AS COSTSUM,
      SUM(QTYSUM) AS QTYSUM,
      SUM(DISTINCTITEMCOUNT) as DISTINCTITEMCOUNT,
      SUM(ITEMCOUNT) AS ITEMCOUNT,
      CONSIGNMENT,
      CRIB,
      USER1,
      USER2,
      USER3,
      USER4,
      USER5,
      USER6
  FROM  XEMPLOYEEDAY
  GROUP BY    TO_DATE(TRUNC(TRANSDATE, 'MM')), SiteID, EMPLOYEEID, Item, ItemClass, ItemType, ItemTypeDesc, TypeDescription, Consignment, Crib,
        User1, User2, User3, User4, User5, User6
  ORDER BY TRANSDATE;
  
  -- create index for re-populated table
  EXECUTE IMMEDIATE  'CREATE INDEX IX_XEMPLM_EMPL_CLS ON XEMPLOYEEMONTH (SiteID, ItemClass)'; 
  
END;
/

-------------------- sp_GenerateInvHealthSummaries -----------------------------
CREATE or REPLACE PROCEDURE sp_GenerateInvHealthSummaries IS
  -- Compute start date from number of months in stored option
  v_StartDate DATE;
  v_CurrentDate DATE;
  v_OvstCriteria NUMBER(3,0);
  v_DeadStockNotIssuedOffset NUMBER(5,0);

BEGIN
  v_DeadStockNotIssuedOffset := GETGLOBALINT('Dashboard_DeadStockNotIssuedOffset', 150);
  v_OvstCriteria := GETGLOBALINT('Dashboard_OverstockCriteria', 0);
  
  -- delete index if it exists
  FOR MY_CUR in (SELECT INDEX_NAME FROM USER_INDEXES WHERE INDEX_NAME='IX_XINVHLTH_ST_CR' AND TABLE_NAME = 'XINVENTORYHEALTH') loop
    EXECUTE IMMEDIATE 'DROP INDEX ' || MY_CUR.INDEX_NAME;
  END LOOP;  

  EXECUTE IMMEDIATE  'TRUNCATE TABLE XINVENTORYHEALTH';
  INSERT INTO XINVENTORYHEALTH( SITEID, "Site Description", PARENTSITEID, CRIB, "Crib Name", "Crib Type", ITEM, 
      "Item Description", ITEMCLASS, ITEMTYPE, OVERSTOCK, "Dead Stock", "Below Min", "Below Critical", "Out Of Stock",
      LOST, UNUSABLE, "In Repair", "Scheduled CC", "Due Cycle Count", "Pending Rework", "Total Inventory", "Inventory Qty",
      "Checked Out Cost", "Checked Out Qty", "Due Calibration")
                          
  With StationAggregated AS (
    SELECT 
      Crib.SiteID,
      STATION.Item,
      STATION.Crib,
      STATION.CribBin,
      NVL(OnOrder, 0) AS OnOrder,
      NVL(Quantity, 0) AS Quantity,
      NVL(BinQuantity, 0) AS BinQuantity,
      NVL(TotalPrice, 0) AS TotalPrice,
      NVL(Maximum, 0) AS Maximum,
      NVL(OverrideOrderPoint, OrderPoint) AS OrderPoint,
      DateLastIssue,
      DateLastReceipt,
      StopOrdering,
      CriticalPoint,
      ((CASE WHEN sh.prev1 < 0 THEN 0 ELSE NVL(sh.prev1,0) END +
        CASE WHEN sh.Prev2 < 0 THEN 0 ELSE NVL(sh.Prev2,0) END +
        CASE WHEN sh.Prev3 < 0 THEN 0 ELSE NVL(sh.Prev3,0) END +
        CASE WHEN sh.Prev4 < 0 THEN 0 ELSE NVL(sh.Prev4,0) END +
        CASE WHEN sh.Prev5 < 0 THEN 0 ELSE NVL(sh.Prev5,0) END +
        CASE WHEN sh.Prev6 < 0 THEN 0 ELSE NVL(sh.Prev6,0) END +
        CASE WHEN sh.Prev7 < 0 THEN 0 ELSE NVL(sh.Prev7,0) END +
        CASE WHEN sh.Prev8 < 0 THEN 0 ELSE NVL(sh.Prev8,0) END +
        CASE WHEN sh.Prev9 < 0 THEN 0 ELSE NVL(sh.Prev9,0) END +
        CASE WHEN sh.Prev10 < 0 THEN 0 ELSE NVL(sh.Prev10,0) END +
        CASE WHEN sh.Prev11 < 0 THEN 0 ELSE NVL(sh.Prev11,0) END +
        CASE WHEN sh.Prev12 < 0 THEN 0 ELSE NVL(sh.Prev12,0) END) / 12 ) AS AvgUsage
    FROM STATION
      inner join crib
          on STATION.Crib = Crib.Crib
          LEFT outer JOIN StationHistory sh
          ON STATION.CribBin = sh.CribBin
    WHERE
        item is not null and (BinType = 0 or BinType is NULL)
  
  UNION ALL
  
    SELECT 
      Crib.SiteID,
      s.Item,
      s.Crib,
      CASE WHEN s.BinType = 3 THEN ss.CribBin ELSE s.CribBin END AS CribBin,
      MAX(NVL(ss.OnOrder, 0)) AS OnOrder,
      SUM(NVL(s.Quantity, 0)) AS Quantity,
      SUM(NVL(s.BinQuantity, 0)) AS BinQuantity,
      SUM(NVL(s.TotalPrice, 0)) AS TotalPrice,
      MAX(NVL(ss.Maximum, 0)) AS Maximum,
      MAX(NVL(ss.OverrideOrderPoint, ss.OrderPoint)) as OrderPoint,
      MAX(s.DateLastIssue) AS DateLastIssue,
      MAX(s.DateLastReceipt) AS DateLastReceipt,
      MAX(CAST(ss.StopOrdering AS NUMBER(10))) AS StopOrdering,
      MAX(ss.CriticalPoint) AS CriticalPoint,
      SUM(((CASE WHEN sh.prev1 < 0 THEN 0 ELSE NVL(sh.prev1,0) END +
        CASE WHEN sh.Prev2 < 0 THEN 0 ELSE NVL(sh.Prev2,0) END +
        CASE WHEN sh.Prev3 < 0 THEN 0 ELSE NVL(sh.Prev3,0) END +
        CASE WHEN sh.Prev4 < 0 THEN 0 ELSE NVL(sh.Prev4,0) END +
        CASE WHEN sh.Prev5 < 0 THEN 0 ELSE NVL(sh.Prev5,0) END +
        CASE WHEN sh.Prev6 < 0 THEN 0 ELSE NVL(sh.Prev6,0) END +
        CASE WHEN sh.Prev7 < 0 THEN 0 ELSE NVL(sh.Prev7,0) END +
        CASE WHEN sh.Prev8 < 0 THEN 0 ELSE NVL(sh.Prev8,0) END +
        CASE WHEN sh.Prev9 < 0 THEN 0 ELSE NVL(sh.Prev9,0) END +
        CASE WHEN sh.Prev10 < 0 THEN 0 ELSE NVL(sh.Prev10,0) END +
        CASE WHEN sh.Prev11 < 0 THEN 0 ELSE NVL(sh.Prev11,0) END +
        CASE WHEN sh.Prev12 < 0 THEN 0 ELSE NVL(sh.Prev12,0) END) / 12 )) AS AvgUsage
    FROM STATION s
      left outer join STATION ss on ss.CribBin = s.PrimaryCribBin AND ss.BinType = 2
      inner join crib on s.Crib = Crib.Crib
          LEFT outer JOIN StationHistory sh ON s.CribBin = sh.CribBin
    WHERE
      s.item is not null and  s.BinType <> 0 and s.BinType <> 1 and s.BinType is NOT NULL
      and CASE WHEN s.BinType = 3 THEN ss.CribBin ELSE s.CribBin END is not null
    GROUP BY Crib.SiteID, s.Item, s.Crib, CASE WHEN s.BinType = 3 THEN ss.CribBin ELSE s.CribBin END
  ),
    
  
  --//////////////////// Overstock ////////////////////////
  OverStock AS(
    SELECT 
      Crib.SiteID AS SiteID, 
      Crib.Crib AS Crib,
      Item,
      count(CribBin) AS Overstock
    FROM StationAggregated sa
      inner join crib
        on sa.Crib = Crib.Crib
    WHERE 
         Quantity > 0 AND
      (Quantity + OnOrder) >	CASE WHEN v_OvstCriteria = 0 THEN  Maximum
                    WHEN v_OvstCriteria = 1 THEN AvgUsage 
                    ELSE Maximum 
                  END
    GROUP BY Crib.SiteID, Crib.Crib, Item--, ItemDesc, ITEMCLASS
  ),
  
  --//////////////////// Deadstock ////////////////////////
  DeadStock AS ( 
    SELECT 
      c.SiteID AS SiteID,
      c.Crib AS Crib,
      Item,
      count(CribBin) AS DeadStock
    FROM   
      StationAggregated sa 
        INNER JOIN Crib c on sa.Crib = c.Crib
    WHERE
      (sa.DateLastIssue IS NULL OR sa.DateLastIssue <= v_StartDate)     
      AND (sa.DateLastReceipt IS NULL OR sa.DateLastReceipt <= v_StartDate) 
      AND sa.BinQuantity > 0
    group by c.SiteID, c.Crib, Item
  ),
  
  --//////////////////// Below Min ////////////////////////
  BelowMin AS (
    SELECT 
      c.SiteID AS SiteID,
      c.Crib AS Crib,
      Item,
      count(CribBin) AS BelowMin
    FROM
      StationAggregated sa
        INNER JOIN Crib c ON sa.Crib = c.Crib
    WHERE StopOrdering <> 1 
      AND sa.Item is not null
      AND ((sa.BinQuantity < sa.OrderPoint) AND sa.OrderPoint <> -1)
    GROUP BY c.SiteID, c.Crib, Item
  ),
  
  --//////////////////// Below Critical ////////////////////////
  BelowCritical as (
    SELECT 
      c.SiteID as SiteID,
      c.Crib as Crib,
      Item,
      count(CribBin) as BelowCrit
    FROM
      StationAggregated sa
        INNER JOIN Crib c ON sa.Crib = c.Crib
    WHERE StopOrdering <> 1 
      AND ((sa.BinQuantity < CriticalPoint) AND sa.OrderPoint <> -1)
    GROUP BY c.SiteID, c.Crib, Item--, Description1, INVENTRY.ItemClass
  ),
  
  --//////////////////// Out of Stock ////////////////////////
  OutOfStock as (
    SELECT 
      c.SiteID as SiteID,
      c.Crib as Crib,
      Item,
      count(CribBin) as OutOfStock
    FROM
      StationAggregated sa
        INNER JOIN Crib c ON sa.Crib = c.Crib
    WHERE StopOrdering <> 1 
      AND ((sa.BinQuantity = 0) AND sa.OrderPoint <> -1)
    GROUP BY c.siteid, c.Crib, Item
  ),
  
  --///////////////////// Bins Scheduled ///////////////////////////////////////
  ScheduledCC as (
    SELECT
      c.SiteID,
      ii.Crib,
      ii.ItemNumber AS Item,
      count(ii.CribBin) AS SceduledCC 	
    FROM ItemInventory ii
      INNER JOIN Station s on s.CribBin = ii.CribBin AND s.Item = ii.ItemNumber -- Make sure that only existing CribBinsItemNumber are counted 
      INNER JOIN Crib c ON ii.Crib = c.Crib
    WHERE DATECOUNTED IS NULL
    Group by c.SiteID, ii.Crib, ii.ItemNumber
  ),
  
  --///////////////////// Bins Past Due ///////////////////////////////////////
  PastDueCC as (
    SELECT
      c.SiteID,
      ii.Crib,
      ii.ItemNumber AS Item,
      count(ii.CribBin) AS PastDueCC 	
    FROM ItemInventory ii
      INNER JOIN Station s on s.CribBin = ii.CribBin AND s.Item = ii.ItemNumber -- Make sure that only existing CribBinsItemNumber are counted 
      INNER JOIN Crib c ON ii.Crib = c.Crib
    WHERE DATECOUNTED IS NULL AND DATEDUE <= CURRENT_DATE
    Group by c.SiteID, ii.Crib, ii.ItemNumber
  ),
  
  --//////////////////////// Unusable //////////////////////////////////////////
  Unusable as (
    SELECT
      c.SiteID,
      c.Crib,
      isr.ItemNumber as Item,
      count(isr.SerialID) Unusable 
    FROM ItemSerial isr
      INNER JOIN SerialStatus ss on isr.Status = ss.Status
      INNER JOIN Station s on isr.CribBin = s.CribBin
      INNER JOIN Crib c on s.Crib = c.Crib
  
    WHERE ss.StatusDesc = 'Unusable'
    Group By 	c.SiteID, c.Crib, isr.ItemNumber--, Description1, inv.ItemClass
  ),
  
  statushistory as (
    select sh1.serialid,sh2.cribbin
    from
    (
      select serialid,max(statushistoryid) as shID
      from serialstatushistory
      where cribbin is not null and cribbin not like '!%'
      group by serialid
    ) sh1
      inner join serialstatushistory sh2
        on sh1.shid = sh2.statushistoryid
  ),
  
  --//////////////////////// Lost //////////////////////////////////////////
  Lost as (
    SELECT
      c.SiteID,
      c.Crib,
      isr.ItemNumber as Item,
      count(isr.SerialID) Lost 
    FROM ItemSerial isr
      INNER JOIN SerialStatus ss on isr.Status = ss.Status
      INNER JOIN statushistory sh on sh.SerialId = isr.SerialID
      INNER JOIN Station s on sh.CribBin = s.CribBin
      INNER JOIN Crib c on s.Crib = c.Crib
  
    WHERE ss.StatusDesc = 'Lost'
    Group By 	c.SiteID, c.Crib, isr.ItemNumber
  ),
  
  --///////////////////// In Repair ///////////////////////////////////////
  InRepair as (
    SELECT
      c.SiteID,
      c.Crib,
      isr.ItemNumber as Item,
      count(isr.SerialID) AS InRepair 
    FROM ItemSerial isr
      INNER JOIN SerialStatus ss on isr.Status = ss.Status
      INNER JOIN statushistory sh on sh.SerialId = isr.SerialID
      INNER JOIN Station s on sh.CribBin = s.CribBin
      INNER JOIN Crib c on s.Crib = c.Crib
  
    WHERE ss.StatusDesc = 'In Repair'
    Group By 	c.SiteID, c.Crib, isr.ItemNumber 
  ),
  
  --///////////////////// Pending Rework ///////////////////////////////////////
  PendingRework as (
    SELECT
      c.SiteID,
      c.Crib,
      Item,
      Count(Item) AS PendingRework
    FROM STATION s
      INNER JOIN Crib c ON s.Crib = c.Crib
    where s.PendingRework > 0
    Group by c.SiteID, c.Crib, Item
  ),
  
  --/////////////////////// Total Inventory Value /////////////////////////////////
  InventoryValue as (
    SELECT
      c.SiteID,
      c.Crib,
      Item,
      SUM(NVL(TotalPrice, 0)) AS InvValue
    FROM STATION s
      INNER JOIN Crib c ON s.Crib = c.Crib 
    WHERE s.Item IS NOT NULL
    group by 	c.SiteID, c.Crib, Item
  ),
  
  --/////////////////////// Total Inventory Qty /////////////////////////////////
  InventoryQty as (
    SELECT
      c.SiteID,
      c.Crib,
      Item,
      SUM(s.Quantity) AS InvQty
    FROM STATION s
      INNER JOIN Crib c ON s.Crib = c.Crib 
    WHERE s.Item IS NOT NULL
    group by 	c.SiteID, c.Crib, Item
  ),
  
  --/////////////////////// Checked Out Items Cost /////////////////////////////////
  CheckedOutCost as (
    SELECT
      c.SiteID,
      c.Crib,
      co.Item as Item,
          SUM(NVL(co.Cost, 0)) as CheckedOutCost
  
    FROM CHECKOUT co
      INNER JOIN STATION s ON s.CribBin = co.CribBin
      INNER JOIN Crib c ON c.Crib = s.Crib
    GROUP BY c.SiteID, c.Crib, co.Item
  ),
  
  --/////////////////////// Checked Out Items Qty /////////////////////////////////
  CheckedOutQty as (
    SELECT
      c.SiteID,
      c.Crib,
      co.Item as Item,
          SUM(NVL(co.Quantity, 0)) as CheckedOutQty
  
    FROM CHECKOUT co
      INNER JOIN STATION s ON s.CribBin = co.CribBin
      INNER JOIN Crib c ON c.Crib = s.Crib
    GROUP BY c.SiteID, c.Crib, co.Item
  ),
  
  --/////////////////////// Past Calibration Gauges /////////////////////////////////
  PastCalibration as (
    SELECT 
      c.SiteID,
      c.Crib,
      itms.ItemNumber as Item,
      SUM(s.Quantity) AS PastCalib
    FROM ItemSerial itms
      INNER JOIN Inventry inv ON inv.ItemNumber = itms.ItemNumber
      INNER JOIN Station s ON s.CribBin = itms.CribBin
      INNER JOIN Crib c ON c.Crib = s.Crib
    WHERE SERIALID IN (SELECT SERIALID FROM GAUGE WHERE NEXTCERTIFYDATE < CURRENT_DATE)
      AND itms.Status NOT IN ( 4,7,8,9 ) -- Not in OutOfService, InCalibration, Lost, Off-Site
    group by 	c.SiteID, c.Crib, itms.ItemNumber
  ),
  
  -- Building total table with distinct Site, crib and item compasite
  Total as (
    SELECT Distinct SiteID, Crib, Item from OverStock
    UNION 
    SELECT Distinct SiteID, Crib, Item from DeadStock
    UNION
    SELECT Distinct SiteID, Crib, Item from BelowMin
    Union
    SELECT Distinct SiteID, Crib, Item from BelowCritical
    UNION
    SELECT Distinct SiteID, Crib, Item from OutOfStock
    UNION 
    SELECT Distinct SiteID, Crib, Item from Lost
    UNION
    SELECT Distinct SiteID, Crib, Item from Unusable
    Union
    SELECT Distinct SiteID, Crib, Item from InRepair
    UNION 
    SELECT Distinct SiteID, Crib, Item from ScheduledCC
    UNION
    SELECT Distinct SiteID, Crib, Item from PastDueCC
    Union
    SELECT Distinct SiteID, Crib, Item from PendingRework
    Union
    SELECT Distinct SiteID, Crib, Item from InventoryValue
    Union
    SELECT Distinct SiteID, Crib, Item from InventoryQty
    Union
    SELECT Distinct SiteID, Crib, Item from CheckedOutCost 
    Union
    SELECT Distinct SiteID, Crib, Item from CheckedOutQty
    Union
    SELECT Distinct SiteID, Crib, Item from PastCalibration
  )  
  
  SELECT
    tot.SiteID as SiteID,
    SiteDescription,
    ParentSiteID,
    tot.Crib as Crib,
    c.Name as CribName,
    ct.Description CribType,
    tot.Item as Item,
    Description1 AS ItemDesc,
    NVL(inv.ItemClass,'(None)') AS ItemGroup,
    ItemTypeDesc,
    NVL(Overstock,0) AS Overstock,
    NVL(DeadStock,0) AS DeadStock,
    NVL(BelowMin,0) AS BelowMin,
    NVL(BelowCrit,0) AS BelowCrit,
    NVL(OutOfStock,0) AS OutOfStock,
    NVL(Lost,0) AS Lost,
    NVL(Unusable,0) AS Unusable,
    NVL(InRepair,0) AS InRepair,
    NVL(SceduledCC,0) AS ScheduledCC,
    NVL(PastDueCC,0) AS PastDueCC,
    NVL(PendingRework,0) AS PendingRework,
    NVL(InvValue,0) AS InvValue,
    NVL(InvQty,0) AS InvQty,
    NVL(CheckedOutCost,0) AS CheckedOutCost,
    NVL(CheckedOutQty,0) AS CheckedOutQty,
    NVL(PastCalib,0) AS PastCalib
  
  FROM Total tot
      left outer join OverStock ovs on ovs.SiteID = tot.SiteID AND ovs.Crib = tot.Crib AND ovs.Item = tot.Item
      left outer join DeadStock ds on ds.SiteID = tot.SiteID AND ds.Crib = tot.Crib AND ds.Item = tot.Item
      left outer join BelowMin bm on bm.SiteID = tot.SiteID AND bm.Crib = tot.Crib AND bm.Item = tot.Item
      left outer join BelowCritical bc on bc.SiteID = tot.SiteID AND bc.Crib = tot.Crib AND bc.Item = tot.Item
      left outer join OutOfStock ous on ous.SiteID = tot.SiteID AND ous.Crib = tot.Crib AND ous.Item = tot.Item
      left outer join Lost  l on l.SiteID = tot.SiteID AND l.Crib = tot.Crib AND l.Item = tot.Item
      left outer join Unusable uu on uu.SiteID = tot.SiteID AND uu.Crib = tot.Crib AND uu.Item = tot.Item
      left outer join InRepair ir on ir.SiteID = tot.SiteID AND ir.Crib = tot.Crib AND ir.Item = tot.Item
      left outer join ScheduledCC sch on sch.SiteID = tot.SiteID AND sch.Crib = tot.Crib AND sch.Item = tot.Item
      left outer join PastDueCC pd on pd.SiteID = tot.SiteID AND pd.Crib = tot.Crib AND pd.Item = tot.Item
      left outer join PendingRework pr on pr.SiteID = tot.SiteID AND pr.Crib = tot.Crib AND pr.Item = tot.Item
      left outer join CheckedOutCost coc on coc.SiteID = tot.SiteID AND coc.Crib = tot.Crib AND coc.Item = tot.Item
      left outer join CheckedOutQty coq on coq.SiteID = tot.SiteID AND coq.Crib = tot.Crib AND coq.Item = tot.Item
      left outer join PastCalibration pc on pc.SiteID = tot.SiteID AND pc.Crib = tot.Crib AND pc.Item = tot.Item
      left outer join InventoryValue iv on iv.SiteID = tot.SiteID AND iv.Crib = tot.Crib AND iv.Item = tot.Item
      left outer join InventoryQty iq on iq.SiteID = tot.SiteID AND iq.Crib = tot.Crib AND iq.Item = tot.Item
  
    LEFT OUTER JOIN INVENTRY inv ON tot.Item = inv.ItemNumber
    LEFT OUTER JOIN ItemType it ON it.ItemType = inv.ItemType
    LEFT OUTER JOIN SiteProfile sp ON tot.SiteID = sp.SiteID
    LEFT OUTER JOIN Crib c ON tot.Crib = c.Crib
    left OUTER JOIN CribType ct ON c.CribType = ct.CribType
  
  ORDER BY  SiteID, Crib, Item;
  
  -- create index for re-populated table
  EXECUTE IMMEDIATE  'CREATE INDEX IX_XINVHLTH_ST_CR ON XINVENTORYHEALTH (SiteID, Crib)'; 
 
END sp_GenerateInvHealthSummaries;
/

----------------------- sp_GeneratePODetailsSummaries -------------------------- 
CREATE or REPLACE PROCEDURE sp_GeneratePODetailsSummaries IS
  -- Compute start date from number of months in stored option
  v_StartDate DATE;
  v_DashboardMonths NUMBER(3,0);
  v_AvgLeadTime NUMBER(3,0);

BEGIN
  v_AvgLeadTime := GETGLOBALINT('Dashboard_LeadTimeForPODetailsSum', 3);
  v_DashboardMonths := GETGLOBALINT('Dashboard_ProcessUsageMonths', 24);
  v_StartDate := ADD_MONTHS(CURRENT_DATE, -v_DashboardMonths);
  
  ------------------------------- XPODetails -----------------------------------
  -- delete index if it exists
  FOR MY_CUR in (SELECT INDEX_NAME FROM ALL_INDEXES WHERE INDEX_NAME='IX_XPODT_ST_CR' AND TABLE_NAME = 'XPODETAILS') loop
    EXECUTE IMMEDIATE 'DROP INDEX ' || MY_CUR.INDEX_NAME;
  END LOOP;  

  EXECUTE IMMEDIATE  'TRUNCATE TABLE XPODetails';
  INSERT INTO XPODetails( POITEMID, PONUMBER, SITEID, CRIB, ITEM, 
                        DATEORDERED, RECEIVED, QUANTITY, COST, TYPE,
                        LT, POSTATUSDESCRIPTION, LTSTATUS, PODETAILSTATUS )
  Select
    PODetail.ID,
    PO.PONumber, 
    SiteID,
    Crib,
    Item,
    DateOrdered,
    Received,
    Quantity,
    Cost,
    pot.Name AS Type,
    Received - DateOrdered AS LT,
    POStatusDescription,
    'Late',
    CASE 
      WHEN Received is NOT Null 
        THEN 'Fullfilled' 
      WHEN  Received is Null AND POStatusDescription = 'Closed'
        THEN 'Closed\Not Received'
      WHEN  Received is Null AND (CURRENT_DATE - DateOrdered) > v_AvgLeadTime
        THEN 'Open\Late'
      ELSE
        'Open\OnTime'
    END as PODetailStatus 
  FROM PODetail
    inner join PO on PO.PONumber = PODetail.PONumber
    inner join POStatus pos on PO.POStatusNo = pos.POStatusNo
    inner join PoType pot on PODETAIL.Type = pot.ID
  WHERE 
    DateOrdered > v_StartDate AND SiteID IS NOT NULL AND
    ((POStatusDescription in ('Closed', 'Partial') AND Received IS NOT NULL AND Received - DateOrdered > v_AvgLeadTime) OR
    (POStatusDescription = 'Closed' AND Received is NULL) OR
    (POStatusDescription in ('Ordered', 'Partial') AND (PODetail.Type = 0 or PODetail.Type = 1) AND Received is NULL AND (CURRENT_DATE -DateOrdered) > v_AvgLeadTime))                        

  UNION ALL
  
  Select
    PODetail.ID,
    PO.PONumber, 
    SiteID,
    Crib,
    Item,
    DateOrdered,
    Received,
    Quantity,
    Cost,
    pot.Name as Type,
    Received - DateOrdered LT,
    POStatusDescription,
    'At',
    'Fullfilled'
  FROM PODetail
    inner join PO on PO.PONumber = PODetail.PONumber
    inner join POStatus pos on PO.POStatusNo = pos.POStatusNo
    inner join PoType pot on PODETAIL.Type = pot.ID
  WHERE 
    DateOrdered > v_StartDate AND SiteID IS NOT NULL AND
    (POStatusDescription in ('Closed', 'Partial') AND Received IS NOT NULL AND Received - DateOrdered = v_AvgLeadTime )
    
  UNION ALL
  
  Select
    PODetail.ID,
    PO.PONumber, 
    SiteID,
    Crib,
    Item,
    DateOrdered,
    Received,
    Quantity,
    Cost,
    pot.Name as Type,
    Received -DateOrdered LT,
    POStatusDescription,
   'Early',
   'Fullfilled'
  FROM PODetail
    inner join PO on PO.PONumber = PODetail.PONumber
    inner join POStatus pos on PO.POStatusNo = pos.POStatusNo
    inner join PoType pot on PODETAIL.Type = pot.ID
  WHERE 
    DateOrdered > v_StartDate AND SiteID IS NOT NULL AND Received is NOT NULL AND
    Received -DateOrdered < v_AvgLeadTime
  
  UNION ALL
  
  Select
    PODetail.ID,
    PO.PONumber, 
    SiteID,
    Crib,
    Item,
    DateOrdered,
    Received,
    Quantity,
    Cost,
    pot.Name as Type,
    Received -DateOrdered LT,
    POStatusDescription,
   'Open\OnTime',
   'Open\OnTime'
  FROM PODetail
    inner join PO on PO.PONumber = PODetail.PONumber
    inner join POStatus pos on PO.POStatusNo = pos.POStatusNo
    inner join PoType pot on PODETAIL.Type = pot.ID
  WHERE 
    DateOrdered > v_StartDate AND SiteID IS NOT NULL AND Received is NULL AND
    POStatusDescription in ('Partial', 'Ordered') AND (PODetail.Type = 0 or PODetail.Type = 1)
    AND (CURRENT_DATE - DateOrdered) <= v_AvgLeadTime
    
  ORDER BY PODetailStatus;  
  -- create index for re-populated table
  EXECUTE IMMEDIATE  'CREATE INDEX IX_XPODT_ST_CR ON XPODETAILS (SiteID, Crib)';

  ------------------------------- XPODetailsSum --------------------------------
  -- delete index if it exists
  FOR MY_CUR in (SELECT INDEX_NAME FROM USER_INDEXES WHERE INDEX_NAME='IX_XPODTSUM_ST_CR' AND TABLE_NAME = 'XPODETAILSSUM') loop
    EXECUTE IMMEDIATE 'DROP INDEX ' || MY_CUR.INDEX_NAME;
  END LOOP;  
 
  EXECUTE IMMEDIATE  'TRUNCATE TABLE XPODETAILSSUM';
  INSERT INTO XPODETAILSSUM(SITEID, CRIB, ITEM, PARENTSITEID, ITEMCLASS, ITEMCLASSDESC, ITEMTYPE, 
        ITEMTYPEDESC, "Lines Count", "Qty Sum", "Cost Sum",
        "Pending Authorization", "Open Total", "Open And Late", "Open And At LT", "Open And Early",
        "Late Total", "Received Late", "Received At LT", "Received Early")
                          
  with PODetails as (
    Select
      PODetail.ID,
      PO.PONumber, 
      SiteID,
      Crib,
      Item,
      DateOrdered,
      Received,
      Quantity,
      Cost,
      pot.Name AS Type,
      (Received - DateOrdered) AS LT,
      POStatusDescription,
      'Late' AS LTStatus,
      CASE 
        WHEN Received is NOT Null 
          THEN 'Fullfilled' 
        WHEN  Received is Null AND POStatusDescription = 'Closed'
          THEN 'Closed\Not Received'
        WHEN  Received is Null AND (CURRENT_DATE - DateOrdered) > v_AvgLeadTime
          THEN 'Open\Late'
        ELSE
          'Open\OnTime'
      END AS PODetailStatus
    FROM PODetail
      inner join PO on PO.PONumber = PODetail.PONumber
      inner join POStatus pos on PO.POStatusNo = pos.POStatusNo
      inner join PoType pot on PODETAIL.Type = pot.ID
    WHERE 
      DateOrdered > v_StartDate AND SiteID IS NOT NULL AND
      ((POStatusDescription in ('Closed', 'Partial') AND Received IS NOT NULL AND (Received - DateOrdered) > v_AvgLeadTime) OR
      (POStatusDescription = 'Closed' AND Received is NULL) OR
      (POStatusDescription in ('Ordered', 'Partial') AND Received is NULL AND (CURRENT_DATE - DateOrdered) > v_AvgLeadTime))
  
    UNION ALL
  
    Select
      PODetail.ID,
      PO.PONumber, 
      SiteID,
      Crib,
      Item,
      DateOrdered,
      Received,
      Quantity,
      Cost,
      pot.Name as Type,
      (Received - DateOrdered) AS LT,
      POStatusDescription,
     'At' AS LTStatus,
     'Fullfilled' AS PODetailStatus
    FROM PODetail
      inner join PO on PO.PONumber = PODetail.PONumber
      inner join POStatus pos on PO.POStatusNo = pos.POStatusNo
      inner join PoType pot on PODETAIL.Type = pot.ID
    WHERE 
      DateOrdered > v_StartDate AND SiteID IS NOT NULL AND
      (POStatusDescription in ('Closed', 'Partial') AND Received IS NOT NULL AND (Received - DateOrdered) = v_AvgLeadTime )
  
    UNION ALL
  
    Select
      PODetail.ID,
      PO.PONumber, 
      SiteID,
      Crib,
      Item,
      DateOrdered,
      Received,
      Quantity,
      Cost,
      pot.Name as Type,
      (Received - DateOrdered) AS LT,
      POStatusDescription,
     'Early' AS LTStatus,
     'Fullfilled' AS PODetailStatus
    FROM PODetail
      inner join PO on PO.PONumber = PODetail.PONumber
      inner join POStatus pos on PO.POStatusNo = pos.POStatusNo
      inner join PoType pot on PODETAIL.Type = pot.ID
    WHERE 
      DateOrdered > v_StartDate AND SiteID IS NOT NULL AND Received is NOT NULL AND
      Received -DateOrdered < v_AvgLeadTime
  
    UNION ALL
  
    Select
      PODetail.ID,
      PO.PONumber, 
      SiteID,
      Crib,
      Item,
      DateOrdered,
      Received,
      Quantity,
      Cost,
      pot.Name as Type,
      (Received - DateOrdered) AS LT,
      POStatusDescription,
     'OpenEarly' AS LTStatus,
     'OpenEarly' AS PODetailStatus
    FROM PODetail
      inner join PO on PO.PONumber = PODetail.PONumber
      inner join POStatus pos on PO.POStatusNo = pos.POStatusNo
      inner join PoType pot on PODETAIL.Type = pot.ID
    WHERE 
      DateOrdered > v_StartDate AND SiteID IS NOT NULL AND Received is NULL AND
      POStatusDescription in ('Partial', 'Ordered') AND (CURRENT_DATE - DateOrdered) < v_AvgLeadTime
  
    UNION ALL
  
    Select
      PODetail.ID,
      PO.PONumber, 
      SiteID,
      Crib,
      Item,
      DateOrdered,
      Received,
      Quantity,
      Cost,
      pot.Name as Type,
      (Received - DateOrdered) AS LT,
      POStatusDescription,
      'OpenAt' AS LTStatus,
      'OpenAt' AS PODetailStatus
    FROM PODetail
      inner join PO on PO.PONumber = PODetail.PONumber
      inner join POStatus pos on PO.POStatusNo = pos.POStatusNo
      inner join PoType pot on PODETAIL.Type = pot.ID
    WHERE 
      DateOrdered > v_StartDate AND SiteID IS NOT NULL AND Received is NULL AND
      POStatusDescription in ('Partial', 'Ordered') AND (CURRENT_DATE - DateOrdered) = v_AvgLeadTime
  ),
  
  POLineData AS (
    SELECT
      sp.SiteID,
      Crib,
      Item,
      sp.ParentSiteID,
      inv.ItemClass,
      ItemClassDescription,
      inv.ItemType,
      it.ItemTypeDesc,
      Count (ID) as POLinesCount,
      SUM (Quantity) as QtySum,
      SUM (Cost) as CostSum,
      SUM ( CASE WHEN PODetailStatus = 'OpenLate' OR PODetailStatus = 'OpenEarly' OR PODetailStatus = 'OpenAt' THEN 1 ELSE 0 END ) as POLinesOpenTotal,
      SUM ( CASE WHEN PODetailStatus = 'OpenLate' THEN 1 ELSE 0	END ) as POLinesOpenAndLate,
      SUM ( CASE WHEN PODetailStatus = 'OpenEarly' THEN 1 ELSE 0 END ) as POLinesOpenAndEarly,
      SUM ( CASE WHEN PODetailStatus = 'OpenAt' THEN 1 ELSE 0 END ) as POLinesOpenAndAtLT,
      SUM ( CASE WHEN LTStatus = 'Late' THEN 1 ELSE 0 END ) as POLinesLateTotal,
      SUM ( CASE WHEN LTStatus = 'Late' AND PODetailStatus = 'Fullfilled' THEN 1 ELSE 0 END ) as POLinesReceivedLate,
      SUM ( CASE WHEN LTStatus = 'At' THEN 1 ELSE 0 END ) as POLinesReceivedAtLeadTime,
      SUM ( CASE WHEN LTStatus = 'Early' THEN 1 ELSE 0 END ) as POLinesReceivedEarly
  
    FROM PODetails
      inner join  SiteProfile sp on PODetails.SiteID = sp.SiteID
      left outer join INVENTRY inv on PODetails.Item = inv.ItemNumber
      left outer join ItemClass ic on inv.ItemClass = ic.ItemClass
      left outer join ItemType it on inv.ItemType = it.ItemType
  
    GROUP BY	sp.SiteID,
          Crib,
          Item,
          sp.ParentSiteID,
          inv.ItemClass,
          ItemClassDescription,
          inv.ItemType,
          it.ItemTypeDesc
  ),
  
  POPendingData AS (
    SELECT 
      c.SiteID,
      c.Crib,
      vpwal.ItemNumber as Item,
      sp.ParentSiteID,
      inv.ItemClass,
      ItemClassDescription,
      inv.ItemType,
      it.ItemTypeDesc,
      count(ID) as PendingAuthorization 
    FROM VPendingWithAltVendor vpwal
      inner join Crib c on vpwal.CRIB = c.Crib
      inner join  SiteProfile sp on c.SiteID = sp.SiteID
      left outer join INVENTRY inv on vpwal.ItemNumber = inv.ItemNumber
      left outer join ItemClass ic on inv.ItemClass = ic.ItemClass
      left outer join ItemType it on inv.ItemType = it.ItemType
    WHERE 
      (Type IS NULL OR Type = 0) 
      AND PendingOrderType IN(0,1,4) 
      AND ((AutoPurchase IS NULL OR AutoPurchase = 0) AND (StationAutoPurchase IS NULL or StationAutoPurchase = 0)) 
      AND (SuggestedQuantity IS NOT NULL OR REQDETNO IS NOT NULL OR c.CRIB IN (SELECT CRIB FROM CRIB WHERE ORDERREVIEWOPTION IS NULL OR ORDERREVIEWOPTION = 0))
      --AND (ItemNumber IS NULL OR BuyerGroupID IS NULL OR BuyerGroupID IN (Select BuyerGroupID From EmployeeBuyerGroup WHERE EmployeeID = 'E-00'))
    GROUP BY c.Crib, vpwal.ItemNumber, c.SiteID, sp.ParentSiteID, inv.ItemClass, ItemClassDescription, inv.ItemType, it.ItemTypeDesc
  )
  
  SELECT
    NVL(POLineData.SiteID,POPendingData.SiteID) AS SiteID,
    NVL(POLineData.Crib,POPendingData.Crib) AS Crib,
    NVL(POLineData.Item,POPendingData.Item) AS Item,
    NVL(POLineData.ParentSiteID,POPendingData.ParentSiteID) AS ParentSiteID,
    NVL(POLineData.ItemClass,POPendingData.ItemClass) AS ItemClass,
    NVL(POLineData.ItemClassDescription,POPendingData.ItemClassDescription) AS ItemClassDescription,
    NVL(POLineData.ItemType,POPendingData.ItemType) AS ItemType,
    NVL(POLineData.ItemTypeDesc,POPendingData.ItemTypeDesc) AS ItemTypeDesc,
    NVL(POLineData.POLinesCount,0) AS POLinesCount,
    NVL(POLineData.QtySum,0) AS QtySum,
    NVL(POLineData.CostSum,0) AS CostSum,
    NVL(PendingAuthorization,0) AS PendingAuthorization,
    NVL(POLineData.POLinesOpenTotal,0) AS POLinesOpenTotal,
    NVL(POLineData.POLinesOpenAndLate,0) AS POLinesOpenAndLate,
    NVL(POLineData.POLinesOpenAndAtLT,0) AS POLinesOpenAndAtLT,
    NVL(POLineData.POLinesOpenAndEarly,0) AS POLinesOpenAndEarly,
    NVL(POLineData.POLinesLateTotal,0) AS POLinesLateTotal,
    NVL(POLineData.POLinesReceivedLate,0) AS POLinesReceivedLate,
    NVL(POLineData.POLinesReceivedAtLeadTime,0) AS POLinesReceivedAtLeadTime,
    NVL(POLineData.POLinesReceivedEarly,0) AS POLinesReceivedEarly	
  FROM 
  
    POLineData 
      FULL OUTER JOIN POPendingData on POPendingData.SiteID = POLineData.SiteID 
      AND POPendingData.Crib = POLineData.Crib 
      AND POPendingData.Item = POLineData.Item
  
  order by SiteID, Crib, Item;

  -- create index for re-populated table
  EXECUTE IMMEDIATE  'CREATE INDEX IX_XPODTSUM_ST_CR ON XPODETAILSSUM (SiteID, Crib)'; 
 
END;
/

--------------- GENERATE DASHBOARD SUMMARIES -------------
CREATE OR REPLACE PROCEDURE GenerateDashboardSummaries
AS
BEGIN

	sp_GenerateSiteUsageSummaries;
  sp_GenerateEmplUsageSummaries;
  sp_GenerateInvHealthSummaries;
  sp_GeneratePODetailsSummaries;
  
  -- Record last date tables updated so status can be monitored
  MERGE INTO GLOBALSETTINGS USING dual ON ( KEYNAME = 'Dashboard_LastSummaryDate' )
  WHEN MATCHED THEN UPDATE SET STRING = TO_CHAR(CURRENT_DATE)
  WHEN NOT MATCHED THEN INSERT (KEYNAME, STRING) 
      VALUES ('Dashboard_LastSummaryDate', TO_CHAR (CURRENT_DATE)); 
 
END GenerateDashboardSummaries;
/
